(function(){const f=document.createElement("link").relList;if(f&&f.supports&&f.supports("modulepreload"))return;for(const m of document.querySelectorAll('link[rel="modulepreload"]'))r(m);new MutationObserver(m=>{for(const h of m)if(h.type==="childList")for(const x of h.addedNodes)x.tagName==="LINK"&&x.rel==="modulepreload"&&r(x)}).observe(document,{childList:!0,subtree:!0});function s(m){const h={};return m.integrity&&(h.integrity=m.integrity),m.referrerPolicy&&(h.referrerPolicy=m.referrerPolicy),m.crossOrigin==="use-credentials"?h.credentials="include":m.crossOrigin==="anonymous"?h.credentials="omit":h.credentials="same-origin",h}function r(m){if(m.ep)return;m.ep=!0;const h=s(m);fetch(m.href,h)}})();function by(i){return i&&i.__esModule&&Object.prototype.hasOwnProperty.call(i,"default")?i.default:i}var wr={exports:{}},Vn={};/**
 * @license React
 * react-jsx-runtime.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var rm;function xy(){if(rm)return Vn;rm=1;var i=Symbol.for("react.transitional.element"),f=Symbol.for("react.fragment");function s(r,m,h){var x=null;if(h!==void 0&&(x=""+h),m.key!==void 0&&(x=""+m.key),"key"in m){h={};for(var N in m)N!=="key"&&(h[N]=m[N])}else h=m;return m=h.ref,{$$typeof:i,type:r,key:x,ref:m!==void 0?m:null,props:h}}return Vn.Fragment=f,Vn.jsx=s,Vn.jsxs=s,Vn}var fm;function Sy(){return fm||(fm=1,wr.exports=xy()),wr.exports}var d=Sy(),qr={exports:{}},ae={};/**
 * @license React
 * react.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var sm;function Ey(){if(sm)return ae;sm=1;var i=Symbol.for("react.transitional.element"),f=Symbol.for("react.portal"),s=Symbol.for("react.fragment"),r=Symbol.for("react.strict_mode"),m=Symbol.for("react.profiler"),h=Symbol.for("react.consumer"),x=Symbol.for("react.context"),N=Symbol.for("react.forward_ref"),S=Symbol.for("react.suspense"),y=Symbol.for("react.memo"),A=Symbol.for("react.lazy"),E=Symbol.for("react.activity"),L=Symbol.iterator;function X(b){return b===null||typeof b!="object"?null:(b=L&&b[L]||b["@@iterator"],typeof b=="function"?b:null)}var Q={isMounted:function(){return!1},enqueueForceUpdate:function(){},enqueueReplaceState:function(){},enqueueSetState:function(){}},R=Object.assign,B={};function w(b,U,Y){this.props=b,this.context=U,this.refs=B,this.updater=Y||Q}w.prototype.isReactComponent={},w.prototype.setState=function(b,U){if(typeof b!="object"&&typeof b!="function"&&b!=null)throw Error("takes an object of state variables to update or a function which returns an object of state variables.");this.updater.enqueueSetState(this,b,U,"setState")},w.prototype.forceUpdate=function(b){this.updater.enqueueForceUpdate(this,b,"forceUpdate")};function k(){}k.prototype=w.prototype;function K(b,U,Y){this.props=b,this.context=U,this.refs=B,this.updater=Y||Q}var ce=K.prototype=new k;ce.constructor=K,R(ce,w.prototype),ce.isPureReactComponent=!0;var le=Array.isArray;function re(){}var $={H:null,A:null,T:null,S:null},_e=Object.prototype.hasOwnProperty;function He(b,U,Y){var Z=Y.ref;return{$$typeof:i,type:b,key:U,ref:Z!==void 0?Z:null,props:Y}}function at(b,U){return He(b.type,U,b.props)}function Ve(b){return typeof b=="object"&&b!==null&&b.$$typeof===i}function Ce(b){var U={"=":"=0",":":"=2"};return"$"+b.replace(/[=:]/g,function(Y){return U[Y]})}var F=/\/+/g;function Me(b,U){return typeof b=="object"&&b!==null&&b.key!=null?Ce(""+b.key):U.toString(36)}function fe(b){switch(b.status){case"fulfilled":return b.value;case"rejected":throw b.reason;default:switch(typeof b.status=="string"?b.then(re,re):(b.status="pending",b.then(function(U){b.status==="pending"&&(b.status="fulfilled",b.value=U)},function(U){b.status==="pending"&&(b.status="rejected",b.reason=U)})),b.status){case"fulfilled":return b.value;case"rejected":throw b.reason}}throw b}function O(b,U,Y,Z,ee){var te=typeof b;(te==="undefined"||te==="boolean")&&(b=null);var ne=!1;if(b===null)ne=!0;else switch(te){case"bigint":case"string":case"number":ne=!0;break;case"object":switch(b.$$typeof){case i:case f:ne=!0;break;case A:return ne=b._init,O(ne(b._payload),U,Y,Z,ee)}}if(ne)return ee=ee(b),ne=Z===""?"."+Me(b,0):Z,le(ee)?(Y="",ne!=null&&(Y=ne.replace(F,"$&/")+"/"),O(ee,U,Y,"",function(ql){return ql})):ee!=null&&(Ve(ee)&&(ee=at(ee,Y+(ee.key==null||b&&b.key===ee.key?"":(""+ee.key).replace(F,"$&/")+"/")+ne)),U.push(ee)),1;ne=0;var $e=Z===""?".":Z+":";if(le(b))for(var Be=0;Be<b.length;Be++)Z=b[Be],te=$e+Me(Z,Be),ne+=O(Z,U,Y,te,ee);else if(Be=X(b),typeof Be=="function")for(b=Be.call(b),Be=0;!(Z=b.next()).done;)Z=Z.value,te=$e+Me(Z,Be++),ne+=O(Z,U,Y,te,ee);else if(te==="object"){if(typeof b.then=="function")return O(fe(b),U,Y,Z,ee);throw U=String(b),Error("Objects are not valid as a React child (found: "+(U==="[object Object]"?"object with keys {"+Object.keys(b).join(", ")+"}":U)+"). If you meant to render a collection of children, use an array instead.")}return ne}function G(b,U,Y){if(b==null)return b;var Z=[],ee=0;return O(b,Z,"","",function(te){return U.call(Y,te,ee++)}),Z}function I(b){if(b._status===-1){var U=b._result;U=U(),U.then(function(Y){(b._status===0||b._status===-1)&&(b._status=1,b._result=Y)},function(Y){(b._status===0||b._status===-1)&&(b._status=2,b._result=Y)}),b._status===-1&&(b._status=0,b._result=U)}if(b._status===1)return b._result.default;throw b._result}var ge=typeof reportError=="function"?reportError:function(b){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var U=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof b=="object"&&b!==null&&typeof b.message=="string"?String(b.message):String(b),error:b});if(!window.dispatchEvent(U))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",b);return}console.error(b)},Se={map:G,forEach:function(b,U,Y){G(b,function(){U.apply(this,arguments)},Y)},count:function(b){var U=0;return G(b,function(){U++}),U},toArray:function(b){return G(b,function(U){return U})||[]},only:function(b){if(!Ve(b))throw Error("React.Children.only expected to receive a single React element child.");return b}};return ae.Activity=E,ae.Children=Se,ae.Component=w,ae.Fragment=s,ae.Profiler=m,ae.PureComponent=K,ae.StrictMode=r,ae.Suspense=S,ae.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=$,ae.__COMPILER_RUNTIME={__proto__:null,c:function(b){return $.H.useMemoCache(b)}},ae.cache=function(b){return function(){return b.apply(null,arguments)}},ae.cacheSignal=function(){return null},ae.cloneElement=function(b,U,Y){if(b==null)throw Error("The argument must be a React element, but you passed "+b+".");var Z=R({},b.props),ee=b.key;if(U!=null)for(te in U.key!==void 0&&(ee=""+U.key),U)!_e.call(U,te)||te==="key"||te==="__self"||te==="__source"||te==="ref"&&U.ref===void 0||(Z[te]=U[te]);var te=arguments.length-2;if(te===1)Z.children=Y;else if(1<te){for(var ne=Array(te),$e=0;$e<te;$e++)ne[$e]=arguments[$e+2];Z.children=ne}return He(b.type,ee,Z)},ae.createContext=function(b){return b={$$typeof:x,_currentValue:b,_currentValue2:b,_threadCount:0,Provider:null,Consumer:null},b.Provider=b,b.Consumer={$$typeof:h,_context:b},b},ae.createElement=function(b,U,Y){var Z,ee={},te=null;if(U!=null)for(Z in U.key!==void 0&&(te=""+U.key),U)_e.call(U,Z)&&Z!=="key"&&Z!=="__self"&&Z!=="__source"&&(ee[Z]=U[Z]);var ne=arguments.length-2;if(ne===1)ee.children=Y;else if(1<ne){for(var $e=Array(ne),Be=0;Be<ne;Be++)$e[Be]=arguments[Be+2];ee.children=$e}if(b&&b.defaultProps)for(Z in ne=b.defaultProps,ne)ee[Z]===void 0&&(ee[Z]=ne[Z]);return He(b,te,ee)},ae.createRef=function(){return{current:null}},ae.forwardRef=function(b){return{$$typeof:N,render:b}},ae.isValidElement=Ve,ae.lazy=function(b){return{$$typeof:A,_payload:{_status:-1,_result:b},_init:I}},ae.memo=function(b,U){return{$$typeof:y,type:b,compare:U===void 0?null:U}},ae.startTransition=function(b){var U=$.T,Y={};$.T=Y;try{var Z=b(),ee=$.S;ee!==null&&ee(Y,Z),typeof Z=="object"&&Z!==null&&typeof Z.then=="function"&&Z.then(re,ge)}catch(te){ge(te)}finally{U!==null&&Y.types!==null&&(U.types=Y.types),$.T=U}},ae.unstable_useCacheRefresh=function(){return $.H.useCacheRefresh()},ae.use=function(b){return $.H.use(b)},ae.useActionState=function(b,U,Y){return $.H.useActionState(b,U,Y)},ae.useCallback=function(b,U){return $.H.useCallback(b,U)},ae.useContext=function(b){return $.H.useContext(b)},ae.useDebugValue=function(){},ae.useDeferredValue=function(b,U){return $.H.useDeferredValue(b,U)},ae.useEffect=function(b,U){return $.H.useEffect(b,U)},ae.useEffectEvent=function(b){return $.H.useEffectEvent(b)},ae.useId=function(){return $.H.useId()},ae.useImperativeHandle=function(b,U,Y){return $.H.useImperativeHandle(b,U,Y)},ae.useInsertionEffect=function(b,U){return $.H.useInsertionEffect(b,U)},ae.useLayoutEffect=function(b,U){return $.H.useLayoutEffect(b,U)},ae.useMemo=function(b,U){return $.H.useMemo(b,U)},ae.useOptimistic=function(b,U){return $.H.useOptimistic(b,U)},ae.useReducer=function(b,U,Y){return $.H.useReducer(b,U,Y)},ae.useRef=function(b){return $.H.useRef(b)},ae.useState=function(b){return $.H.useState(b)},ae.useSyncExternalStore=function(b,U,Y){return $.H.useSyncExternalStore(b,U,Y)},ae.useTransition=function(){return $.H.useTransition()},ae.version="19.2.4",ae}var om;function Ir(){return om||(om=1,qr.exports=Ey()),qr.exports}var g=Ir();const ua=by(g);var Yr={exports:{}},Kn={},Gr={exports:{}},Xr={};/**
 * @license React
 * scheduler.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var dm;function Ty(){return dm||(dm=1,(function(i){function f(O,G){var I=O.length;O.push(G);e:for(;0<I;){var ge=I-1>>>1,Se=O[ge];if(0<m(Se,G))O[ge]=G,O[I]=Se,I=ge;else break e}}function s(O){return O.length===0?null:O[0]}function r(O){if(O.length===0)return null;var G=O[0],I=O.pop();if(I!==G){O[0]=I;e:for(var ge=0,Se=O.length,b=Se>>>1;ge<b;){var U=2*(ge+1)-1,Y=O[U],Z=U+1,ee=O[Z];if(0>m(Y,I))Z<Se&&0>m(ee,Y)?(O[ge]=ee,O[Z]=I,ge=Z):(O[ge]=Y,O[U]=I,ge=U);else if(Z<Se&&0>m(ee,I))O[ge]=ee,O[Z]=I,ge=Z;else break e}}return G}function m(O,G){var I=O.sortIndex-G.sortIndex;return I!==0?I:O.id-G.id}if(i.unstable_now=void 0,typeof performance=="object"&&typeof performance.now=="function"){var h=performance;i.unstable_now=function(){return h.now()}}else{var x=Date,N=x.now();i.unstable_now=function(){return x.now()-N}}var S=[],y=[],A=1,E=null,L=3,X=!1,Q=!1,R=!1,B=!1,w=typeof setTimeout=="function"?setTimeout:null,k=typeof clearTimeout=="function"?clearTimeout:null,K=typeof setImmediate<"u"?setImmediate:null;function ce(O){for(var G=s(y);G!==null;){if(G.callback===null)r(y);else if(G.startTime<=O)r(y),G.sortIndex=G.expirationTime,f(S,G);else break;G=s(y)}}function le(O){if(R=!1,ce(O),!Q)if(s(S)!==null)Q=!0,re||(re=!0,Ce());else{var G=s(y);G!==null&&fe(le,G.startTime-O)}}var re=!1,$=-1,_e=5,He=-1;function at(){return B?!0:!(i.unstable_now()-He<_e)}function Ve(){if(B=!1,re){var O=i.unstable_now();He=O;var G=!0;try{e:{Q=!1,R&&(R=!1,k($),$=-1),X=!0;var I=L;try{t:{for(ce(O),E=s(S);E!==null&&!(E.expirationTime>O&&at());){var ge=E.callback;if(typeof ge=="function"){E.callback=null,L=E.priorityLevel;var Se=ge(E.expirationTime<=O);if(O=i.unstable_now(),typeof Se=="function"){E.callback=Se,ce(O),G=!0;break t}E===s(S)&&r(S),ce(O)}else r(S);E=s(S)}if(E!==null)G=!0;else{var b=s(y);b!==null&&fe(le,b.startTime-O),G=!1}}break e}finally{E=null,L=I,X=!1}G=void 0}}finally{G?Ce():re=!1}}}var Ce;if(typeof K=="function")Ce=function(){K(Ve)};else if(typeof MessageChannel<"u"){var F=new MessageChannel,Me=F.port2;F.port1.onmessage=Ve,Ce=function(){Me.postMessage(null)}}else Ce=function(){w(Ve,0)};function fe(O,G){$=w(function(){O(i.unstable_now())},G)}i.unstable_IdlePriority=5,i.unstable_ImmediatePriority=1,i.unstable_LowPriority=4,i.unstable_NormalPriority=3,i.unstable_Profiling=null,i.unstable_UserBlockingPriority=2,i.unstable_cancelCallback=function(O){O.callback=null},i.unstable_forceFrameRate=function(O){0>O||125<O?console.error("forceFrameRate takes a positive int between 0 and 125, forcing frame rates higher than 125 fps is not supported"):_e=0<O?Math.floor(1e3/O):5},i.unstable_getCurrentPriorityLevel=function(){return L},i.unstable_next=function(O){switch(L){case 1:case 2:case 3:var G=3;break;default:G=L}var I=L;L=G;try{return O()}finally{L=I}},i.unstable_requestPaint=function(){B=!0},i.unstable_runWithPriority=function(O,G){switch(O){case 1:case 2:case 3:case 4:case 5:break;default:O=3}var I=L;L=O;try{return G()}finally{L=I}},i.unstable_scheduleCallback=function(O,G,I){var ge=i.unstable_now();switch(typeof I=="object"&&I!==null?(I=I.delay,I=typeof I=="number"&&0<I?ge+I:ge):I=ge,O){case 1:var Se=-1;break;case 2:Se=250;break;case 5:Se=1073741823;break;case 4:Se=1e4;break;default:Se=5e3}return Se=I+Se,O={id:A++,callback:G,priorityLevel:O,startTime:I,expirationTime:Se,sortIndex:-1},I>ge?(O.sortIndex=I,f(y,O),s(S)===null&&O===s(y)&&(R?(k($),$=-1):R=!0,fe(le,I-ge))):(O.sortIndex=Se,f(S,O),Q||X||(Q=!0,re||(re=!0,Ce()))),O},i.unstable_shouldYield=at,i.unstable_wrapCallback=function(O){var G=L;return function(){var I=L;L=G;try{return O.apply(this,arguments)}finally{L=I}}}})(Xr)),Xr}var mm;function Ny(){return mm||(mm=1,Gr.exports=Ty()),Gr.exports}var Qr={exports:{}},tt={};/**
 * @license React
 * react-dom.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var hm;function zy(){if(hm)return tt;hm=1;var i=Ir();function f(S){var y="https://react.dev/errors/"+S;if(1<arguments.length){y+="?args[]="+encodeURIComponent(arguments[1]);for(var A=2;A<arguments.length;A++)y+="&args[]="+encodeURIComponent(arguments[A])}return"Minified React error #"+S+"; visit "+y+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function s(){}var r={d:{f:s,r:function(){throw Error(f(522))},D:s,C:s,L:s,m:s,X:s,S:s,M:s},p:0,findDOMNode:null},m=Symbol.for("react.portal");function h(S,y,A){var E=3<arguments.length&&arguments[3]!==void 0?arguments[3]:null;return{$$typeof:m,key:E==null?null:""+E,children:S,containerInfo:y,implementation:A}}var x=i.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE;function N(S,y){if(S==="font")return"";if(typeof y=="string")return y==="use-credentials"?y:""}return tt.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE=r,tt.createPortal=function(S,y){var A=2<arguments.length&&arguments[2]!==void 0?arguments[2]:null;if(!y||y.nodeType!==1&&y.nodeType!==9&&y.nodeType!==11)throw Error(f(299));return h(S,y,null,A)},tt.flushSync=function(S){var y=x.T,A=r.p;try{if(x.T=null,r.p=2,S)return S()}finally{x.T=y,r.p=A,r.d.f()}},tt.preconnect=function(S,y){typeof S=="string"&&(y?(y=y.crossOrigin,y=typeof y=="string"?y==="use-credentials"?y:"":void 0):y=null,r.d.C(S,y))},tt.prefetchDNS=function(S){typeof S=="string"&&r.d.D(S)},tt.preinit=function(S,y){if(typeof S=="string"&&y&&typeof y.as=="string"){var A=y.as,E=N(A,y.crossOrigin),L=typeof y.integrity=="string"?y.integrity:void 0,X=typeof y.fetchPriority=="string"?y.fetchPriority:void 0;A==="style"?r.d.S(S,typeof y.precedence=="string"?y.precedence:void 0,{crossOrigin:E,integrity:L,fetchPriority:X}):A==="script"&&r.d.X(S,{crossOrigin:E,integrity:L,fetchPriority:X,nonce:typeof y.nonce=="string"?y.nonce:void 0})}},tt.preinitModule=function(S,y){if(typeof S=="string")if(typeof y=="object"&&y!==null){if(y.as==null||y.as==="script"){var A=N(y.as,y.crossOrigin);r.d.M(S,{crossOrigin:A,integrity:typeof y.integrity=="string"?y.integrity:void 0,nonce:typeof y.nonce=="string"?y.nonce:void 0})}}else y==null&&r.d.M(S)},tt.preload=function(S,y){if(typeof S=="string"&&typeof y=="object"&&y!==null&&typeof y.as=="string"){var A=y.as,E=N(A,y.crossOrigin);r.d.L(S,A,{crossOrigin:E,integrity:typeof y.integrity=="string"?y.integrity:void 0,nonce:typeof y.nonce=="string"?y.nonce:void 0,type:typeof y.type=="string"?y.type:void 0,fetchPriority:typeof y.fetchPriority=="string"?y.fetchPriority:void 0,referrerPolicy:typeof y.referrerPolicy=="string"?y.referrerPolicy:void 0,imageSrcSet:typeof y.imageSrcSet=="string"?y.imageSrcSet:void 0,imageSizes:typeof y.imageSizes=="string"?y.imageSizes:void 0,media:typeof y.media=="string"?y.media:void 0})}},tt.preloadModule=function(S,y){if(typeof S=="string")if(y){var A=N(y.as,y.crossOrigin);r.d.m(S,{as:typeof y.as=="string"&&y.as!=="script"?y.as:void 0,crossOrigin:A,integrity:typeof y.integrity=="string"?y.integrity:void 0})}else r.d.m(S)},tt.requestFormReset=function(S){r.d.r(S)},tt.unstable_batchedUpdates=function(S,y){return S(y)},tt.useFormState=function(S,y,A){return x.H.useFormState(S,y,A)},tt.useFormStatus=function(){return x.H.useHostTransitionStatus()},tt.version="19.2.4",tt}var vm;function jy(){if(vm)return Qr.exports;vm=1;function i(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(i)}catch(f){console.error(f)}}return i(),Qr.exports=zy(),Qr.exports}/**
 * @license React
 * react-dom-client.production.js
 *
 * Copyright (c) Meta Platforms, Inc. and affiliates.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */var ym;function _y(){if(ym)return Kn;ym=1;var i=Ny(),f=Ir(),s=jy();function r(e){var t="https://react.dev/errors/"+e;if(1<arguments.length){t+="?args[]="+encodeURIComponent(arguments[1]);for(var l=2;l<arguments.length;l++)t+="&args[]="+encodeURIComponent(arguments[l])}return"Minified React error #"+e+"; visit "+t+" for the full message or use the non-minified dev environment for full errors and additional helpful warnings."}function m(e){return!(!e||e.nodeType!==1&&e.nodeType!==9&&e.nodeType!==11)}function h(e){var t=e,l=e;if(e.alternate)for(;t.return;)t=t.return;else{e=t;do t=e,(t.flags&4098)!==0&&(l=t.return),e=t.return;while(e)}return t.tag===3?l:null}function x(e){if(e.tag===13){var t=e.memoizedState;if(t===null&&(e=e.alternate,e!==null&&(t=e.memoizedState)),t!==null)return t.dehydrated}return null}function N(e){if(e.tag===31){var t=e.memoizedState;if(t===null&&(e=e.alternate,e!==null&&(t=e.memoizedState)),t!==null)return t.dehydrated}return null}function S(e){if(h(e)!==e)throw Error(r(188))}function y(e){var t=e.alternate;if(!t){if(t=h(e),t===null)throw Error(r(188));return t!==e?null:e}for(var l=e,a=t;;){var n=l.return;if(n===null)break;var u=n.alternate;if(u===null){if(a=n.return,a!==null){l=a;continue}break}if(n.child===u.child){for(u=n.child;u;){if(u===l)return S(n),e;if(u===a)return S(n),t;u=u.sibling}throw Error(r(188))}if(l.return!==a.return)l=n,a=u;else{for(var c=!1,o=n.child;o;){if(o===l){c=!0,l=n,a=u;break}if(o===a){c=!0,a=n,l=u;break}o=o.sibling}if(!c){for(o=u.child;o;){if(o===l){c=!0,l=u,a=n;break}if(o===a){c=!0,a=u,l=n;break}o=o.sibling}if(!c)throw Error(r(189))}}if(l.alternate!==a)throw Error(r(190))}if(l.tag!==3)throw Error(r(188));return l.stateNode.current===l?e:t}function A(e){var t=e.tag;if(t===5||t===26||t===27||t===6)return e;for(e=e.child;e!==null;){if(t=A(e),t!==null)return t;e=e.sibling}return null}var E=Object.assign,L=Symbol.for("react.element"),X=Symbol.for("react.transitional.element"),Q=Symbol.for("react.portal"),R=Symbol.for("react.fragment"),B=Symbol.for("react.strict_mode"),w=Symbol.for("react.profiler"),k=Symbol.for("react.consumer"),K=Symbol.for("react.context"),ce=Symbol.for("react.forward_ref"),le=Symbol.for("react.suspense"),re=Symbol.for("react.suspense_list"),$=Symbol.for("react.memo"),_e=Symbol.for("react.lazy"),He=Symbol.for("react.activity"),at=Symbol.for("react.memo_cache_sentinel"),Ve=Symbol.iterator;function Ce(e){return e===null||typeof e!="object"?null:(e=Ve&&e[Ve]||e["@@iterator"],typeof e=="function"?e:null)}var F=Symbol.for("react.client.reference");function Me(e){if(e==null)return null;if(typeof e=="function")return e.$$typeof===F?null:e.displayName||e.name||null;if(typeof e=="string")return e;switch(e){case R:return"Fragment";case w:return"Profiler";case B:return"StrictMode";case le:return"Suspense";case re:return"SuspenseList";case He:return"Activity"}if(typeof e=="object")switch(e.$$typeof){case Q:return"Portal";case K:return e.displayName||"Context";case k:return(e._context.displayName||"Context")+".Consumer";case ce:var t=e.render;return e=e.displayName,e||(e=t.displayName||t.name||"",e=e!==""?"ForwardRef("+e+")":"ForwardRef"),e;case $:return t=e.displayName||null,t!==null?t:Me(e.type)||"Memo";case _e:t=e._payload,e=e._init;try{return Me(e(t))}catch{}}return null}var fe=Array.isArray,O=f.__CLIENT_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,G=s.__DOM_INTERNALS_DO_NOT_USE_OR_WARN_USERS_THEY_CANNOT_UPGRADE,I={pending:!1,data:null,method:null,action:null},ge=[],Se=-1;function b(e){return{current:e}}function U(e){0>Se||(e.current=ge[Se],ge[Se]=null,Se--)}function Y(e,t){Se++,ge[Se]=e.current,e.current=t}var Z=b(null),ee=b(null),te=b(null),ne=b(null);function $e(e,t){switch(Y(te,t),Y(ee,e),Y(Z,null),t.nodeType){case 9:case 11:e=(e=t.documentElement)&&(e=e.namespaceURI)?Od(e):0;break;default:if(e=t.tagName,t=t.namespaceURI)t=Od(t),e=Md(t,e);else switch(e){case"svg":e=1;break;case"math":e=2;break;default:e=0}}U(Z),Y(Z,e)}function Be(){U(Z),U(ee),U(te)}function ql(e){e.memoizedState!==null&&Y(ne,e);var t=Z.current,l=Md(t,e.type);t!==l&&(Y(ee,e),Y(Z,l))}function Yl(e){ee.current===e&&(U(Z),U(ee)),ne.current===e&&(U(ne),Gn._currentValue=I)}var $a,dl;function qt(e){if($a===void 0)try{throw Error()}catch(l){var t=l.stack.trim().match(/\n( *(at )?)/);$a=t&&t[1]||"",dl=-1<l.stack.indexOf(`
    at`)?" (<anonymous>)":-1<l.stack.indexOf("@")?"@unknown:0:0":""}return`
`+$a+e+dl}var Wa=!1;function Fa(e,t){if(!e||Wa)return"";Wa=!0;var l=Error.prepareStackTrace;Error.prepareStackTrace=void 0;try{var a={DetermineComponentFrameRoot:function(){try{if(t){var H=function(){throw Error()};if(Object.defineProperty(H.prototype,"props",{set:function(){throw Error()}}),typeof Reflect=="object"&&Reflect.construct){try{Reflect.construct(H,[])}catch(C){var _=C}Reflect.construct(e,[],H)}else{try{H.call()}catch(C){_=C}e.call(H.prototype)}}else{try{throw Error()}catch(C){_=C}(H=e())&&typeof H.catch=="function"&&H.catch(function(){})}}catch(C){if(C&&_&&typeof C.stack=="string")return[C.stack,_.stack]}return[null,null]}};a.DetermineComponentFrameRoot.displayName="DetermineComponentFrameRoot";var n=Object.getOwnPropertyDescriptor(a.DetermineComponentFrameRoot,"name");n&&n.configurable&&Object.defineProperty(a.DetermineComponentFrameRoot,"name",{value:"DetermineComponentFrameRoot"});var u=a.DetermineComponentFrameRoot(),c=u[0],o=u[1];if(c&&o){var v=c.split(`
`),j=o.split(`
`);for(n=a=0;a<v.length&&!v[a].includes("DetermineComponentFrameRoot");)a++;for(;n<j.length&&!j[n].includes("DetermineComponentFrameRoot");)n++;if(a===v.length||n===j.length)for(a=v.length-1,n=j.length-1;1<=a&&0<=n&&v[a]!==j[n];)n--;for(;1<=a&&0<=n;a--,n--)if(v[a]!==j[n]){if(a!==1||n!==1)do if(a--,n--,0>n||v[a]!==j[n]){var M=`
`+v[a].replace(" at new "," at ");return e.displayName&&M.includes("<anonymous>")&&(M=M.replace("<anonymous>",e.displayName)),M}while(1<=a&&0<=n);break}}}finally{Wa=!1,Error.prepareStackTrace=l}return(l=e?e.displayName||e.name:"")?qt(l):""}function q(e,t){switch(e.tag){case 26:case 27:case 5:return qt(e.type);case 16:return qt("Lazy");case 13:return e.child!==t&&t!==null?qt("Suspense Fallback"):qt("Suspense");case 19:return qt("SuspenseList");case 0:case 15:return Fa(e.type,!1);case 11:return Fa(e.type.render,!1);case 1:return Fa(e.type,!0);case 31:return qt("Activity");default:return""}}function ve(e){try{var t="",l=null;do t+=q(e,l),l=e,e=e.return;while(e);return t}catch(a){return`
Error generating stack: `+a.message+`
`+a.stack}}var nt=Object.prototype.hasOwnProperty,Dt=i.unstable_scheduleCallback,Yt=i.unstable_cancelCallback,In=i.unstable_shouldYield,Pn=i.unstable_requestPaint,be=i.unstable_now,Pm=i.unstable_getCurrentPriorityLevel,rf=i.unstable_ImmediatePriority,ff=i.unstable_UserBlockingPriority,eu=i.unstable_NormalPriority,eh=i.unstable_LowPriority,sf=i.unstable_IdlePriority,th=i.log,lh=i.unstable_setDisableYieldValue,Ia=null,dt=null;function ml(e){if(typeof th=="function"&&lh(e),dt&&typeof dt.setStrictMode=="function")try{dt.setStrictMode(Ia,e)}catch{}}var mt=Math.clz32?Math.clz32:uh,ah=Math.log,nh=Math.LN2;function uh(e){return e>>>=0,e===0?32:31-(ah(e)/nh|0)|0}var tu=256,lu=262144,au=4194304;function Gl(e){var t=e&42;if(t!==0)return t;switch(e&-e){case 1:return 1;case 2:return 2;case 4:return 4;case 8:return 8;case 16:return 16;case 32:return 32;case 64:return 64;case 128:return 128;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:return e&261888;case 262144:case 524288:case 1048576:case 2097152:return e&3932160;case 4194304:case 8388608:case 16777216:case 33554432:return e&62914560;case 67108864:return 67108864;case 134217728:return 134217728;case 268435456:return 268435456;case 536870912:return 536870912;case 1073741824:return 0;default:return e}}function nu(e,t,l){var a=e.pendingLanes;if(a===0)return 0;var n=0,u=e.suspendedLanes,c=e.pingedLanes;e=e.warmLanes;var o=a&134217727;return o!==0?(a=o&~u,a!==0?n=Gl(a):(c&=o,c!==0?n=Gl(c):l||(l=o&~e,l!==0&&(n=Gl(l))))):(o=a&~u,o!==0?n=Gl(o):c!==0?n=Gl(c):l||(l=a&~e,l!==0&&(n=Gl(l)))),n===0?0:t!==0&&t!==n&&(t&u)===0&&(u=n&-n,l=t&-t,u>=l||u===32&&(l&4194048)!==0)?t:n}function Pa(e,t){return(e.pendingLanes&~(e.suspendedLanes&~e.pingedLanes)&t)===0}function ih(e,t){switch(e){case 1:case 2:case 4:case 8:case 64:return t+250;case 16:case 32:case 128:case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:return t+5e3;case 4194304:case 8388608:case 16777216:case 33554432:return-1;case 67108864:case 134217728:case 268435456:case 536870912:case 1073741824:return-1;default:return-1}}function of(){var e=au;return au<<=1,(au&62914560)===0&&(au=4194304),e}function ji(e){for(var t=[],l=0;31>l;l++)t.push(e);return t}function en(e,t){e.pendingLanes|=t,t!==268435456&&(e.suspendedLanes=0,e.pingedLanes=0,e.warmLanes=0)}function ch(e,t,l,a,n,u){var c=e.pendingLanes;e.pendingLanes=l,e.suspendedLanes=0,e.pingedLanes=0,e.warmLanes=0,e.expiredLanes&=l,e.entangledLanes&=l,e.errorRecoveryDisabledLanes&=l,e.shellSuspendCounter=0;var o=e.entanglements,v=e.expirationTimes,j=e.hiddenUpdates;for(l=c&~l;0<l;){var M=31-mt(l),H=1<<M;o[M]=0,v[M]=-1;var _=j[M];if(_!==null)for(j[M]=null,M=0;M<_.length;M++){var C=_[M];C!==null&&(C.lane&=-536870913)}l&=~H}a!==0&&df(e,a,0),u!==0&&n===0&&e.tag!==0&&(e.suspendedLanes|=u&~(c&~t))}function df(e,t,l){e.pendingLanes|=t,e.suspendedLanes&=~t;var a=31-mt(t);e.entangledLanes|=t,e.entanglements[a]=e.entanglements[a]|1073741824|l&261930}function mf(e,t){var l=e.entangledLanes|=t;for(e=e.entanglements;l;){var a=31-mt(l),n=1<<a;n&t|e[a]&t&&(e[a]|=t),l&=~n}}function hf(e,t){var l=t&-t;return l=(l&42)!==0?1:_i(l),(l&(e.suspendedLanes|t))!==0?0:l}function _i(e){switch(e){case 2:e=1;break;case 8:e=4;break;case 32:e=16;break;case 256:case 512:case 1024:case 2048:case 4096:case 8192:case 16384:case 32768:case 65536:case 131072:case 262144:case 524288:case 1048576:case 2097152:case 4194304:case 8388608:case 16777216:case 33554432:e=128;break;case 268435456:e=134217728;break;default:e=0}return e}function Ai(e){return e&=-e,2<e?8<e?(e&134217727)!==0?32:268435456:8:2}function vf(){var e=G.p;return e!==0?e:(e=window.event,e===void 0?32:tm(e.type))}function yf(e,t){var l=G.p;try{return G.p=e,t()}finally{G.p=l}}var hl=Math.random().toString(36).slice(2),We="__reactFiber$"+hl,ut="__reactProps$"+hl,ia="__reactContainer$"+hl,Ci="__reactEvents$"+hl,rh="__reactListeners$"+hl,fh="__reactHandles$"+hl,pf="__reactResources$"+hl,tn="__reactMarker$"+hl;function Ri(e){delete e[We],delete e[ut],delete e[Ci],delete e[rh],delete e[fh]}function ca(e){var t=e[We];if(t)return t;for(var l=e.parentNode;l;){if(t=l[ia]||l[We]){if(l=t.alternate,t.child!==null||l!==null&&l.child!==null)for(e=qd(e);e!==null;){if(l=e[We])return l;e=qd(e)}return t}e=l,l=e.parentNode}return null}function ra(e){if(e=e[We]||e[ia]){var t=e.tag;if(t===5||t===6||t===13||t===31||t===26||t===27||t===3)return e}return null}function ln(e){var t=e.tag;if(t===5||t===26||t===27||t===6)return e.stateNode;throw Error(r(33))}function fa(e){var t=e[pf];return t||(t=e[pf]={hoistableStyles:new Map,hoistableScripts:new Map}),t}function Je(e){e[tn]=!0}var gf=new Set,bf={};function Xl(e,t){sa(e,t),sa(e+"Capture",t)}function sa(e,t){for(bf[e]=t,e=0;e<t.length;e++)gf.add(t[e])}var sh=RegExp("^[:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD][:A-Z_a-z\\u00C0-\\u00D6\\u00D8-\\u00F6\\u00F8-\\u02FF\\u0370-\\u037D\\u037F-\\u1FFF\\u200C-\\u200D\\u2070-\\u218F\\u2C00-\\u2FEF\\u3001-\\uD7FF\\uF900-\\uFDCF\\uFDF0-\\uFFFD\\-.0-9\\u00B7\\u0300-\\u036F\\u203F-\\u2040]*$"),xf={},Sf={};function oh(e){return nt.call(Sf,e)?!0:nt.call(xf,e)?!1:sh.test(e)?Sf[e]=!0:(xf[e]=!0,!1)}function uu(e,t,l){if(oh(t))if(l===null)e.removeAttribute(t);else{switch(typeof l){case"undefined":case"function":case"symbol":e.removeAttribute(t);return;case"boolean":var a=t.toLowerCase().slice(0,5);if(a!=="data-"&&a!=="aria-"){e.removeAttribute(t);return}}e.setAttribute(t,""+l)}}function iu(e,t,l){if(l===null)e.removeAttribute(t);else{switch(typeof l){case"undefined":case"function":case"symbol":case"boolean":e.removeAttribute(t);return}e.setAttribute(t,""+l)}}function Kt(e,t,l,a){if(a===null)e.removeAttribute(l);else{switch(typeof a){case"undefined":case"function":case"symbol":case"boolean":e.removeAttribute(l);return}e.setAttributeNS(t,l,""+a)}}function Et(e){switch(typeof e){case"bigint":case"boolean":case"number":case"string":case"undefined":return e;case"object":return e;default:return""}}function Ef(e){var t=e.type;return(e=e.nodeName)&&e.toLowerCase()==="input"&&(t==="checkbox"||t==="radio")}function dh(e,t,l){var a=Object.getOwnPropertyDescriptor(e.constructor.prototype,t);if(!e.hasOwnProperty(t)&&typeof a<"u"&&typeof a.get=="function"&&typeof a.set=="function"){var n=a.get,u=a.set;return Object.defineProperty(e,t,{configurable:!0,get:function(){return n.call(this)},set:function(c){l=""+c,u.call(this,c)}}),Object.defineProperty(e,t,{enumerable:a.enumerable}),{getValue:function(){return l},setValue:function(c){l=""+c},stopTracking:function(){e._valueTracker=null,delete e[t]}}}}function Oi(e){if(!e._valueTracker){var t=Ef(e)?"checked":"value";e._valueTracker=dh(e,t,""+e[t])}}function Tf(e){if(!e)return!1;var t=e._valueTracker;if(!t)return!0;var l=t.getValue(),a="";return e&&(a=Ef(e)?e.checked?"true":"false":e.value),e=a,e!==l?(t.setValue(e),!0):!1}function cu(e){if(e=e||(typeof document<"u"?document:void 0),typeof e>"u")return null;try{return e.activeElement||e.body}catch{return e.body}}var mh=/[\n"\\]/g;function Tt(e){return e.replace(mh,function(t){return"\\"+t.charCodeAt(0).toString(16)+" "})}function Mi(e,t,l,a,n,u,c,o){e.name="",c!=null&&typeof c!="function"&&typeof c!="symbol"&&typeof c!="boolean"?e.type=c:e.removeAttribute("type"),t!=null?c==="number"?(t===0&&e.value===""||e.value!=t)&&(e.value=""+Et(t)):e.value!==""+Et(t)&&(e.value=""+Et(t)):c!=="submit"&&c!=="reset"||e.removeAttribute("value"),t!=null?Di(e,c,Et(t)):l!=null?Di(e,c,Et(l)):a!=null&&e.removeAttribute("value"),n==null&&u!=null&&(e.defaultChecked=!!u),n!=null&&(e.checked=n&&typeof n!="function"&&typeof n!="symbol"),o!=null&&typeof o!="function"&&typeof o!="symbol"&&typeof o!="boolean"?e.name=""+Et(o):e.removeAttribute("name")}function Nf(e,t,l,a,n,u,c,o){if(u!=null&&typeof u!="function"&&typeof u!="symbol"&&typeof u!="boolean"&&(e.type=u),t!=null||l!=null){if(!(u!=="submit"&&u!=="reset"||t!=null)){Oi(e);return}l=l!=null?""+Et(l):"",t=t!=null?""+Et(t):l,o||t===e.value||(e.value=t),e.defaultValue=t}a=a??n,a=typeof a!="function"&&typeof a!="symbol"&&!!a,e.checked=o?e.checked:!!a,e.defaultChecked=!!a,c!=null&&typeof c!="function"&&typeof c!="symbol"&&typeof c!="boolean"&&(e.name=c),Oi(e)}function Di(e,t,l){t==="number"&&cu(e.ownerDocument)===e||e.defaultValue===""+l||(e.defaultValue=""+l)}function oa(e,t,l,a){if(e=e.options,t){t={};for(var n=0;n<l.length;n++)t["$"+l[n]]=!0;for(l=0;l<e.length;l++)n=t.hasOwnProperty("$"+e[l].value),e[l].selected!==n&&(e[l].selected=n),n&&a&&(e[l].defaultSelected=!0)}else{for(l=""+Et(l),t=null,n=0;n<e.length;n++){if(e[n].value===l){e[n].selected=!0,a&&(e[n].defaultSelected=!0);return}t!==null||e[n].disabled||(t=e[n])}t!==null&&(t.selected=!0)}}function zf(e,t,l){if(t!=null&&(t=""+Et(t),t!==e.value&&(e.value=t),l==null)){e.defaultValue!==t&&(e.defaultValue=t);return}e.defaultValue=l!=null?""+Et(l):""}function jf(e,t,l,a){if(t==null){if(a!=null){if(l!=null)throw Error(r(92));if(fe(a)){if(1<a.length)throw Error(r(93));a=a[0]}l=a}l==null&&(l=""),t=l}l=Et(t),e.defaultValue=l,a=e.textContent,a===l&&a!==""&&a!==null&&(e.value=a),Oi(e)}function da(e,t){if(t){var l=e.firstChild;if(l&&l===e.lastChild&&l.nodeType===3){l.nodeValue=t;return}}e.textContent=t}var hh=new Set("animationIterationCount aspectRatio borderImageOutset borderImageSlice borderImageWidth boxFlex boxFlexGroup boxOrdinalGroup columnCount columns flex flexGrow flexPositive flexShrink flexNegative flexOrder gridArea gridRow gridRowEnd gridRowSpan gridRowStart gridColumn gridColumnEnd gridColumnSpan gridColumnStart fontWeight lineClamp lineHeight opacity order orphans scale tabSize widows zIndex zoom fillOpacity floodOpacity stopOpacity strokeDasharray strokeDashoffset strokeMiterlimit strokeOpacity strokeWidth MozAnimationIterationCount MozBoxFlex MozBoxFlexGroup MozLineClamp msAnimationIterationCount msFlex msZoom msFlexGrow msFlexNegative msFlexOrder msFlexPositive msFlexShrink msGridColumn msGridColumnSpan msGridRow msGridRowSpan WebkitAnimationIterationCount WebkitBoxFlex WebKitBoxFlexGroup WebkitBoxOrdinalGroup WebkitColumnCount WebkitColumns WebkitFlex WebkitFlexGrow WebkitFlexPositive WebkitFlexShrink WebkitLineClamp".split(" "));function _f(e,t,l){var a=t.indexOf("--")===0;l==null||typeof l=="boolean"||l===""?a?e.setProperty(t,""):t==="float"?e.cssFloat="":e[t]="":a?e.setProperty(t,l):typeof l!="number"||l===0||hh.has(t)?t==="float"?e.cssFloat=l:e[t]=(""+l).trim():e[t]=l+"px"}function Af(e,t,l){if(t!=null&&typeof t!="object")throw Error(r(62));if(e=e.style,l!=null){for(var a in l)!l.hasOwnProperty(a)||t!=null&&t.hasOwnProperty(a)||(a.indexOf("--")===0?e.setProperty(a,""):a==="float"?e.cssFloat="":e[a]="");for(var n in t)a=t[n],t.hasOwnProperty(n)&&l[n]!==a&&_f(e,n,a)}else for(var u in t)t.hasOwnProperty(u)&&_f(e,u,t[u])}function Ui(e){if(e.indexOf("-")===-1)return!1;switch(e){case"annotation-xml":case"color-profile":case"font-face":case"font-face-src":case"font-face-uri":case"font-face-format":case"font-face-name":case"missing-glyph":return!1;default:return!0}}var vh=new Map([["acceptCharset","accept-charset"],["htmlFor","for"],["httpEquiv","http-equiv"],["crossOrigin","crossorigin"],["accentHeight","accent-height"],["alignmentBaseline","alignment-baseline"],["arabicForm","arabic-form"],["baselineShift","baseline-shift"],["capHeight","cap-height"],["clipPath","clip-path"],["clipRule","clip-rule"],["colorInterpolation","color-interpolation"],["colorInterpolationFilters","color-interpolation-filters"],["colorProfile","color-profile"],["colorRendering","color-rendering"],["dominantBaseline","dominant-baseline"],["enableBackground","enable-background"],["fillOpacity","fill-opacity"],["fillRule","fill-rule"],["floodColor","flood-color"],["floodOpacity","flood-opacity"],["fontFamily","font-family"],["fontSize","font-size"],["fontSizeAdjust","font-size-adjust"],["fontStretch","font-stretch"],["fontStyle","font-style"],["fontVariant","font-variant"],["fontWeight","font-weight"],["glyphName","glyph-name"],["glyphOrientationHorizontal","glyph-orientation-horizontal"],["glyphOrientationVertical","glyph-orientation-vertical"],["horizAdvX","horiz-adv-x"],["horizOriginX","horiz-origin-x"],["imageRendering","image-rendering"],["letterSpacing","letter-spacing"],["lightingColor","lighting-color"],["markerEnd","marker-end"],["markerMid","marker-mid"],["markerStart","marker-start"],["overlinePosition","overline-position"],["overlineThickness","overline-thickness"],["paintOrder","paint-order"],["panose-1","panose-1"],["pointerEvents","pointer-events"],["renderingIntent","rendering-intent"],["shapeRendering","shape-rendering"],["stopColor","stop-color"],["stopOpacity","stop-opacity"],["strikethroughPosition","strikethrough-position"],["strikethroughThickness","strikethrough-thickness"],["strokeDasharray","stroke-dasharray"],["strokeDashoffset","stroke-dashoffset"],["strokeLinecap","stroke-linecap"],["strokeLinejoin","stroke-linejoin"],["strokeMiterlimit","stroke-miterlimit"],["strokeOpacity","stroke-opacity"],["strokeWidth","stroke-width"],["textAnchor","text-anchor"],["textDecoration","text-decoration"],["textRendering","text-rendering"],["transformOrigin","transform-origin"],["underlinePosition","underline-position"],["underlineThickness","underline-thickness"],["unicodeBidi","unicode-bidi"],["unicodeRange","unicode-range"],["unitsPerEm","units-per-em"],["vAlphabetic","v-alphabetic"],["vHanging","v-hanging"],["vIdeographic","v-ideographic"],["vMathematical","v-mathematical"],["vectorEffect","vector-effect"],["vertAdvY","vert-adv-y"],["vertOriginX","vert-origin-x"],["vertOriginY","vert-origin-y"],["wordSpacing","word-spacing"],["writingMode","writing-mode"],["xmlnsXlink","xmlns:xlink"],["xHeight","x-height"]]),yh=/^[\u0000-\u001F ]*j[\r\n\t]*a[\r\n\t]*v[\r\n\t]*a[\r\n\t]*s[\r\n\t]*c[\r\n\t]*r[\r\n\t]*i[\r\n\t]*p[\r\n\t]*t[\r\n\t]*:/i;function ru(e){return yh.test(""+e)?"javascript:throw new Error('React has blocked a javascript: URL as a security precaution.')":e}function Jt(){}var Hi=null;function Bi(e){return e=e.target||e.srcElement||window,e.correspondingUseElement&&(e=e.correspondingUseElement),e.nodeType===3?e.parentNode:e}var ma=null,ha=null;function Cf(e){var t=ra(e);if(t&&(e=t.stateNode)){var l=e[ut]||null;e:switch(e=t.stateNode,t.type){case"input":if(Mi(e,l.value,l.defaultValue,l.defaultValue,l.checked,l.defaultChecked,l.type,l.name),t=l.name,l.type==="radio"&&t!=null){for(l=e;l.parentNode;)l=l.parentNode;for(l=l.querySelectorAll('input[name="'+Tt(""+t)+'"][type="radio"]'),t=0;t<l.length;t++){var a=l[t];if(a!==e&&a.form===e.form){var n=a[ut]||null;if(!n)throw Error(r(90));Mi(a,n.value,n.defaultValue,n.defaultValue,n.checked,n.defaultChecked,n.type,n.name)}}for(t=0;t<l.length;t++)a=l[t],a.form===e.form&&Tf(a)}break e;case"textarea":zf(e,l.value,l.defaultValue);break e;case"select":t=l.value,t!=null&&oa(e,!!l.multiple,t,!1)}}}var Li=!1;function Rf(e,t,l){if(Li)return e(t,l);Li=!0;try{var a=e(t);return a}finally{if(Li=!1,(ma!==null||ha!==null)&&($u(),ma&&(t=ma,e=ha,ha=ma=null,Cf(t),e)))for(t=0;t<e.length;t++)Cf(e[t])}}function an(e,t){var l=e.stateNode;if(l===null)return null;var a=l[ut]||null;if(a===null)return null;l=a[t];e:switch(t){case"onClick":case"onClickCapture":case"onDoubleClick":case"onDoubleClickCapture":case"onMouseDown":case"onMouseDownCapture":case"onMouseMove":case"onMouseMoveCapture":case"onMouseUp":case"onMouseUpCapture":case"onMouseEnter":(a=!a.disabled)||(e=e.type,a=!(e==="button"||e==="input"||e==="select"||e==="textarea")),e=!a;break e;default:e=!1}if(e)return null;if(l&&typeof l!="function")throw Error(r(231,t,typeof l));return l}var kt=!(typeof window>"u"||typeof window.document>"u"||typeof window.document.createElement>"u"),wi=!1;if(kt)try{var nn={};Object.defineProperty(nn,"passive",{get:function(){wi=!0}}),window.addEventListener("test",nn,nn),window.removeEventListener("test",nn,nn)}catch{wi=!1}var vl=null,qi=null,fu=null;function Of(){if(fu)return fu;var e,t=qi,l=t.length,a,n="value"in vl?vl.value:vl.textContent,u=n.length;for(e=0;e<l&&t[e]===n[e];e++);var c=l-e;for(a=1;a<=c&&t[l-a]===n[u-a];a++);return fu=n.slice(e,1<a?1-a:void 0)}function su(e){var t=e.keyCode;return"charCode"in e?(e=e.charCode,e===0&&t===13&&(e=13)):e=t,e===10&&(e=13),32<=e||e===13?e:0}function ou(){return!0}function Mf(){return!1}function it(e){function t(l,a,n,u,c){this._reactName=l,this._targetInst=n,this.type=a,this.nativeEvent=u,this.target=c,this.currentTarget=null;for(var o in e)e.hasOwnProperty(o)&&(l=e[o],this[o]=l?l(u):u[o]);return this.isDefaultPrevented=(u.defaultPrevented!=null?u.defaultPrevented:u.returnValue===!1)?ou:Mf,this.isPropagationStopped=Mf,this}return E(t.prototype,{preventDefault:function(){this.defaultPrevented=!0;var l=this.nativeEvent;l&&(l.preventDefault?l.preventDefault():typeof l.returnValue!="unknown"&&(l.returnValue=!1),this.isDefaultPrevented=ou)},stopPropagation:function(){var l=this.nativeEvent;l&&(l.stopPropagation?l.stopPropagation():typeof l.cancelBubble!="unknown"&&(l.cancelBubble=!0),this.isPropagationStopped=ou)},persist:function(){},isPersistent:ou}),t}var Ql={eventPhase:0,bubbles:0,cancelable:0,timeStamp:function(e){return e.timeStamp||Date.now()},defaultPrevented:0,isTrusted:0},du=it(Ql),un=E({},Ql,{view:0,detail:0}),ph=it(un),Yi,Gi,cn,mu=E({},un,{screenX:0,screenY:0,clientX:0,clientY:0,pageX:0,pageY:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,getModifierState:Qi,button:0,buttons:0,relatedTarget:function(e){return e.relatedTarget===void 0?e.fromElement===e.srcElement?e.toElement:e.fromElement:e.relatedTarget},movementX:function(e){return"movementX"in e?e.movementX:(e!==cn&&(cn&&e.type==="mousemove"?(Yi=e.screenX-cn.screenX,Gi=e.screenY-cn.screenY):Gi=Yi=0,cn=e),Yi)},movementY:function(e){return"movementY"in e?e.movementY:Gi}}),Df=it(mu),gh=E({},mu,{dataTransfer:0}),bh=it(gh),xh=E({},un,{relatedTarget:0}),Xi=it(xh),Sh=E({},Ql,{animationName:0,elapsedTime:0,pseudoElement:0}),Eh=it(Sh),Th=E({},Ql,{clipboardData:function(e){return"clipboardData"in e?e.clipboardData:window.clipboardData}}),Nh=it(Th),zh=E({},Ql,{data:0}),Uf=it(zh),jh={Esc:"Escape",Spacebar:" ",Left:"ArrowLeft",Up:"ArrowUp",Right:"ArrowRight",Down:"ArrowDown",Del:"Delete",Win:"OS",Menu:"ContextMenu",Apps:"ContextMenu",Scroll:"ScrollLock",MozPrintableKey:"Unidentified"},_h={8:"Backspace",9:"Tab",12:"Clear",13:"Enter",16:"Shift",17:"Control",18:"Alt",19:"Pause",20:"CapsLock",27:"Escape",32:" ",33:"PageUp",34:"PageDown",35:"End",36:"Home",37:"ArrowLeft",38:"ArrowUp",39:"ArrowRight",40:"ArrowDown",45:"Insert",46:"Delete",112:"F1",113:"F2",114:"F3",115:"F4",116:"F5",117:"F6",118:"F7",119:"F8",120:"F9",121:"F10",122:"F11",123:"F12",144:"NumLock",145:"ScrollLock",224:"Meta"},Ah={Alt:"altKey",Control:"ctrlKey",Meta:"metaKey",Shift:"shiftKey"};function Ch(e){var t=this.nativeEvent;return t.getModifierState?t.getModifierState(e):(e=Ah[e])?!!t[e]:!1}function Qi(){return Ch}var Rh=E({},un,{key:function(e){if(e.key){var t=jh[e.key]||e.key;if(t!=="Unidentified")return t}return e.type==="keypress"?(e=su(e),e===13?"Enter":String.fromCharCode(e)):e.type==="keydown"||e.type==="keyup"?_h[e.keyCode]||"Unidentified":""},code:0,location:0,ctrlKey:0,shiftKey:0,altKey:0,metaKey:0,repeat:0,locale:0,getModifierState:Qi,charCode:function(e){return e.type==="keypress"?su(e):0},keyCode:function(e){return e.type==="keydown"||e.type==="keyup"?e.keyCode:0},which:function(e){return e.type==="keypress"?su(e):e.type==="keydown"||e.type==="keyup"?e.keyCode:0}}),Oh=it(Rh),Mh=E({},mu,{pointerId:0,width:0,height:0,pressure:0,tangentialPressure:0,tiltX:0,tiltY:0,twist:0,pointerType:0,isPrimary:0}),Hf=it(Mh),Dh=E({},un,{touches:0,targetTouches:0,changedTouches:0,altKey:0,metaKey:0,ctrlKey:0,shiftKey:0,getModifierState:Qi}),Uh=it(Dh),Hh=E({},Ql,{propertyName:0,elapsedTime:0,pseudoElement:0}),Bh=it(Hh),Lh=E({},mu,{deltaX:function(e){return"deltaX"in e?e.deltaX:"wheelDeltaX"in e?-e.wheelDeltaX:0},deltaY:function(e){return"deltaY"in e?e.deltaY:"wheelDeltaY"in e?-e.wheelDeltaY:"wheelDelta"in e?-e.wheelDelta:0},deltaZ:0,deltaMode:0}),wh=it(Lh),qh=E({},Ql,{newState:0,oldState:0}),Yh=it(qh),Gh=[9,13,27,32],Zi=kt&&"CompositionEvent"in window,rn=null;kt&&"documentMode"in document&&(rn=document.documentMode);var Xh=kt&&"TextEvent"in window&&!rn,Bf=kt&&(!Zi||rn&&8<rn&&11>=rn),Lf=" ",wf=!1;function qf(e,t){switch(e){case"keyup":return Gh.indexOf(t.keyCode)!==-1;case"keydown":return t.keyCode!==229;case"keypress":case"mousedown":case"focusout":return!0;default:return!1}}function Yf(e){return e=e.detail,typeof e=="object"&&"data"in e?e.data:null}var va=!1;function Qh(e,t){switch(e){case"compositionend":return Yf(t);case"keypress":return t.which!==32?null:(wf=!0,Lf);case"textInput":return e=t.data,e===Lf&&wf?null:e;default:return null}}function Zh(e,t){if(va)return e==="compositionend"||!Zi&&qf(e,t)?(e=Of(),fu=qi=vl=null,va=!1,e):null;switch(e){case"paste":return null;case"keypress":if(!(t.ctrlKey||t.altKey||t.metaKey)||t.ctrlKey&&t.altKey){if(t.char&&1<t.char.length)return t.char;if(t.which)return String.fromCharCode(t.which)}return null;case"compositionend":return Bf&&t.locale!=="ko"?null:t.data;default:return null}}var Vh={color:!0,date:!0,datetime:!0,"datetime-local":!0,email:!0,month:!0,number:!0,password:!0,range:!0,search:!0,tel:!0,text:!0,time:!0,url:!0,week:!0};function Gf(e){var t=e&&e.nodeName&&e.nodeName.toLowerCase();return t==="input"?!!Vh[e.type]:t==="textarea"}function Xf(e,t,l,a){ma?ha?ha.push(a):ha=[a]:ma=a,t=li(t,"onChange"),0<t.length&&(l=new du("onChange","change",null,l,a),e.push({event:l,listeners:t}))}var fn=null,sn=null;function Kh(e){zd(e,0)}function hu(e){var t=ln(e);if(Tf(t))return e}function Qf(e,t){if(e==="change")return t}var Zf=!1;if(kt){var Vi;if(kt){var Ki="oninput"in document;if(!Ki){var Vf=document.createElement("div");Vf.setAttribute("oninput","return;"),Ki=typeof Vf.oninput=="function"}Vi=Ki}else Vi=!1;Zf=Vi&&(!document.documentMode||9<document.documentMode)}function Kf(){fn&&(fn.detachEvent("onpropertychange",Jf),sn=fn=null)}function Jf(e){if(e.propertyName==="value"&&hu(sn)){var t=[];Xf(t,sn,e,Bi(e)),Rf(Kh,t)}}function Jh(e,t,l){e==="focusin"?(Kf(),fn=t,sn=l,fn.attachEvent("onpropertychange",Jf)):e==="focusout"&&Kf()}function kh(e){if(e==="selectionchange"||e==="keyup"||e==="keydown")return hu(sn)}function $h(e,t){if(e==="click")return hu(t)}function Wh(e,t){if(e==="input"||e==="change")return hu(t)}function Fh(e,t){return e===t&&(e!==0||1/e===1/t)||e!==e&&t!==t}var ht=typeof Object.is=="function"?Object.is:Fh;function on(e,t){if(ht(e,t))return!0;if(typeof e!="object"||e===null||typeof t!="object"||t===null)return!1;var l=Object.keys(e),a=Object.keys(t);if(l.length!==a.length)return!1;for(a=0;a<l.length;a++){var n=l[a];if(!nt.call(t,n)||!ht(e[n],t[n]))return!1}return!0}function kf(e){for(;e&&e.firstChild;)e=e.firstChild;return e}function $f(e,t){var l=kf(e);e=0;for(var a;l;){if(l.nodeType===3){if(a=e+l.textContent.length,e<=t&&a>=t)return{node:l,offset:t-e};e=a}e:{for(;l;){if(l.nextSibling){l=l.nextSibling;break e}l=l.parentNode}l=void 0}l=kf(l)}}function Wf(e,t){return e&&t?e===t?!0:e&&e.nodeType===3?!1:t&&t.nodeType===3?Wf(e,t.parentNode):"contains"in e?e.contains(t):e.compareDocumentPosition?!!(e.compareDocumentPosition(t)&16):!1:!1}function Ff(e){e=e!=null&&e.ownerDocument!=null&&e.ownerDocument.defaultView!=null?e.ownerDocument.defaultView:window;for(var t=cu(e.document);t instanceof e.HTMLIFrameElement;){try{var l=typeof t.contentWindow.location.href=="string"}catch{l=!1}if(l)e=t.contentWindow;else break;t=cu(e.document)}return t}function Ji(e){var t=e&&e.nodeName&&e.nodeName.toLowerCase();return t&&(t==="input"&&(e.type==="text"||e.type==="search"||e.type==="tel"||e.type==="url"||e.type==="password")||t==="textarea"||e.contentEditable==="true")}var Ih=kt&&"documentMode"in document&&11>=document.documentMode,ya=null,ki=null,dn=null,$i=!1;function If(e,t,l){var a=l.window===l?l.document:l.nodeType===9?l:l.ownerDocument;$i||ya==null||ya!==cu(a)||(a=ya,"selectionStart"in a&&Ji(a)?a={start:a.selectionStart,end:a.selectionEnd}:(a=(a.ownerDocument&&a.ownerDocument.defaultView||window).getSelection(),a={anchorNode:a.anchorNode,anchorOffset:a.anchorOffset,focusNode:a.focusNode,focusOffset:a.focusOffset}),dn&&on(dn,a)||(dn=a,a=li(ki,"onSelect"),0<a.length&&(t=new du("onSelect","select",null,t,l),e.push({event:t,listeners:a}),t.target=ya)))}function Zl(e,t){var l={};return l[e.toLowerCase()]=t.toLowerCase(),l["Webkit"+e]="webkit"+t,l["Moz"+e]="moz"+t,l}var pa={animationend:Zl("Animation","AnimationEnd"),animationiteration:Zl("Animation","AnimationIteration"),animationstart:Zl("Animation","AnimationStart"),transitionrun:Zl("Transition","TransitionRun"),transitionstart:Zl("Transition","TransitionStart"),transitioncancel:Zl("Transition","TransitionCancel"),transitionend:Zl("Transition","TransitionEnd")},Wi={},Pf={};kt&&(Pf=document.createElement("div").style,"AnimationEvent"in window||(delete pa.animationend.animation,delete pa.animationiteration.animation,delete pa.animationstart.animation),"TransitionEvent"in window||delete pa.transitionend.transition);function Vl(e){if(Wi[e])return Wi[e];if(!pa[e])return e;var t=pa[e],l;for(l in t)if(t.hasOwnProperty(l)&&l in Pf)return Wi[e]=t[l];return e}var es=Vl("animationend"),ts=Vl("animationiteration"),ls=Vl("animationstart"),Ph=Vl("transitionrun"),ev=Vl("transitionstart"),tv=Vl("transitioncancel"),as=Vl("transitionend"),ns=new Map,Fi="abort auxClick beforeToggle cancel canPlay canPlayThrough click close contextMenu copy cut drag dragEnd dragEnter dragExit dragLeave dragOver dragStart drop durationChange emptied encrypted ended error gotPointerCapture input invalid keyDown keyPress keyUp load loadedData loadedMetadata loadStart lostPointerCapture mouseDown mouseMove mouseOut mouseOver mouseUp paste pause play playing pointerCancel pointerDown pointerMove pointerOut pointerOver pointerUp progress rateChange reset resize seeked seeking stalled submit suspend timeUpdate touchCancel touchEnd touchStart volumeChange scroll toggle touchMove waiting wheel".split(" ");Fi.push("scrollEnd");function Ut(e,t){ns.set(e,t),Xl(t,[e])}var vu=typeof reportError=="function"?reportError:function(e){if(typeof window=="object"&&typeof window.ErrorEvent=="function"){var t=new window.ErrorEvent("error",{bubbles:!0,cancelable:!0,message:typeof e=="object"&&e!==null&&typeof e.message=="string"?String(e.message):String(e),error:e});if(!window.dispatchEvent(t))return}else if(typeof process=="object"&&typeof process.emit=="function"){process.emit("uncaughtException",e);return}console.error(e)},Nt=[],ga=0,Ii=0;function yu(){for(var e=ga,t=Ii=ga=0;t<e;){var l=Nt[t];Nt[t++]=null;var a=Nt[t];Nt[t++]=null;var n=Nt[t];Nt[t++]=null;var u=Nt[t];if(Nt[t++]=null,a!==null&&n!==null){var c=a.pending;c===null?n.next=n:(n.next=c.next,c.next=n),a.pending=n}u!==0&&us(l,n,u)}}function pu(e,t,l,a){Nt[ga++]=e,Nt[ga++]=t,Nt[ga++]=l,Nt[ga++]=a,Ii|=a,e.lanes|=a,e=e.alternate,e!==null&&(e.lanes|=a)}function Pi(e,t,l,a){return pu(e,t,l,a),gu(e)}function Kl(e,t){return pu(e,null,null,t),gu(e)}function us(e,t,l){e.lanes|=l;var a=e.alternate;a!==null&&(a.lanes|=l);for(var n=!1,u=e.return;u!==null;)u.childLanes|=l,a=u.alternate,a!==null&&(a.childLanes|=l),u.tag===22&&(e=u.stateNode,e===null||e._visibility&1||(n=!0)),e=u,u=u.return;return e.tag===3?(u=e.stateNode,n&&t!==null&&(n=31-mt(l),e=u.hiddenUpdates,a=e[n],a===null?e[n]=[t]:a.push(t),t.lane=l|536870912),u):null}function gu(e){if(50<Un)throw Un=0,rr=null,Error(r(185));for(var t=e.return;t!==null;)e=t,t=e.return;return e.tag===3?e.stateNode:null}var ba={};function lv(e,t,l,a){this.tag=e,this.key=l,this.sibling=this.child=this.return=this.stateNode=this.type=this.elementType=null,this.index=0,this.refCleanup=this.ref=null,this.pendingProps=t,this.dependencies=this.memoizedState=this.updateQueue=this.memoizedProps=null,this.mode=a,this.subtreeFlags=this.flags=0,this.deletions=null,this.childLanes=this.lanes=0,this.alternate=null}function vt(e,t,l,a){return new lv(e,t,l,a)}function ec(e){return e=e.prototype,!(!e||!e.isReactComponent)}function $t(e,t){var l=e.alternate;return l===null?(l=vt(e.tag,t,e.key,e.mode),l.elementType=e.elementType,l.type=e.type,l.stateNode=e.stateNode,l.alternate=e,e.alternate=l):(l.pendingProps=t,l.type=e.type,l.flags=0,l.subtreeFlags=0,l.deletions=null),l.flags=e.flags&65011712,l.childLanes=e.childLanes,l.lanes=e.lanes,l.child=e.child,l.memoizedProps=e.memoizedProps,l.memoizedState=e.memoizedState,l.updateQueue=e.updateQueue,t=e.dependencies,l.dependencies=t===null?null:{lanes:t.lanes,firstContext:t.firstContext},l.sibling=e.sibling,l.index=e.index,l.ref=e.ref,l.refCleanup=e.refCleanup,l}function is(e,t){e.flags&=65011714;var l=e.alternate;return l===null?(e.childLanes=0,e.lanes=t,e.child=null,e.subtreeFlags=0,e.memoizedProps=null,e.memoizedState=null,e.updateQueue=null,e.dependencies=null,e.stateNode=null):(e.childLanes=l.childLanes,e.lanes=l.lanes,e.child=l.child,e.subtreeFlags=0,e.deletions=null,e.memoizedProps=l.memoizedProps,e.memoizedState=l.memoizedState,e.updateQueue=l.updateQueue,e.type=l.type,t=l.dependencies,e.dependencies=t===null?null:{lanes:t.lanes,firstContext:t.firstContext}),e}function bu(e,t,l,a,n,u){var c=0;if(a=e,typeof e=="function")ec(e)&&(c=1);else if(typeof e=="string")c=cy(e,l,Z.current)?26:e==="html"||e==="head"||e==="body"?27:5;else e:switch(e){case He:return e=vt(31,l,t,n),e.elementType=He,e.lanes=u,e;case R:return Jl(l.children,n,u,t);case B:c=8,n|=24;break;case w:return e=vt(12,l,t,n|2),e.elementType=w,e.lanes=u,e;case le:return e=vt(13,l,t,n),e.elementType=le,e.lanes=u,e;case re:return e=vt(19,l,t,n),e.elementType=re,e.lanes=u,e;default:if(typeof e=="object"&&e!==null)switch(e.$$typeof){case K:c=10;break e;case k:c=9;break e;case ce:c=11;break e;case $:c=14;break e;case _e:c=16,a=null;break e}c=29,l=Error(r(130,e===null?"null":typeof e,"")),a=null}return t=vt(c,l,t,n),t.elementType=e,t.type=a,t.lanes=u,t}function Jl(e,t,l,a){return e=vt(7,e,a,t),e.lanes=l,e}function tc(e,t,l){return e=vt(6,e,null,t),e.lanes=l,e}function cs(e){var t=vt(18,null,null,0);return t.stateNode=e,t}function lc(e,t,l){return t=vt(4,e.children!==null?e.children:[],e.key,t),t.lanes=l,t.stateNode={containerInfo:e.containerInfo,pendingChildren:null,implementation:e.implementation},t}var rs=new WeakMap;function zt(e,t){if(typeof e=="object"&&e!==null){var l=rs.get(e);return l!==void 0?l:(t={value:e,source:t,stack:ve(t)},rs.set(e,t),t)}return{value:e,source:t,stack:ve(t)}}var xa=[],Sa=0,xu=null,mn=0,jt=[],_t=0,yl=null,Gt=1,Xt="";function Wt(e,t){xa[Sa++]=mn,xa[Sa++]=xu,xu=e,mn=t}function fs(e,t,l){jt[_t++]=Gt,jt[_t++]=Xt,jt[_t++]=yl,yl=e;var a=Gt;e=Xt;var n=32-mt(a)-1;a&=~(1<<n),l+=1;var u=32-mt(t)+n;if(30<u){var c=n-n%5;u=(a&(1<<c)-1).toString(32),a>>=c,n-=c,Gt=1<<32-mt(t)+n|l<<n|a,Xt=u+e}else Gt=1<<u|l<<n|a,Xt=e}function ac(e){e.return!==null&&(Wt(e,1),fs(e,1,0))}function nc(e){for(;e===xu;)xu=xa[--Sa],xa[Sa]=null,mn=xa[--Sa],xa[Sa]=null;for(;e===yl;)yl=jt[--_t],jt[_t]=null,Xt=jt[--_t],jt[_t]=null,Gt=jt[--_t],jt[_t]=null}function ss(e,t){jt[_t++]=Gt,jt[_t++]=Xt,jt[_t++]=yl,Gt=t.id,Xt=t.overflow,yl=e}var Fe=null,Re=null,he=!1,pl=null,At=!1,uc=Error(r(519));function gl(e){var t=Error(r(418,1<arguments.length&&arguments[1]!==void 0&&arguments[1]?"text":"HTML",""));throw hn(zt(t,e)),uc}function os(e){var t=e.stateNode,l=e.type,a=e.memoizedProps;switch(t[We]=e,t[ut]=a,l){case"dialog":oe("cancel",t),oe("close",t);break;case"iframe":case"object":case"embed":oe("load",t);break;case"video":case"audio":for(l=0;l<Bn.length;l++)oe(Bn[l],t);break;case"source":oe("error",t);break;case"img":case"image":case"link":oe("error",t),oe("load",t);break;case"details":oe("toggle",t);break;case"input":oe("invalid",t),Nf(t,a.value,a.defaultValue,a.checked,a.defaultChecked,a.type,a.name,!0);break;case"select":oe("invalid",t);break;case"textarea":oe("invalid",t),jf(t,a.value,a.defaultValue,a.children)}l=a.children,typeof l!="string"&&typeof l!="number"&&typeof l!="bigint"||t.textContent===""+l||a.suppressHydrationWarning===!0||Cd(t.textContent,l)?(a.popover!=null&&(oe("beforetoggle",t),oe("toggle",t)),a.onScroll!=null&&oe("scroll",t),a.onScrollEnd!=null&&oe("scrollend",t),a.onClick!=null&&(t.onclick=Jt),t=!0):t=!1,t||gl(e,!0)}function ds(e){for(Fe=e.return;Fe;)switch(Fe.tag){case 5:case 31:case 13:At=!1;return;case 27:case 3:At=!0;return;default:Fe=Fe.return}}function Ea(e){if(e!==Fe)return!1;if(!he)return ds(e),he=!0,!1;var t=e.tag,l;if((l=t!==3&&t!==27)&&((l=t===5)&&(l=e.type,l=!(l!=="form"&&l!=="button")||Tr(e.type,e.memoizedProps)),l=!l),l&&Re&&gl(e),ds(e),t===13){if(e=e.memoizedState,e=e!==null?e.dehydrated:null,!e)throw Error(r(317));Re=wd(e)}else if(t===31){if(e=e.memoizedState,e=e!==null?e.dehydrated:null,!e)throw Error(r(317));Re=wd(e)}else t===27?(t=Re,Ml(e.type)?(e=Ar,Ar=null,Re=e):Re=t):Re=Fe?Rt(e.stateNode.nextSibling):null;return!0}function kl(){Re=Fe=null,he=!1}function ic(){var e=pl;return e!==null&&(st===null?st=e:st.push.apply(st,e),pl=null),e}function hn(e){pl===null?pl=[e]:pl.push(e)}var cc=b(null),$l=null,Ft=null;function bl(e,t,l){Y(cc,t._currentValue),t._currentValue=l}function It(e){e._currentValue=cc.current,U(cc)}function rc(e,t,l){for(;e!==null;){var a=e.alternate;if((e.childLanes&t)!==t?(e.childLanes|=t,a!==null&&(a.childLanes|=t)):a!==null&&(a.childLanes&t)!==t&&(a.childLanes|=t),e===l)break;e=e.return}}function fc(e,t,l,a){var n=e.child;for(n!==null&&(n.return=e);n!==null;){var u=n.dependencies;if(u!==null){var c=n.child;u=u.firstContext;e:for(;u!==null;){var o=u;u=n;for(var v=0;v<t.length;v++)if(o.context===t[v]){u.lanes|=l,o=u.alternate,o!==null&&(o.lanes|=l),rc(u.return,l,e),a||(c=null);break e}u=o.next}}else if(n.tag===18){if(c=n.return,c===null)throw Error(r(341));c.lanes|=l,u=c.alternate,u!==null&&(u.lanes|=l),rc(c,l,e),c=null}else c=n.child;if(c!==null)c.return=n;else for(c=n;c!==null;){if(c===e){c=null;break}if(n=c.sibling,n!==null){n.return=c.return,c=n;break}c=c.return}n=c}}function Ta(e,t,l,a){e=null;for(var n=t,u=!1;n!==null;){if(!u){if((n.flags&524288)!==0)u=!0;else if((n.flags&262144)!==0)break}if(n.tag===10){var c=n.alternate;if(c===null)throw Error(r(387));if(c=c.memoizedProps,c!==null){var o=n.type;ht(n.pendingProps.value,c.value)||(e!==null?e.push(o):e=[o])}}else if(n===ne.current){if(c=n.alternate,c===null)throw Error(r(387));c.memoizedState.memoizedState!==n.memoizedState.memoizedState&&(e!==null?e.push(Gn):e=[Gn])}n=n.return}e!==null&&fc(t,e,l,a),t.flags|=262144}function Su(e){for(e=e.firstContext;e!==null;){if(!ht(e.context._currentValue,e.memoizedValue))return!0;e=e.next}return!1}function Wl(e){$l=e,Ft=null,e=e.dependencies,e!==null&&(e.firstContext=null)}function Ie(e){return ms($l,e)}function Eu(e,t){return $l===null&&Wl(e),ms(e,t)}function ms(e,t){var l=t._currentValue;if(t={context:t,memoizedValue:l,next:null},Ft===null){if(e===null)throw Error(r(308));Ft=t,e.dependencies={lanes:0,firstContext:t},e.flags|=524288}else Ft=Ft.next=t;return l}var av=typeof AbortController<"u"?AbortController:function(){var e=[],t=this.signal={aborted:!1,addEventListener:function(l,a){e.push(a)}};this.abort=function(){t.aborted=!0,e.forEach(function(l){return l()})}},nv=i.unstable_scheduleCallback,uv=i.unstable_NormalPriority,Ge={$$typeof:K,Consumer:null,Provider:null,_currentValue:null,_currentValue2:null,_threadCount:0};function sc(){return{controller:new av,data:new Map,refCount:0}}function vn(e){e.refCount--,e.refCount===0&&nv(uv,function(){e.controller.abort()})}var yn=null,oc=0,Na=0,za=null;function iv(e,t){if(yn===null){var l=yn=[];oc=0,Na=hr(),za={status:"pending",value:void 0,then:function(a){l.push(a)}}}return oc++,t.then(hs,hs),t}function hs(){if(--oc===0&&yn!==null){za!==null&&(za.status="fulfilled");var e=yn;yn=null,Na=0,za=null;for(var t=0;t<e.length;t++)(0,e[t])()}}function cv(e,t){var l=[],a={status:"pending",value:null,reason:null,then:function(n){l.push(n)}};return e.then(function(){a.status="fulfilled",a.value=t;for(var n=0;n<l.length;n++)(0,l[n])(t)},function(n){for(a.status="rejected",a.reason=n,n=0;n<l.length;n++)(0,l[n])(void 0)}),a}var vs=O.S;O.S=function(e,t){Po=be(),typeof t=="object"&&t!==null&&typeof t.then=="function"&&iv(e,t),vs!==null&&vs(e,t)};var Fl=b(null);function dc(){var e=Fl.current;return e!==null?e:Ae.pooledCache}function Tu(e,t){t===null?Y(Fl,Fl.current):Y(Fl,t.pool)}function ys(){var e=dc();return e===null?null:{parent:Ge._currentValue,pool:e}}var ja=Error(r(460)),mc=Error(r(474)),Nu=Error(r(542)),zu={then:function(){}};function ps(e){return e=e.status,e==="fulfilled"||e==="rejected"}function gs(e,t,l){switch(l=e[l],l===void 0?e.push(t):l!==t&&(t.then(Jt,Jt),t=l),t.status){case"fulfilled":return t.value;case"rejected":throw e=t.reason,xs(e),e;default:if(typeof t.status=="string")t.then(Jt,Jt);else{if(e=Ae,e!==null&&100<e.shellSuspendCounter)throw Error(r(482));e=t,e.status="pending",e.then(function(a){if(t.status==="pending"){var n=t;n.status="fulfilled",n.value=a}},function(a){if(t.status==="pending"){var n=t;n.status="rejected",n.reason=a}})}switch(t.status){case"fulfilled":return t.value;case"rejected":throw e=t.reason,xs(e),e}throw Pl=t,ja}}function Il(e){try{var t=e._init;return t(e._payload)}catch(l){throw l!==null&&typeof l=="object"&&typeof l.then=="function"?(Pl=l,ja):l}}var Pl=null;function bs(){if(Pl===null)throw Error(r(459));var e=Pl;return Pl=null,e}function xs(e){if(e===ja||e===Nu)throw Error(r(483))}var _a=null,pn=0;function ju(e){var t=pn;return pn+=1,_a===null&&(_a=[]),gs(_a,e,t)}function gn(e,t){t=t.props.ref,e.ref=t!==void 0?t:null}function _u(e,t){throw t.$$typeof===L?Error(r(525)):(e=Object.prototype.toString.call(t),Error(r(31,e==="[object Object]"?"object with keys {"+Object.keys(t).join(", ")+"}":e)))}function Ss(e){function t(T,p){if(e){var z=T.deletions;z===null?(T.deletions=[p],T.flags|=16):z.push(p)}}function l(T,p){if(!e)return null;for(;p!==null;)t(T,p),p=p.sibling;return null}function a(T){for(var p=new Map;T!==null;)T.key!==null?p.set(T.key,T):p.set(T.index,T),T=T.sibling;return p}function n(T,p){return T=$t(T,p),T.index=0,T.sibling=null,T}function u(T,p,z){return T.index=z,e?(z=T.alternate,z!==null?(z=z.index,z<p?(T.flags|=67108866,p):z):(T.flags|=67108866,p)):(T.flags|=1048576,p)}function c(T){return e&&T.alternate===null&&(T.flags|=67108866),T}function o(T,p,z,D){return p===null||p.tag!==6?(p=tc(z,T.mode,D),p.return=T,p):(p=n(p,z),p.return=T,p)}function v(T,p,z,D){var W=z.type;return W===R?M(T,p,z.props.children,D,z.key):p!==null&&(p.elementType===W||typeof W=="object"&&W!==null&&W.$$typeof===_e&&Il(W)===p.type)?(p=n(p,z.props),gn(p,z),p.return=T,p):(p=bu(z.type,z.key,z.props,null,T.mode,D),gn(p,z),p.return=T,p)}function j(T,p,z,D){return p===null||p.tag!==4||p.stateNode.containerInfo!==z.containerInfo||p.stateNode.implementation!==z.implementation?(p=lc(z,T.mode,D),p.return=T,p):(p=n(p,z.children||[]),p.return=T,p)}function M(T,p,z,D,W){return p===null||p.tag!==7?(p=Jl(z,T.mode,D,W),p.return=T,p):(p=n(p,z),p.return=T,p)}function H(T,p,z){if(typeof p=="string"&&p!==""||typeof p=="number"||typeof p=="bigint")return p=tc(""+p,T.mode,z),p.return=T,p;if(typeof p=="object"&&p!==null){switch(p.$$typeof){case X:return z=bu(p.type,p.key,p.props,null,T.mode,z),gn(z,p),z.return=T,z;case Q:return p=lc(p,T.mode,z),p.return=T,p;case _e:return p=Il(p),H(T,p,z)}if(fe(p)||Ce(p))return p=Jl(p,T.mode,z,null),p.return=T,p;if(typeof p.then=="function")return H(T,ju(p),z);if(p.$$typeof===K)return H(T,Eu(T,p),z);_u(T,p)}return null}function _(T,p,z,D){var W=p!==null?p.key:null;if(typeof z=="string"&&z!==""||typeof z=="number"||typeof z=="bigint")return W!==null?null:o(T,p,""+z,D);if(typeof z=="object"&&z!==null){switch(z.$$typeof){case X:return z.key===W?v(T,p,z,D):null;case Q:return z.key===W?j(T,p,z,D):null;case _e:return z=Il(z),_(T,p,z,D)}if(fe(z)||Ce(z))return W!==null?null:M(T,p,z,D,null);if(typeof z.then=="function")return _(T,p,ju(z),D);if(z.$$typeof===K)return _(T,p,Eu(T,z),D);_u(T,z)}return null}function C(T,p,z,D,W){if(typeof D=="string"&&D!==""||typeof D=="number"||typeof D=="bigint")return T=T.get(z)||null,o(p,T,""+D,W);if(typeof D=="object"&&D!==null){switch(D.$$typeof){case X:return T=T.get(D.key===null?z:D.key)||null,v(p,T,D,W);case Q:return T=T.get(D.key===null?z:D.key)||null,j(p,T,D,W);case _e:return D=Il(D),C(T,p,z,D,W)}if(fe(D)||Ce(D))return T=T.get(z)||null,M(p,T,D,W,null);if(typeof D.then=="function")return C(T,p,z,ju(D),W);if(D.$$typeof===K)return C(T,p,z,Eu(p,D),W);_u(p,D)}return null}function V(T,p,z,D){for(var W=null,ye=null,J=p,ie=p=0,me=null;J!==null&&ie<z.length;ie++){J.index>ie?(me=J,J=null):me=J.sibling;var pe=_(T,J,z[ie],D);if(pe===null){J===null&&(J=me);break}e&&J&&pe.alternate===null&&t(T,J),p=u(pe,p,ie),ye===null?W=pe:ye.sibling=pe,ye=pe,J=me}if(ie===z.length)return l(T,J),he&&Wt(T,ie),W;if(J===null){for(;ie<z.length;ie++)J=H(T,z[ie],D),J!==null&&(p=u(J,p,ie),ye===null?W=J:ye.sibling=J,ye=J);return he&&Wt(T,ie),W}for(J=a(J);ie<z.length;ie++)me=C(J,T,ie,z[ie],D),me!==null&&(e&&me.alternate!==null&&J.delete(me.key===null?ie:me.key),p=u(me,p,ie),ye===null?W=me:ye.sibling=me,ye=me);return e&&J.forEach(function(Ll){return t(T,Ll)}),he&&Wt(T,ie),W}function P(T,p,z,D){if(z==null)throw Error(r(151));for(var W=null,ye=null,J=p,ie=p=0,me=null,pe=z.next();J!==null&&!pe.done;ie++,pe=z.next()){J.index>ie?(me=J,J=null):me=J.sibling;var Ll=_(T,J,pe.value,D);if(Ll===null){J===null&&(J=me);break}e&&J&&Ll.alternate===null&&t(T,J),p=u(Ll,p,ie),ye===null?W=Ll:ye.sibling=Ll,ye=Ll,J=me}if(pe.done)return l(T,J),he&&Wt(T,ie),W;if(J===null){for(;!pe.done;ie++,pe=z.next())pe=H(T,pe.value,D),pe!==null&&(p=u(pe,p,ie),ye===null?W=pe:ye.sibling=pe,ye=pe);return he&&Wt(T,ie),W}for(J=a(J);!pe.done;ie++,pe=z.next())pe=C(J,T,ie,pe.value,D),pe!==null&&(e&&pe.alternate!==null&&J.delete(pe.key===null?ie:pe.key),p=u(pe,p,ie),ye===null?W=pe:ye.sibling=pe,ye=pe);return e&&J.forEach(function(gy){return t(T,gy)}),he&&Wt(T,ie),W}function je(T,p,z,D){if(typeof z=="object"&&z!==null&&z.type===R&&z.key===null&&(z=z.props.children),typeof z=="object"&&z!==null){switch(z.$$typeof){case X:e:{for(var W=z.key;p!==null;){if(p.key===W){if(W=z.type,W===R){if(p.tag===7){l(T,p.sibling),D=n(p,z.props.children),D.return=T,T=D;break e}}else if(p.elementType===W||typeof W=="object"&&W!==null&&W.$$typeof===_e&&Il(W)===p.type){l(T,p.sibling),D=n(p,z.props),gn(D,z),D.return=T,T=D;break e}l(T,p);break}else t(T,p);p=p.sibling}z.type===R?(D=Jl(z.props.children,T.mode,D,z.key),D.return=T,T=D):(D=bu(z.type,z.key,z.props,null,T.mode,D),gn(D,z),D.return=T,T=D)}return c(T);case Q:e:{for(W=z.key;p!==null;){if(p.key===W)if(p.tag===4&&p.stateNode.containerInfo===z.containerInfo&&p.stateNode.implementation===z.implementation){l(T,p.sibling),D=n(p,z.children||[]),D.return=T,T=D;break e}else{l(T,p);break}else t(T,p);p=p.sibling}D=lc(z,T.mode,D),D.return=T,T=D}return c(T);case _e:return z=Il(z),je(T,p,z,D)}if(fe(z))return V(T,p,z,D);if(Ce(z)){if(W=Ce(z),typeof W!="function")throw Error(r(150));return z=W.call(z),P(T,p,z,D)}if(typeof z.then=="function")return je(T,p,ju(z),D);if(z.$$typeof===K)return je(T,p,Eu(T,z),D);_u(T,z)}return typeof z=="string"&&z!==""||typeof z=="number"||typeof z=="bigint"?(z=""+z,p!==null&&p.tag===6?(l(T,p.sibling),D=n(p,z),D.return=T,T=D):(l(T,p),D=tc(z,T.mode,D),D.return=T,T=D),c(T)):l(T,p)}return function(T,p,z,D){try{pn=0;var W=je(T,p,z,D);return _a=null,W}catch(J){if(J===ja||J===Nu)throw J;var ye=vt(29,J,null,T.mode);return ye.lanes=D,ye.return=T,ye}finally{}}}var ea=Ss(!0),Es=Ss(!1),xl=!1;function hc(e){e.updateQueue={baseState:e.memoizedState,firstBaseUpdate:null,lastBaseUpdate:null,shared:{pending:null,lanes:0,hiddenCallbacks:null},callbacks:null}}function vc(e,t){e=e.updateQueue,t.updateQueue===e&&(t.updateQueue={baseState:e.baseState,firstBaseUpdate:e.firstBaseUpdate,lastBaseUpdate:e.lastBaseUpdate,shared:e.shared,callbacks:null})}function Sl(e){return{lane:e,tag:0,payload:null,callback:null,next:null}}function El(e,t,l){var a=e.updateQueue;if(a===null)return null;if(a=a.shared,(xe&2)!==0){var n=a.pending;return n===null?t.next=t:(t.next=n.next,n.next=t),a.pending=t,t=gu(e),us(e,null,l),t}return pu(e,a,t,l),gu(e)}function bn(e,t,l){if(t=t.updateQueue,t!==null&&(t=t.shared,(l&4194048)!==0)){var a=t.lanes;a&=e.pendingLanes,l|=a,t.lanes=l,mf(e,l)}}function yc(e,t){var l=e.updateQueue,a=e.alternate;if(a!==null&&(a=a.updateQueue,l===a)){var n=null,u=null;if(l=l.firstBaseUpdate,l!==null){do{var c={lane:l.lane,tag:l.tag,payload:l.payload,callback:null,next:null};u===null?n=u=c:u=u.next=c,l=l.next}while(l!==null);u===null?n=u=t:u=u.next=t}else n=u=t;l={baseState:a.baseState,firstBaseUpdate:n,lastBaseUpdate:u,shared:a.shared,callbacks:a.callbacks},e.updateQueue=l;return}e=l.lastBaseUpdate,e===null?l.firstBaseUpdate=t:e.next=t,l.lastBaseUpdate=t}var pc=!1;function xn(){if(pc){var e=za;if(e!==null)throw e}}function Sn(e,t,l,a){pc=!1;var n=e.updateQueue;xl=!1;var u=n.firstBaseUpdate,c=n.lastBaseUpdate,o=n.shared.pending;if(o!==null){n.shared.pending=null;var v=o,j=v.next;v.next=null,c===null?u=j:c.next=j,c=v;var M=e.alternate;M!==null&&(M=M.updateQueue,o=M.lastBaseUpdate,o!==c&&(o===null?M.firstBaseUpdate=j:o.next=j,M.lastBaseUpdate=v))}if(u!==null){var H=n.baseState;c=0,M=j=v=null,o=u;do{var _=o.lane&-536870913,C=_!==o.lane;if(C?(de&_)===_:(a&_)===_){_!==0&&_===Na&&(pc=!0),M!==null&&(M=M.next={lane:0,tag:o.tag,payload:o.payload,callback:null,next:null});e:{var V=e,P=o;_=t;var je=l;switch(P.tag){case 1:if(V=P.payload,typeof V=="function"){H=V.call(je,H,_);break e}H=V;break e;case 3:V.flags=V.flags&-65537|128;case 0:if(V=P.payload,_=typeof V=="function"?V.call(je,H,_):V,_==null)break e;H=E({},H,_);break e;case 2:xl=!0}}_=o.callback,_!==null&&(e.flags|=64,C&&(e.flags|=8192),C=n.callbacks,C===null?n.callbacks=[_]:C.push(_))}else C={lane:_,tag:o.tag,payload:o.payload,callback:o.callback,next:null},M===null?(j=M=C,v=H):M=M.next=C,c|=_;if(o=o.next,o===null){if(o=n.shared.pending,o===null)break;C=o,o=C.next,C.next=null,n.lastBaseUpdate=C,n.shared.pending=null}}while(!0);M===null&&(v=H),n.baseState=v,n.firstBaseUpdate=j,n.lastBaseUpdate=M,u===null&&(n.shared.lanes=0),_l|=c,e.lanes=c,e.memoizedState=H}}function Ts(e,t){if(typeof e!="function")throw Error(r(191,e));e.call(t)}function Ns(e,t){var l=e.callbacks;if(l!==null)for(e.callbacks=null,e=0;e<l.length;e++)Ts(l[e],t)}var Aa=b(null),Au=b(0);function zs(e,t){e=cl,Y(Au,e),Y(Aa,t),cl=e|t.baseLanes}function gc(){Y(Au,cl),Y(Aa,Aa.current)}function bc(){cl=Au.current,U(Aa),U(Au)}var yt=b(null),Ct=null;function Tl(e){var t=e.alternate;Y(qe,qe.current&1),Y(yt,e),Ct===null&&(t===null||Aa.current!==null||t.memoizedState!==null)&&(Ct=e)}function xc(e){Y(qe,qe.current),Y(yt,e),Ct===null&&(Ct=e)}function js(e){e.tag===22?(Y(qe,qe.current),Y(yt,e),Ct===null&&(Ct=e)):Nl()}function Nl(){Y(qe,qe.current),Y(yt,yt.current)}function pt(e){U(yt),Ct===e&&(Ct=null),U(qe)}var qe=b(0);function Cu(e){for(var t=e;t!==null;){if(t.tag===13){var l=t.memoizedState;if(l!==null&&(l=l.dehydrated,l===null||jr(l)||_r(l)))return t}else if(t.tag===19&&(t.memoizedProps.revealOrder==="forwards"||t.memoizedProps.revealOrder==="backwards"||t.memoizedProps.revealOrder==="unstable_legacy-backwards"||t.memoizedProps.revealOrder==="together")){if((t.flags&128)!==0)return t}else if(t.child!==null){t.child.return=t,t=t.child;continue}if(t===e)break;for(;t.sibling===null;){if(t.return===null||t.return===e)return null;t=t.return}t.sibling.return=t.return,t=t.sibling}return null}var Pt=0,ue=null,Ne=null,Xe=null,Ru=!1,Ca=!1,ta=!1,Ou=0,En=0,Ra=null,rv=0;function Le(){throw Error(r(321))}function Sc(e,t){if(t===null)return!1;for(var l=0;l<t.length&&l<e.length;l++)if(!ht(e[l],t[l]))return!1;return!0}function Ec(e,t,l,a,n,u){return Pt=u,ue=t,t.memoizedState=null,t.updateQueue=null,t.lanes=0,O.H=e===null||e.memoizedState===null?fo:Lc,ta=!1,u=l(a,n),ta=!1,Ca&&(u=As(t,l,a,n)),_s(e),u}function _s(e){O.H=zn;var t=Ne!==null&&Ne.next!==null;if(Pt=0,Xe=Ne=ue=null,Ru=!1,En=0,Ra=null,t)throw Error(r(300));e===null||Qe||(e=e.dependencies,e!==null&&Su(e)&&(Qe=!0))}function As(e,t,l,a){ue=e;var n=0;do{if(Ca&&(Ra=null),En=0,Ca=!1,25<=n)throw Error(r(301));if(n+=1,Xe=Ne=null,e.updateQueue!=null){var u=e.updateQueue;u.lastEffect=null,u.events=null,u.stores=null,u.memoCache!=null&&(u.memoCache.index=0)}O.H=so,u=t(l,a)}while(Ca);return u}function fv(){var e=O.H,t=e.useState()[0];return t=typeof t.then=="function"?Tn(t):t,e=e.useState()[0],(Ne!==null?Ne.memoizedState:null)!==e&&(ue.flags|=1024),t}function Tc(){var e=Ou!==0;return Ou=0,e}function Nc(e,t,l){t.updateQueue=e.updateQueue,t.flags&=-2053,e.lanes&=~l}function zc(e){if(Ru){for(e=e.memoizedState;e!==null;){var t=e.queue;t!==null&&(t.pending=null),e=e.next}Ru=!1}Pt=0,Xe=Ne=ue=null,Ca=!1,En=Ou=0,Ra=null}function lt(){var e={memoizedState:null,baseState:null,baseQueue:null,queue:null,next:null};return Xe===null?ue.memoizedState=Xe=e:Xe=Xe.next=e,Xe}function Ye(){if(Ne===null){var e=ue.alternate;e=e!==null?e.memoizedState:null}else e=Ne.next;var t=Xe===null?ue.memoizedState:Xe.next;if(t!==null)Xe=t,Ne=e;else{if(e===null)throw ue.alternate===null?Error(r(467)):Error(r(310));Ne=e,e={memoizedState:Ne.memoizedState,baseState:Ne.baseState,baseQueue:Ne.baseQueue,queue:Ne.queue,next:null},Xe===null?ue.memoizedState=Xe=e:Xe=Xe.next=e}return Xe}function Mu(){return{lastEffect:null,events:null,stores:null,memoCache:null}}function Tn(e){var t=En;return En+=1,Ra===null&&(Ra=[]),e=gs(Ra,e,t),t=ue,(Xe===null?t.memoizedState:Xe.next)===null&&(t=t.alternate,O.H=t===null||t.memoizedState===null?fo:Lc),e}function Du(e){if(e!==null&&typeof e=="object"){if(typeof e.then=="function")return Tn(e);if(e.$$typeof===K)return Ie(e)}throw Error(r(438,String(e)))}function jc(e){var t=null,l=ue.updateQueue;if(l!==null&&(t=l.memoCache),t==null){var a=ue.alternate;a!==null&&(a=a.updateQueue,a!==null&&(a=a.memoCache,a!=null&&(t={data:a.data.map(function(n){return n.slice()}),index:0})))}if(t==null&&(t={data:[],index:0}),l===null&&(l=Mu(),ue.updateQueue=l),l.memoCache=t,l=t.data[t.index],l===void 0)for(l=t.data[t.index]=Array(e),a=0;a<e;a++)l[a]=at;return t.index++,l}function el(e,t){return typeof t=="function"?t(e):t}function Uu(e){var t=Ye();return _c(t,Ne,e)}function _c(e,t,l){var a=e.queue;if(a===null)throw Error(r(311));a.lastRenderedReducer=l;var n=e.baseQueue,u=a.pending;if(u!==null){if(n!==null){var c=n.next;n.next=u.next,u.next=c}t.baseQueue=n=u,a.pending=null}if(u=e.baseState,n===null)e.memoizedState=u;else{t=n.next;var o=c=null,v=null,j=t,M=!1;do{var H=j.lane&-536870913;if(H!==j.lane?(de&H)===H:(Pt&H)===H){var _=j.revertLane;if(_===0)v!==null&&(v=v.next={lane:0,revertLane:0,gesture:null,action:j.action,hasEagerState:j.hasEagerState,eagerState:j.eagerState,next:null}),H===Na&&(M=!0);else if((Pt&_)===_){j=j.next,_===Na&&(M=!0);continue}else H={lane:0,revertLane:j.revertLane,gesture:null,action:j.action,hasEagerState:j.hasEagerState,eagerState:j.eagerState,next:null},v===null?(o=v=H,c=u):v=v.next=H,ue.lanes|=_,_l|=_;H=j.action,ta&&l(u,H),u=j.hasEagerState?j.eagerState:l(u,H)}else _={lane:H,revertLane:j.revertLane,gesture:j.gesture,action:j.action,hasEagerState:j.hasEagerState,eagerState:j.eagerState,next:null},v===null?(o=v=_,c=u):v=v.next=_,ue.lanes|=H,_l|=H;j=j.next}while(j!==null&&j!==t);if(v===null?c=u:v.next=o,!ht(u,e.memoizedState)&&(Qe=!0,M&&(l=za,l!==null)))throw l;e.memoizedState=u,e.baseState=c,e.baseQueue=v,a.lastRenderedState=u}return n===null&&(a.lanes=0),[e.memoizedState,a.dispatch]}function Ac(e){var t=Ye(),l=t.queue;if(l===null)throw Error(r(311));l.lastRenderedReducer=e;var a=l.dispatch,n=l.pending,u=t.memoizedState;if(n!==null){l.pending=null;var c=n=n.next;do u=e(u,c.action),c=c.next;while(c!==n);ht(u,t.memoizedState)||(Qe=!0),t.memoizedState=u,t.baseQueue===null&&(t.baseState=u),l.lastRenderedState=u}return[u,a]}function Cs(e,t,l){var a=ue,n=Ye(),u=he;if(u){if(l===void 0)throw Error(r(407));l=l()}else l=t();var c=!ht((Ne||n).memoizedState,l);if(c&&(n.memoizedState=l,Qe=!0),n=n.queue,Oc(Ms.bind(null,a,n,e),[e]),n.getSnapshot!==t||c||Xe!==null&&Xe.memoizedState.tag&1){if(a.flags|=2048,Oa(9,{destroy:void 0},Os.bind(null,a,n,l,t),null),Ae===null)throw Error(r(349));u||(Pt&127)!==0||Rs(a,t,l)}return l}function Rs(e,t,l){e.flags|=16384,e={getSnapshot:t,value:l},t=ue.updateQueue,t===null?(t=Mu(),ue.updateQueue=t,t.stores=[e]):(l=t.stores,l===null?t.stores=[e]:l.push(e))}function Os(e,t,l,a){t.value=l,t.getSnapshot=a,Ds(t)&&Us(e)}function Ms(e,t,l){return l(function(){Ds(t)&&Us(e)})}function Ds(e){var t=e.getSnapshot;e=e.value;try{var l=t();return!ht(e,l)}catch{return!0}}function Us(e){var t=Kl(e,2);t!==null&&ot(t,e,2)}function Cc(e){var t=lt();if(typeof e=="function"){var l=e;if(e=l(),ta){ml(!0);try{l()}finally{ml(!1)}}}return t.memoizedState=t.baseState=e,t.queue={pending:null,lanes:0,dispatch:null,lastRenderedReducer:el,lastRenderedState:e},t}function Hs(e,t,l,a){return e.baseState=l,_c(e,Ne,typeof a=="function"?a:el)}function sv(e,t,l,a,n){if(Lu(e))throw Error(r(485));if(e=t.action,e!==null){var u={payload:n,action:e,next:null,isTransition:!0,status:"pending",value:null,reason:null,listeners:[],then:function(c){u.listeners.push(c)}};O.T!==null?l(!0):u.isTransition=!1,a(u),l=t.pending,l===null?(u.next=t.pending=u,Bs(t,u)):(u.next=l.next,t.pending=l.next=u)}}function Bs(e,t){var l=t.action,a=t.payload,n=e.state;if(t.isTransition){var u=O.T,c={};O.T=c;try{var o=l(n,a),v=O.S;v!==null&&v(c,o),Ls(e,t,o)}catch(j){Rc(e,t,j)}finally{u!==null&&c.types!==null&&(u.types=c.types),O.T=u}}else try{u=l(n,a),Ls(e,t,u)}catch(j){Rc(e,t,j)}}function Ls(e,t,l){l!==null&&typeof l=="object"&&typeof l.then=="function"?l.then(function(a){ws(e,t,a)},function(a){return Rc(e,t,a)}):ws(e,t,l)}function ws(e,t,l){t.status="fulfilled",t.value=l,qs(t),e.state=l,t=e.pending,t!==null&&(l=t.next,l===t?e.pending=null:(l=l.next,t.next=l,Bs(e,l)))}function Rc(e,t,l){var a=e.pending;if(e.pending=null,a!==null){a=a.next;do t.status="rejected",t.reason=l,qs(t),t=t.next;while(t!==a)}e.action=null}function qs(e){e=e.listeners;for(var t=0;t<e.length;t++)(0,e[t])()}function Ys(e,t){return t}function Gs(e,t){if(he){var l=Ae.formState;if(l!==null){e:{var a=ue;if(he){if(Re){t:{for(var n=Re,u=At;n.nodeType!==8;){if(!u){n=null;break t}if(n=Rt(n.nextSibling),n===null){n=null;break t}}u=n.data,n=u==="F!"||u==="F"?n:null}if(n){Re=Rt(n.nextSibling),a=n.data==="F!";break e}}gl(a)}a=!1}a&&(t=l[0])}}return l=lt(),l.memoizedState=l.baseState=t,a={pending:null,lanes:0,dispatch:null,lastRenderedReducer:Ys,lastRenderedState:t},l.queue=a,l=io.bind(null,ue,a),a.dispatch=l,a=Cc(!1),u=Bc.bind(null,ue,!1,a.queue),a=lt(),n={state:t,dispatch:null,action:e,pending:null},a.queue=n,l=sv.bind(null,ue,n,u,l),n.dispatch=l,a.memoizedState=e,[t,l,!1]}function Xs(e){var t=Ye();return Qs(t,Ne,e)}function Qs(e,t,l){if(t=_c(e,t,Ys)[0],e=Uu(el)[0],typeof t=="object"&&t!==null&&typeof t.then=="function")try{var a=Tn(t)}catch(c){throw c===ja?Nu:c}else a=t;t=Ye();var n=t.queue,u=n.dispatch;return l!==t.memoizedState&&(ue.flags|=2048,Oa(9,{destroy:void 0},ov.bind(null,n,l),null)),[a,u,e]}function ov(e,t){e.action=t}function Zs(e){var t=Ye(),l=Ne;if(l!==null)return Qs(t,l,e);Ye(),t=t.memoizedState,l=Ye();var a=l.queue.dispatch;return l.memoizedState=e,[t,a,!1]}function Oa(e,t,l,a){return e={tag:e,create:l,deps:a,inst:t,next:null},t=ue.updateQueue,t===null&&(t=Mu(),ue.updateQueue=t),l=t.lastEffect,l===null?t.lastEffect=e.next=e:(a=l.next,l.next=e,e.next=a,t.lastEffect=e),e}function Vs(){return Ye().memoizedState}function Hu(e,t,l,a){var n=lt();ue.flags|=e,n.memoizedState=Oa(1|t,{destroy:void 0},l,a===void 0?null:a)}function Bu(e,t,l,a){var n=Ye();a=a===void 0?null:a;var u=n.memoizedState.inst;Ne!==null&&a!==null&&Sc(a,Ne.memoizedState.deps)?n.memoizedState=Oa(t,u,l,a):(ue.flags|=e,n.memoizedState=Oa(1|t,u,l,a))}function Ks(e,t){Hu(8390656,8,e,t)}function Oc(e,t){Bu(2048,8,e,t)}function dv(e){ue.flags|=4;var t=ue.updateQueue;if(t===null)t=Mu(),ue.updateQueue=t,t.events=[e];else{var l=t.events;l===null?t.events=[e]:l.push(e)}}function Js(e){var t=Ye().memoizedState;return dv({ref:t,nextImpl:e}),function(){if((xe&2)!==0)throw Error(r(440));return t.impl.apply(void 0,arguments)}}function ks(e,t){return Bu(4,2,e,t)}function $s(e,t){return Bu(4,4,e,t)}function Ws(e,t){if(typeof t=="function"){e=e();var l=t(e);return function(){typeof l=="function"?l():t(null)}}if(t!=null)return e=e(),t.current=e,function(){t.current=null}}function Fs(e,t,l){l=l!=null?l.concat([e]):null,Bu(4,4,Ws.bind(null,t,e),l)}function Mc(){}function Is(e,t){var l=Ye();t=t===void 0?null:t;var a=l.memoizedState;return t!==null&&Sc(t,a[1])?a[0]:(l.memoizedState=[e,t],e)}function Ps(e,t){var l=Ye();t=t===void 0?null:t;var a=l.memoizedState;if(t!==null&&Sc(t,a[1]))return a[0];if(a=e(),ta){ml(!0);try{e()}finally{ml(!1)}}return l.memoizedState=[a,t],a}function Dc(e,t,l){return l===void 0||(Pt&1073741824)!==0&&(de&261930)===0?e.memoizedState=t:(e.memoizedState=l,e=td(),ue.lanes|=e,_l|=e,l)}function eo(e,t,l,a){return ht(l,t)?l:Aa.current!==null?(e=Dc(e,l,a),ht(e,t)||(Qe=!0),e):(Pt&42)===0||(Pt&1073741824)!==0&&(de&261930)===0?(Qe=!0,e.memoizedState=l):(e=td(),ue.lanes|=e,_l|=e,t)}function to(e,t,l,a,n){var u=G.p;G.p=u!==0&&8>u?u:8;var c=O.T,o={};O.T=o,Bc(e,!1,t,l);try{var v=n(),j=O.S;if(j!==null&&j(o,v),v!==null&&typeof v=="object"&&typeof v.then=="function"){var M=cv(v,a);Nn(e,t,M,xt(e))}else Nn(e,t,a,xt(e))}catch(H){Nn(e,t,{then:function(){},status:"rejected",reason:H},xt())}finally{G.p=u,c!==null&&o.types!==null&&(c.types=o.types),O.T=c}}function mv(){}function Uc(e,t,l,a){if(e.tag!==5)throw Error(r(476));var n=lo(e).queue;to(e,n,t,I,l===null?mv:function(){return ao(e),l(a)})}function lo(e){var t=e.memoizedState;if(t!==null)return t;t={memoizedState:I,baseState:I,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:el,lastRenderedState:I},next:null};var l={};return t.next={memoizedState:l,baseState:l,baseQueue:null,queue:{pending:null,lanes:0,dispatch:null,lastRenderedReducer:el,lastRenderedState:l},next:null},e.memoizedState=t,e=e.alternate,e!==null&&(e.memoizedState=t),t}function ao(e){var t=lo(e);t.next===null&&(t=e.alternate.memoizedState),Nn(e,t.next.queue,{},xt())}function Hc(){return Ie(Gn)}function no(){return Ye().memoizedState}function uo(){return Ye().memoizedState}function hv(e){for(var t=e.return;t!==null;){switch(t.tag){case 24:case 3:var l=xt();e=Sl(l);var a=El(t,e,l);a!==null&&(ot(a,t,l),bn(a,t,l)),t={cache:sc()},e.payload=t;return}t=t.return}}function vv(e,t,l){var a=xt();l={lane:a,revertLane:0,gesture:null,action:l,hasEagerState:!1,eagerState:null,next:null},Lu(e)?co(t,l):(l=Pi(e,t,l,a),l!==null&&(ot(l,e,a),ro(l,t,a)))}function io(e,t,l){var a=xt();Nn(e,t,l,a)}function Nn(e,t,l,a){var n={lane:a,revertLane:0,gesture:null,action:l,hasEagerState:!1,eagerState:null,next:null};if(Lu(e))co(t,n);else{var u=e.alternate;if(e.lanes===0&&(u===null||u.lanes===0)&&(u=t.lastRenderedReducer,u!==null))try{var c=t.lastRenderedState,o=u(c,l);if(n.hasEagerState=!0,n.eagerState=o,ht(o,c))return pu(e,t,n,0),Ae===null&&yu(),!1}catch{}finally{}if(l=Pi(e,t,n,a),l!==null)return ot(l,e,a),ro(l,t,a),!0}return!1}function Bc(e,t,l,a){if(a={lane:2,revertLane:hr(),gesture:null,action:a,hasEagerState:!1,eagerState:null,next:null},Lu(e)){if(t)throw Error(r(479))}else t=Pi(e,l,a,2),t!==null&&ot(t,e,2)}function Lu(e){var t=e.alternate;return e===ue||t!==null&&t===ue}function co(e,t){Ca=Ru=!0;var l=e.pending;l===null?t.next=t:(t.next=l.next,l.next=t),e.pending=t}function ro(e,t,l){if((l&4194048)!==0){var a=t.lanes;a&=e.pendingLanes,l|=a,t.lanes=l,mf(e,l)}}var zn={readContext:Ie,use:Du,useCallback:Le,useContext:Le,useEffect:Le,useImperativeHandle:Le,useLayoutEffect:Le,useInsertionEffect:Le,useMemo:Le,useReducer:Le,useRef:Le,useState:Le,useDebugValue:Le,useDeferredValue:Le,useTransition:Le,useSyncExternalStore:Le,useId:Le,useHostTransitionStatus:Le,useFormState:Le,useActionState:Le,useOptimistic:Le,useMemoCache:Le,useCacheRefresh:Le};zn.useEffectEvent=Le;var fo={readContext:Ie,use:Du,useCallback:function(e,t){return lt().memoizedState=[e,t===void 0?null:t],e},useContext:Ie,useEffect:Ks,useImperativeHandle:function(e,t,l){l=l!=null?l.concat([e]):null,Hu(4194308,4,Ws.bind(null,t,e),l)},useLayoutEffect:function(e,t){return Hu(4194308,4,e,t)},useInsertionEffect:function(e,t){Hu(4,2,e,t)},useMemo:function(e,t){var l=lt();t=t===void 0?null:t;var a=e();if(ta){ml(!0);try{e()}finally{ml(!1)}}return l.memoizedState=[a,t],a},useReducer:function(e,t,l){var a=lt();if(l!==void 0){var n=l(t);if(ta){ml(!0);try{l(t)}finally{ml(!1)}}}else n=t;return a.memoizedState=a.baseState=n,e={pending:null,lanes:0,dispatch:null,lastRenderedReducer:e,lastRenderedState:n},a.queue=e,e=e.dispatch=vv.bind(null,ue,e),[a.memoizedState,e]},useRef:function(e){var t=lt();return e={current:e},t.memoizedState=e},useState:function(e){e=Cc(e);var t=e.queue,l=io.bind(null,ue,t);return t.dispatch=l,[e.memoizedState,l]},useDebugValue:Mc,useDeferredValue:function(e,t){var l=lt();return Dc(l,e,t)},useTransition:function(){var e=Cc(!1);return e=to.bind(null,ue,e.queue,!0,!1),lt().memoizedState=e,[!1,e]},useSyncExternalStore:function(e,t,l){var a=ue,n=lt();if(he){if(l===void 0)throw Error(r(407));l=l()}else{if(l=t(),Ae===null)throw Error(r(349));(de&127)!==0||Rs(a,t,l)}n.memoizedState=l;var u={value:l,getSnapshot:t};return n.queue=u,Ks(Ms.bind(null,a,u,e),[e]),a.flags|=2048,Oa(9,{destroy:void 0},Os.bind(null,a,u,l,t),null),l},useId:function(){var e=lt(),t=Ae.identifierPrefix;if(he){var l=Xt,a=Gt;l=(a&~(1<<32-mt(a)-1)).toString(32)+l,t="_"+t+"R_"+l,l=Ou++,0<l&&(t+="H"+l.toString(32)),t+="_"}else l=rv++,t="_"+t+"r_"+l.toString(32)+"_";return e.memoizedState=t},useHostTransitionStatus:Hc,useFormState:Gs,useActionState:Gs,useOptimistic:function(e){var t=lt();t.memoizedState=t.baseState=e;var l={pending:null,lanes:0,dispatch:null,lastRenderedReducer:null,lastRenderedState:null};return t.queue=l,t=Bc.bind(null,ue,!0,l),l.dispatch=t,[e,t]},useMemoCache:jc,useCacheRefresh:function(){return lt().memoizedState=hv.bind(null,ue)},useEffectEvent:function(e){var t=lt(),l={impl:e};return t.memoizedState=l,function(){if((xe&2)!==0)throw Error(r(440));return l.impl.apply(void 0,arguments)}}},Lc={readContext:Ie,use:Du,useCallback:Is,useContext:Ie,useEffect:Oc,useImperativeHandle:Fs,useInsertionEffect:ks,useLayoutEffect:$s,useMemo:Ps,useReducer:Uu,useRef:Vs,useState:function(){return Uu(el)},useDebugValue:Mc,useDeferredValue:function(e,t){var l=Ye();return eo(l,Ne.memoizedState,e,t)},useTransition:function(){var e=Uu(el)[0],t=Ye().memoizedState;return[typeof e=="boolean"?e:Tn(e),t]},useSyncExternalStore:Cs,useId:no,useHostTransitionStatus:Hc,useFormState:Xs,useActionState:Xs,useOptimistic:function(e,t){var l=Ye();return Hs(l,Ne,e,t)},useMemoCache:jc,useCacheRefresh:uo};Lc.useEffectEvent=Js;var so={readContext:Ie,use:Du,useCallback:Is,useContext:Ie,useEffect:Oc,useImperativeHandle:Fs,useInsertionEffect:ks,useLayoutEffect:$s,useMemo:Ps,useReducer:Ac,useRef:Vs,useState:function(){return Ac(el)},useDebugValue:Mc,useDeferredValue:function(e,t){var l=Ye();return Ne===null?Dc(l,e,t):eo(l,Ne.memoizedState,e,t)},useTransition:function(){var e=Ac(el)[0],t=Ye().memoizedState;return[typeof e=="boolean"?e:Tn(e),t]},useSyncExternalStore:Cs,useId:no,useHostTransitionStatus:Hc,useFormState:Zs,useActionState:Zs,useOptimistic:function(e,t){var l=Ye();return Ne!==null?Hs(l,Ne,e,t):(l.baseState=e,[e,l.queue.dispatch])},useMemoCache:jc,useCacheRefresh:uo};so.useEffectEvent=Js;function wc(e,t,l,a){t=e.memoizedState,l=l(a,t),l=l==null?t:E({},t,l),e.memoizedState=l,e.lanes===0&&(e.updateQueue.baseState=l)}var qc={enqueueSetState:function(e,t,l){e=e._reactInternals;var a=xt(),n=Sl(a);n.payload=t,l!=null&&(n.callback=l),t=El(e,n,a),t!==null&&(ot(t,e,a),bn(t,e,a))},enqueueReplaceState:function(e,t,l){e=e._reactInternals;var a=xt(),n=Sl(a);n.tag=1,n.payload=t,l!=null&&(n.callback=l),t=El(e,n,a),t!==null&&(ot(t,e,a),bn(t,e,a))},enqueueForceUpdate:function(e,t){e=e._reactInternals;var l=xt(),a=Sl(l);a.tag=2,t!=null&&(a.callback=t),t=El(e,a,l),t!==null&&(ot(t,e,l),bn(t,e,l))}};function oo(e,t,l,a,n,u,c){return e=e.stateNode,typeof e.shouldComponentUpdate=="function"?e.shouldComponentUpdate(a,u,c):t.prototype&&t.prototype.isPureReactComponent?!on(l,a)||!on(n,u):!0}function mo(e,t,l,a){e=t.state,typeof t.componentWillReceiveProps=="function"&&t.componentWillReceiveProps(l,a),typeof t.UNSAFE_componentWillReceiveProps=="function"&&t.UNSAFE_componentWillReceiveProps(l,a),t.state!==e&&qc.enqueueReplaceState(t,t.state,null)}function la(e,t){var l=t;if("ref"in t){l={};for(var a in t)a!=="ref"&&(l[a]=t[a])}if(e=e.defaultProps){l===t&&(l=E({},l));for(var n in e)l[n]===void 0&&(l[n]=e[n])}return l}function ho(e){vu(e)}function vo(e){console.error(e)}function yo(e){vu(e)}function wu(e,t){try{var l=e.onUncaughtError;l(t.value,{componentStack:t.stack})}catch(a){setTimeout(function(){throw a})}}function po(e,t,l){try{var a=e.onCaughtError;a(l.value,{componentStack:l.stack,errorBoundary:t.tag===1?t.stateNode:null})}catch(n){setTimeout(function(){throw n})}}function Yc(e,t,l){return l=Sl(l),l.tag=3,l.payload={element:null},l.callback=function(){wu(e,t)},l}function go(e){return e=Sl(e),e.tag=3,e}function bo(e,t,l,a){var n=l.type.getDerivedStateFromError;if(typeof n=="function"){var u=a.value;e.payload=function(){return n(u)},e.callback=function(){po(t,l,a)}}var c=l.stateNode;c!==null&&typeof c.componentDidCatch=="function"&&(e.callback=function(){po(t,l,a),typeof n!="function"&&(Al===null?Al=new Set([this]):Al.add(this));var o=a.stack;this.componentDidCatch(a.value,{componentStack:o!==null?o:""})})}function yv(e,t,l,a,n){if(l.flags|=32768,a!==null&&typeof a=="object"&&typeof a.then=="function"){if(t=l.alternate,t!==null&&Ta(t,l,n,!0),l=yt.current,l!==null){switch(l.tag){case 31:case 13:return Ct===null?Wu():l.alternate===null&&we===0&&(we=3),l.flags&=-257,l.flags|=65536,l.lanes=n,a===zu?l.flags|=16384:(t=l.updateQueue,t===null?l.updateQueue=new Set([a]):t.add(a),or(e,a,n)),!1;case 22:return l.flags|=65536,a===zu?l.flags|=16384:(t=l.updateQueue,t===null?(t={transitions:null,markerInstances:null,retryQueue:new Set([a])},l.updateQueue=t):(l=t.retryQueue,l===null?t.retryQueue=new Set([a]):l.add(a)),or(e,a,n)),!1}throw Error(r(435,l.tag))}return or(e,a,n),Wu(),!1}if(he)return t=yt.current,t!==null?((t.flags&65536)===0&&(t.flags|=256),t.flags|=65536,t.lanes=n,a!==uc&&(e=Error(r(422),{cause:a}),hn(zt(e,l)))):(a!==uc&&(t=Error(r(423),{cause:a}),hn(zt(t,l))),e=e.current.alternate,e.flags|=65536,n&=-n,e.lanes|=n,a=zt(a,l),n=Yc(e.stateNode,a,n),yc(e,n),we!==4&&(we=2)),!1;var u=Error(r(520),{cause:a});if(u=zt(u,l),Dn===null?Dn=[u]:Dn.push(u),we!==4&&(we=2),t===null)return!0;a=zt(a,l),l=t;do{switch(l.tag){case 3:return l.flags|=65536,e=n&-n,l.lanes|=e,e=Yc(l.stateNode,a,e),yc(l,e),!1;case 1:if(t=l.type,u=l.stateNode,(l.flags&128)===0&&(typeof t.getDerivedStateFromError=="function"||u!==null&&typeof u.componentDidCatch=="function"&&(Al===null||!Al.has(u))))return l.flags|=65536,n&=-n,l.lanes|=n,n=go(n),bo(n,e,l,a),yc(l,n),!1}l=l.return}while(l!==null);return!1}var Gc=Error(r(461)),Qe=!1;function Pe(e,t,l,a){t.child=e===null?Es(t,null,l,a):ea(t,e.child,l,a)}function xo(e,t,l,a,n){l=l.render;var u=t.ref;if("ref"in a){var c={};for(var o in a)o!=="ref"&&(c[o]=a[o])}else c=a;return Wl(t),a=Ec(e,t,l,c,u,n),o=Tc(),e!==null&&!Qe?(Nc(e,t,n),tl(e,t,n)):(he&&o&&ac(t),t.flags|=1,Pe(e,t,a,n),t.child)}function So(e,t,l,a,n){if(e===null){var u=l.type;return typeof u=="function"&&!ec(u)&&u.defaultProps===void 0&&l.compare===null?(t.tag=15,t.type=u,Eo(e,t,u,a,n)):(e=bu(l.type,null,a,t,t.mode,n),e.ref=t.ref,e.return=t,t.child=e)}if(u=e.child,!$c(e,n)){var c=u.memoizedProps;if(l=l.compare,l=l!==null?l:on,l(c,a)&&e.ref===t.ref)return tl(e,t,n)}return t.flags|=1,e=$t(u,a),e.ref=t.ref,e.return=t,t.child=e}function Eo(e,t,l,a,n){if(e!==null){var u=e.memoizedProps;if(on(u,a)&&e.ref===t.ref)if(Qe=!1,t.pendingProps=a=u,$c(e,n))(e.flags&131072)!==0&&(Qe=!0);else return t.lanes=e.lanes,tl(e,t,n)}return Xc(e,t,l,a,n)}function To(e,t,l,a){var n=a.children,u=e!==null?e.memoizedState:null;if(e===null&&t.stateNode===null&&(t.stateNode={_visibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null}),a.mode==="hidden"){if((t.flags&128)!==0){if(u=u!==null?u.baseLanes|l:l,e!==null){for(a=t.child=e.child,n=0;a!==null;)n=n|a.lanes|a.childLanes,a=a.sibling;a=n&~u}else a=0,t.child=null;return No(e,t,u,l,a)}if((l&536870912)!==0)t.memoizedState={baseLanes:0,cachePool:null},e!==null&&Tu(t,u!==null?u.cachePool:null),u!==null?zs(t,u):gc(),js(t);else return a=t.lanes=536870912,No(e,t,u!==null?u.baseLanes|l:l,l,a)}else u!==null?(Tu(t,u.cachePool),zs(t,u),Nl(),t.memoizedState=null):(e!==null&&Tu(t,null),gc(),Nl());return Pe(e,t,n,l),t.child}function jn(e,t){return e!==null&&e.tag===22||t.stateNode!==null||(t.stateNode={_visibility:1,_pendingMarkers:null,_retryCache:null,_transitions:null}),t.sibling}function No(e,t,l,a,n){var u=dc();return u=u===null?null:{parent:Ge._currentValue,pool:u},t.memoizedState={baseLanes:l,cachePool:u},e!==null&&Tu(t,null),gc(),js(t),e!==null&&Ta(e,t,a,!0),t.childLanes=n,null}function qu(e,t){return t=Gu({mode:t.mode,children:t.children},e.mode),t.ref=e.ref,e.child=t,t.return=e,t}function zo(e,t,l){return ea(t,e.child,null,l),e=qu(t,t.pendingProps),e.flags|=2,pt(t),t.memoizedState=null,e}function pv(e,t,l){var a=t.pendingProps,n=(t.flags&128)!==0;if(t.flags&=-129,e===null){if(he){if(a.mode==="hidden")return e=qu(t,a),t.lanes=536870912,jn(null,e);if(xc(t),(e=Re)?(e=Ld(e,At),e=e!==null&&e.data==="&"?e:null,e!==null&&(t.memoizedState={dehydrated:e,treeContext:yl!==null?{id:Gt,overflow:Xt}:null,retryLane:536870912,hydrationErrors:null},l=cs(e),l.return=t,t.child=l,Fe=t,Re=null)):e=null,e===null)throw gl(t);return t.lanes=536870912,null}return qu(t,a)}var u=e.memoizedState;if(u!==null){var c=u.dehydrated;if(xc(t),n)if(t.flags&256)t.flags&=-257,t=zo(e,t,l);else if(t.memoizedState!==null)t.child=e.child,t.flags|=128,t=null;else throw Error(r(558));else if(Qe||Ta(e,t,l,!1),n=(l&e.childLanes)!==0,Qe||n){if(a=Ae,a!==null&&(c=hf(a,l),c!==0&&c!==u.retryLane))throw u.retryLane=c,Kl(e,c),ot(a,e,c),Gc;Wu(),t=zo(e,t,l)}else e=u.treeContext,Re=Rt(c.nextSibling),Fe=t,he=!0,pl=null,At=!1,e!==null&&ss(t,e),t=qu(t,a),t.flags|=4096;return t}return e=$t(e.child,{mode:a.mode,children:a.children}),e.ref=t.ref,t.child=e,e.return=t,e}function Yu(e,t){var l=t.ref;if(l===null)e!==null&&e.ref!==null&&(t.flags|=4194816);else{if(typeof l!="function"&&typeof l!="object")throw Error(r(284));(e===null||e.ref!==l)&&(t.flags|=4194816)}}function Xc(e,t,l,a,n){return Wl(t),l=Ec(e,t,l,a,void 0,n),a=Tc(),e!==null&&!Qe?(Nc(e,t,n),tl(e,t,n)):(he&&a&&ac(t),t.flags|=1,Pe(e,t,l,n),t.child)}function jo(e,t,l,a,n,u){return Wl(t),t.updateQueue=null,l=As(t,a,l,n),_s(e),a=Tc(),e!==null&&!Qe?(Nc(e,t,u),tl(e,t,u)):(he&&a&&ac(t),t.flags|=1,Pe(e,t,l,u),t.child)}function _o(e,t,l,a,n){if(Wl(t),t.stateNode===null){var u=ba,c=l.contextType;typeof c=="object"&&c!==null&&(u=Ie(c)),u=new l(a,u),t.memoizedState=u.state!==null&&u.state!==void 0?u.state:null,u.updater=qc,t.stateNode=u,u._reactInternals=t,u=t.stateNode,u.props=a,u.state=t.memoizedState,u.refs={},hc(t),c=l.contextType,u.context=typeof c=="object"&&c!==null?Ie(c):ba,u.state=t.memoizedState,c=l.getDerivedStateFromProps,typeof c=="function"&&(wc(t,l,c,a),u.state=t.memoizedState),typeof l.getDerivedStateFromProps=="function"||typeof u.getSnapshotBeforeUpdate=="function"||typeof u.UNSAFE_componentWillMount!="function"&&typeof u.componentWillMount!="function"||(c=u.state,typeof u.componentWillMount=="function"&&u.componentWillMount(),typeof u.UNSAFE_componentWillMount=="function"&&u.UNSAFE_componentWillMount(),c!==u.state&&qc.enqueueReplaceState(u,u.state,null),Sn(t,a,u,n),xn(),u.state=t.memoizedState),typeof u.componentDidMount=="function"&&(t.flags|=4194308),a=!0}else if(e===null){u=t.stateNode;var o=t.memoizedProps,v=la(l,o);u.props=v;var j=u.context,M=l.contextType;c=ba,typeof M=="object"&&M!==null&&(c=Ie(M));var H=l.getDerivedStateFromProps;M=typeof H=="function"||typeof u.getSnapshotBeforeUpdate=="function",o=t.pendingProps!==o,M||typeof u.UNSAFE_componentWillReceiveProps!="function"&&typeof u.componentWillReceiveProps!="function"||(o||j!==c)&&mo(t,u,a,c),xl=!1;var _=t.memoizedState;u.state=_,Sn(t,a,u,n),xn(),j=t.memoizedState,o||_!==j||xl?(typeof H=="function"&&(wc(t,l,H,a),j=t.memoizedState),(v=xl||oo(t,l,v,a,_,j,c))?(M||typeof u.UNSAFE_componentWillMount!="function"&&typeof u.componentWillMount!="function"||(typeof u.componentWillMount=="function"&&u.componentWillMount(),typeof u.UNSAFE_componentWillMount=="function"&&u.UNSAFE_componentWillMount()),typeof u.componentDidMount=="function"&&(t.flags|=4194308)):(typeof u.componentDidMount=="function"&&(t.flags|=4194308),t.memoizedProps=a,t.memoizedState=j),u.props=a,u.state=j,u.context=c,a=v):(typeof u.componentDidMount=="function"&&(t.flags|=4194308),a=!1)}else{u=t.stateNode,vc(e,t),c=t.memoizedProps,M=la(l,c),u.props=M,H=t.pendingProps,_=u.context,j=l.contextType,v=ba,typeof j=="object"&&j!==null&&(v=Ie(j)),o=l.getDerivedStateFromProps,(j=typeof o=="function"||typeof u.getSnapshotBeforeUpdate=="function")||typeof u.UNSAFE_componentWillReceiveProps!="function"&&typeof u.componentWillReceiveProps!="function"||(c!==H||_!==v)&&mo(t,u,a,v),xl=!1,_=t.memoizedState,u.state=_,Sn(t,a,u,n),xn();var C=t.memoizedState;c!==H||_!==C||xl||e!==null&&e.dependencies!==null&&Su(e.dependencies)?(typeof o=="function"&&(wc(t,l,o,a),C=t.memoizedState),(M=xl||oo(t,l,M,a,_,C,v)||e!==null&&e.dependencies!==null&&Su(e.dependencies))?(j||typeof u.UNSAFE_componentWillUpdate!="function"&&typeof u.componentWillUpdate!="function"||(typeof u.componentWillUpdate=="function"&&u.componentWillUpdate(a,C,v),typeof u.UNSAFE_componentWillUpdate=="function"&&u.UNSAFE_componentWillUpdate(a,C,v)),typeof u.componentDidUpdate=="function"&&(t.flags|=4),typeof u.getSnapshotBeforeUpdate=="function"&&(t.flags|=1024)):(typeof u.componentDidUpdate!="function"||c===e.memoizedProps&&_===e.memoizedState||(t.flags|=4),typeof u.getSnapshotBeforeUpdate!="function"||c===e.memoizedProps&&_===e.memoizedState||(t.flags|=1024),t.memoizedProps=a,t.memoizedState=C),u.props=a,u.state=C,u.context=v,a=M):(typeof u.componentDidUpdate!="function"||c===e.memoizedProps&&_===e.memoizedState||(t.flags|=4),typeof u.getSnapshotBeforeUpdate!="function"||c===e.memoizedProps&&_===e.memoizedState||(t.flags|=1024),a=!1)}return u=a,Yu(e,t),a=(t.flags&128)!==0,u||a?(u=t.stateNode,l=a&&typeof l.getDerivedStateFromError!="function"?null:u.render(),t.flags|=1,e!==null&&a?(t.child=ea(t,e.child,null,n),t.child=ea(t,null,l,n)):Pe(e,t,l,n),t.memoizedState=u.state,e=t.child):e=tl(e,t,n),e}function Ao(e,t,l,a){return kl(),t.flags|=256,Pe(e,t,l,a),t.child}var Qc={dehydrated:null,treeContext:null,retryLane:0,hydrationErrors:null};function Zc(e){return{baseLanes:e,cachePool:ys()}}function Vc(e,t,l){return e=e!==null?e.childLanes&~l:0,t&&(e|=bt),e}function Co(e,t,l){var a=t.pendingProps,n=!1,u=(t.flags&128)!==0,c;if((c=u)||(c=e!==null&&e.memoizedState===null?!1:(qe.current&2)!==0),c&&(n=!0,t.flags&=-129),c=(t.flags&32)!==0,t.flags&=-33,e===null){if(he){if(n?Tl(t):Nl(),(e=Re)?(e=Ld(e,At),e=e!==null&&e.data!=="&"?e:null,e!==null&&(t.memoizedState={dehydrated:e,treeContext:yl!==null?{id:Gt,overflow:Xt}:null,retryLane:536870912,hydrationErrors:null},l=cs(e),l.return=t,t.child=l,Fe=t,Re=null)):e=null,e===null)throw gl(t);return _r(e)?t.lanes=32:t.lanes=536870912,null}var o=a.children;return a=a.fallback,n?(Nl(),n=t.mode,o=Gu({mode:"hidden",children:o},n),a=Jl(a,n,l,null),o.return=t,a.return=t,o.sibling=a,t.child=o,a=t.child,a.memoizedState=Zc(l),a.childLanes=Vc(e,c,l),t.memoizedState=Qc,jn(null,a)):(Tl(t),Kc(t,o))}var v=e.memoizedState;if(v!==null&&(o=v.dehydrated,o!==null)){if(u)t.flags&256?(Tl(t),t.flags&=-257,t=Jc(e,t,l)):t.memoizedState!==null?(Nl(),t.child=e.child,t.flags|=128,t=null):(Nl(),o=a.fallback,n=t.mode,a=Gu({mode:"visible",children:a.children},n),o=Jl(o,n,l,null),o.flags|=2,a.return=t,o.return=t,a.sibling=o,t.child=a,ea(t,e.child,null,l),a=t.child,a.memoizedState=Zc(l),a.childLanes=Vc(e,c,l),t.memoizedState=Qc,t=jn(null,a));else if(Tl(t),_r(o)){if(c=o.nextSibling&&o.nextSibling.dataset,c)var j=c.dgst;c=j,a=Error(r(419)),a.stack="",a.digest=c,hn({value:a,source:null,stack:null}),t=Jc(e,t,l)}else if(Qe||Ta(e,t,l,!1),c=(l&e.childLanes)!==0,Qe||c){if(c=Ae,c!==null&&(a=hf(c,l),a!==0&&a!==v.retryLane))throw v.retryLane=a,Kl(e,a),ot(c,e,a),Gc;jr(o)||Wu(),t=Jc(e,t,l)}else jr(o)?(t.flags|=192,t.child=e.child,t=null):(e=v.treeContext,Re=Rt(o.nextSibling),Fe=t,he=!0,pl=null,At=!1,e!==null&&ss(t,e),t=Kc(t,a.children),t.flags|=4096);return t}return n?(Nl(),o=a.fallback,n=t.mode,v=e.child,j=v.sibling,a=$t(v,{mode:"hidden",children:a.children}),a.subtreeFlags=v.subtreeFlags&65011712,j!==null?o=$t(j,o):(o=Jl(o,n,l,null),o.flags|=2),o.return=t,a.return=t,a.sibling=o,t.child=a,jn(null,a),a=t.child,o=e.child.memoizedState,o===null?o=Zc(l):(n=o.cachePool,n!==null?(v=Ge._currentValue,n=n.parent!==v?{parent:v,pool:v}:n):n=ys(),o={baseLanes:o.baseLanes|l,cachePool:n}),a.memoizedState=o,a.childLanes=Vc(e,c,l),t.memoizedState=Qc,jn(e.child,a)):(Tl(t),l=e.child,e=l.sibling,l=$t(l,{mode:"visible",children:a.children}),l.return=t,l.sibling=null,e!==null&&(c=t.deletions,c===null?(t.deletions=[e],t.flags|=16):c.push(e)),t.child=l,t.memoizedState=null,l)}function Kc(e,t){return t=Gu({mode:"visible",children:t},e.mode),t.return=e,e.child=t}function Gu(e,t){return e=vt(22,e,null,t),e.lanes=0,e}function Jc(e,t,l){return ea(t,e.child,null,l),e=Kc(t,t.pendingProps.children),e.flags|=2,t.memoizedState=null,e}function Ro(e,t,l){e.lanes|=t;var a=e.alternate;a!==null&&(a.lanes|=t),rc(e.return,t,l)}function kc(e,t,l,a,n,u){var c=e.memoizedState;c===null?e.memoizedState={isBackwards:t,rendering:null,renderingStartTime:0,last:a,tail:l,tailMode:n,treeForkCount:u}:(c.isBackwards=t,c.rendering=null,c.renderingStartTime=0,c.last=a,c.tail=l,c.tailMode=n,c.treeForkCount=u)}function Oo(e,t,l){var a=t.pendingProps,n=a.revealOrder,u=a.tail;a=a.children;var c=qe.current,o=(c&2)!==0;if(o?(c=c&1|2,t.flags|=128):c&=1,Y(qe,c),Pe(e,t,a,l),a=he?mn:0,!o&&e!==null&&(e.flags&128)!==0)e:for(e=t.child;e!==null;){if(e.tag===13)e.memoizedState!==null&&Ro(e,l,t);else if(e.tag===19)Ro(e,l,t);else if(e.child!==null){e.child.return=e,e=e.child;continue}if(e===t)break e;for(;e.sibling===null;){if(e.return===null||e.return===t)break e;e=e.return}e.sibling.return=e.return,e=e.sibling}switch(n){case"forwards":for(l=t.child,n=null;l!==null;)e=l.alternate,e!==null&&Cu(e)===null&&(n=l),l=l.sibling;l=n,l===null?(n=t.child,t.child=null):(n=l.sibling,l.sibling=null),kc(t,!1,n,l,u,a);break;case"backwards":case"unstable_legacy-backwards":for(l=null,n=t.child,t.child=null;n!==null;){if(e=n.alternate,e!==null&&Cu(e)===null){t.child=n;break}e=n.sibling,n.sibling=l,l=n,n=e}kc(t,!0,l,null,u,a);break;case"together":kc(t,!1,null,null,void 0,a);break;default:t.memoizedState=null}return t.child}function tl(e,t,l){if(e!==null&&(t.dependencies=e.dependencies),_l|=t.lanes,(l&t.childLanes)===0)if(e!==null){if(Ta(e,t,l,!1),(l&t.childLanes)===0)return null}else return null;if(e!==null&&t.child!==e.child)throw Error(r(153));if(t.child!==null){for(e=t.child,l=$t(e,e.pendingProps),t.child=l,l.return=t;e.sibling!==null;)e=e.sibling,l=l.sibling=$t(e,e.pendingProps),l.return=t;l.sibling=null}return t.child}function $c(e,t){return(e.lanes&t)!==0?!0:(e=e.dependencies,!!(e!==null&&Su(e)))}function gv(e,t,l){switch(t.tag){case 3:$e(t,t.stateNode.containerInfo),bl(t,Ge,e.memoizedState.cache),kl();break;case 27:case 5:ql(t);break;case 4:$e(t,t.stateNode.containerInfo);break;case 10:bl(t,t.type,t.memoizedProps.value);break;case 31:if(t.memoizedState!==null)return t.flags|=128,xc(t),null;break;case 13:var a=t.memoizedState;if(a!==null)return a.dehydrated!==null?(Tl(t),t.flags|=128,null):(l&t.child.childLanes)!==0?Co(e,t,l):(Tl(t),e=tl(e,t,l),e!==null?e.sibling:null);Tl(t);break;case 19:var n=(e.flags&128)!==0;if(a=(l&t.childLanes)!==0,a||(Ta(e,t,l,!1),a=(l&t.childLanes)!==0),n){if(a)return Oo(e,t,l);t.flags|=128}if(n=t.memoizedState,n!==null&&(n.rendering=null,n.tail=null,n.lastEffect=null),Y(qe,qe.current),a)break;return null;case 22:return t.lanes=0,To(e,t,l,t.pendingProps);case 24:bl(t,Ge,e.memoizedState.cache)}return tl(e,t,l)}function Mo(e,t,l){if(e!==null)if(e.memoizedProps!==t.pendingProps)Qe=!0;else{if(!$c(e,l)&&(t.flags&128)===0)return Qe=!1,gv(e,t,l);Qe=(e.flags&131072)!==0}else Qe=!1,he&&(t.flags&1048576)!==0&&fs(t,mn,t.index);switch(t.lanes=0,t.tag){case 16:e:{var a=t.pendingProps;if(e=Il(t.elementType),t.type=e,typeof e=="function")ec(e)?(a=la(e,a),t.tag=1,t=_o(null,t,e,a,l)):(t.tag=0,t=Xc(null,t,e,a,l));else{if(e!=null){var n=e.$$typeof;if(n===ce){t.tag=11,t=xo(null,t,e,a,l);break e}else if(n===$){t.tag=14,t=So(null,t,e,a,l);break e}}throw t=Me(e)||e,Error(r(306,t,""))}}return t;case 0:return Xc(e,t,t.type,t.pendingProps,l);case 1:return a=t.type,n=la(a,t.pendingProps),_o(e,t,a,n,l);case 3:e:{if($e(t,t.stateNode.containerInfo),e===null)throw Error(r(387));a=t.pendingProps;var u=t.memoizedState;n=u.element,vc(e,t),Sn(t,a,null,l);var c=t.memoizedState;if(a=c.cache,bl(t,Ge,a),a!==u.cache&&fc(t,[Ge],l,!0),xn(),a=c.element,u.isDehydrated)if(u={element:a,isDehydrated:!1,cache:c.cache},t.updateQueue.baseState=u,t.memoizedState=u,t.flags&256){t=Ao(e,t,a,l);break e}else if(a!==n){n=zt(Error(r(424)),t),hn(n),t=Ao(e,t,a,l);break e}else{switch(e=t.stateNode.containerInfo,e.nodeType){case 9:e=e.body;break;default:e=e.nodeName==="HTML"?e.ownerDocument.body:e}for(Re=Rt(e.firstChild),Fe=t,he=!0,pl=null,At=!0,l=Es(t,null,a,l),t.child=l;l;)l.flags=l.flags&-3|4096,l=l.sibling}else{if(kl(),a===n){t=tl(e,t,l);break e}Pe(e,t,a,l)}t=t.child}return t;case 26:return Yu(e,t),e===null?(l=Qd(t.type,null,t.pendingProps,null))?t.memoizedState=l:he||(l=t.type,e=t.pendingProps,a=ai(te.current).createElement(l),a[We]=t,a[ut]=e,et(a,l,e),Je(a),t.stateNode=a):t.memoizedState=Qd(t.type,e.memoizedProps,t.pendingProps,e.memoizedState),null;case 27:return ql(t),e===null&&he&&(a=t.stateNode=Yd(t.type,t.pendingProps,te.current),Fe=t,At=!0,n=Re,Ml(t.type)?(Ar=n,Re=Rt(a.firstChild)):Re=n),Pe(e,t,t.pendingProps.children,l),Yu(e,t),e===null&&(t.flags|=4194304),t.child;case 5:return e===null&&he&&((n=a=Re)&&(a=kv(a,t.type,t.pendingProps,At),a!==null?(t.stateNode=a,Fe=t,Re=Rt(a.firstChild),At=!1,n=!0):n=!1),n||gl(t)),ql(t),n=t.type,u=t.pendingProps,c=e!==null?e.memoizedProps:null,a=u.children,Tr(n,u)?a=null:c!==null&&Tr(n,c)&&(t.flags|=32),t.memoizedState!==null&&(n=Ec(e,t,fv,null,null,l),Gn._currentValue=n),Yu(e,t),Pe(e,t,a,l),t.child;case 6:return e===null&&he&&((e=l=Re)&&(l=$v(l,t.pendingProps,At),l!==null?(t.stateNode=l,Fe=t,Re=null,e=!0):e=!1),e||gl(t)),null;case 13:return Co(e,t,l);case 4:return $e(t,t.stateNode.containerInfo),a=t.pendingProps,e===null?t.child=ea(t,null,a,l):Pe(e,t,a,l),t.child;case 11:return xo(e,t,t.type,t.pendingProps,l);case 7:return Pe(e,t,t.pendingProps,l),t.child;case 8:return Pe(e,t,t.pendingProps.children,l),t.child;case 12:return Pe(e,t,t.pendingProps.children,l),t.child;case 10:return a=t.pendingProps,bl(t,t.type,a.value),Pe(e,t,a.children,l),t.child;case 9:return n=t.type._context,a=t.pendingProps.children,Wl(t),n=Ie(n),a=a(n),t.flags|=1,Pe(e,t,a,l),t.child;case 14:return So(e,t,t.type,t.pendingProps,l);case 15:return Eo(e,t,t.type,t.pendingProps,l);case 19:return Oo(e,t,l);case 31:return pv(e,t,l);case 22:return To(e,t,l,t.pendingProps);case 24:return Wl(t),a=Ie(Ge),e===null?(n=dc(),n===null&&(n=Ae,u=sc(),n.pooledCache=u,u.refCount++,u!==null&&(n.pooledCacheLanes|=l),n=u),t.memoizedState={parent:a,cache:n},hc(t),bl(t,Ge,n)):((e.lanes&l)!==0&&(vc(e,t),Sn(t,null,null,l),xn()),n=e.memoizedState,u=t.memoizedState,n.parent!==a?(n={parent:a,cache:a},t.memoizedState=n,t.lanes===0&&(t.memoizedState=t.updateQueue.baseState=n),bl(t,Ge,a)):(a=u.cache,bl(t,Ge,a),a!==n.cache&&fc(t,[Ge],l,!0))),Pe(e,t,t.pendingProps.children,l),t.child;case 29:throw t.pendingProps}throw Error(r(156,t.tag))}function ll(e){e.flags|=4}function Wc(e,t,l,a,n){if((t=(e.mode&32)!==0)&&(t=!1),t){if(e.flags|=16777216,(n&335544128)===n)if(e.stateNode.complete)e.flags|=8192;else if(ud())e.flags|=8192;else throw Pl=zu,mc}else e.flags&=-16777217}function Do(e,t){if(t.type!=="stylesheet"||(t.state.loading&4)!==0)e.flags&=-16777217;else if(e.flags|=16777216,!kd(t))if(ud())e.flags|=8192;else throw Pl=zu,mc}function Xu(e,t){t!==null&&(e.flags|=4),e.flags&16384&&(t=e.tag!==22?of():536870912,e.lanes|=t,Ha|=t)}function _n(e,t){if(!he)switch(e.tailMode){case"hidden":t=e.tail;for(var l=null;t!==null;)t.alternate!==null&&(l=t),t=t.sibling;l===null?e.tail=null:l.sibling=null;break;case"collapsed":l=e.tail;for(var a=null;l!==null;)l.alternate!==null&&(a=l),l=l.sibling;a===null?t||e.tail===null?e.tail=null:e.tail.sibling=null:a.sibling=null}}function Oe(e){var t=e.alternate!==null&&e.alternate.child===e.child,l=0,a=0;if(t)for(var n=e.child;n!==null;)l|=n.lanes|n.childLanes,a|=n.subtreeFlags&65011712,a|=n.flags&65011712,n.return=e,n=n.sibling;else for(n=e.child;n!==null;)l|=n.lanes|n.childLanes,a|=n.subtreeFlags,a|=n.flags,n.return=e,n=n.sibling;return e.subtreeFlags|=a,e.childLanes=l,t}function bv(e,t,l){var a=t.pendingProps;switch(nc(t),t.tag){case 16:case 15:case 0:case 11:case 7:case 8:case 12:case 9:case 14:return Oe(t),null;case 1:return Oe(t),null;case 3:return l=t.stateNode,a=null,e!==null&&(a=e.memoizedState.cache),t.memoizedState.cache!==a&&(t.flags|=2048),It(Ge),Be(),l.pendingContext&&(l.context=l.pendingContext,l.pendingContext=null),(e===null||e.child===null)&&(Ea(t)?ll(t):e===null||e.memoizedState.isDehydrated&&(t.flags&256)===0||(t.flags|=1024,ic())),Oe(t),null;case 26:var n=t.type,u=t.memoizedState;return e===null?(ll(t),u!==null?(Oe(t),Do(t,u)):(Oe(t),Wc(t,n,null,a,l))):u?u!==e.memoizedState?(ll(t),Oe(t),Do(t,u)):(Oe(t),t.flags&=-16777217):(e=e.memoizedProps,e!==a&&ll(t),Oe(t),Wc(t,n,e,a,l)),null;case 27:if(Yl(t),l=te.current,n=t.type,e!==null&&t.stateNode!=null)e.memoizedProps!==a&&ll(t);else{if(!a){if(t.stateNode===null)throw Error(r(166));return Oe(t),null}e=Z.current,Ea(t)?os(t):(e=Yd(n,a,l),t.stateNode=e,ll(t))}return Oe(t),null;case 5:if(Yl(t),n=t.type,e!==null&&t.stateNode!=null)e.memoizedProps!==a&&ll(t);else{if(!a){if(t.stateNode===null)throw Error(r(166));return Oe(t),null}if(u=Z.current,Ea(t))os(t);else{var c=ai(te.current);switch(u){case 1:u=c.createElementNS("http://www.w3.org/2000/svg",n);break;case 2:u=c.createElementNS("http://www.w3.org/1998/Math/MathML",n);break;default:switch(n){case"svg":u=c.createElementNS("http://www.w3.org/2000/svg",n);break;case"math":u=c.createElementNS("http://www.w3.org/1998/Math/MathML",n);break;case"script":u=c.createElement("div"),u.innerHTML="<script><\/script>",u=u.removeChild(u.firstChild);break;case"select":u=typeof a.is=="string"?c.createElement("select",{is:a.is}):c.createElement("select"),a.multiple?u.multiple=!0:a.size&&(u.size=a.size);break;default:u=typeof a.is=="string"?c.createElement(n,{is:a.is}):c.createElement(n)}}u[We]=t,u[ut]=a;e:for(c=t.child;c!==null;){if(c.tag===5||c.tag===6)u.appendChild(c.stateNode);else if(c.tag!==4&&c.tag!==27&&c.child!==null){c.child.return=c,c=c.child;continue}if(c===t)break e;for(;c.sibling===null;){if(c.return===null||c.return===t)break e;c=c.return}c.sibling.return=c.return,c=c.sibling}t.stateNode=u;e:switch(et(u,n,a),n){case"button":case"input":case"select":case"textarea":a=!!a.autoFocus;break e;case"img":a=!0;break e;default:a=!1}a&&ll(t)}}return Oe(t),Wc(t,t.type,e===null?null:e.memoizedProps,t.pendingProps,l),null;case 6:if(e&&t.stateNode!=null)e.memoizedProps!==a&&ll(t);else{if(typeof a!="string"&&t.stateNode===null)throw Error(r(166));if(e=te.current,Ea(t)){if(e=t.stateNode,l=t.memoizedProps,a=null,n=Fe,n!==null)switch(n.tag){case 27:case 5:a=n.memoizedProps}e[We]=t,e=!!(e.nodeValue===l||a!==null&&a.suppressHydrationWarning===!0||Cd(e.nodeValue,l)),e||gl(t,!0)}else e=ai(e).createTextNode(a),e[We]=t,t.stateNode=e}return Oe(t),null;case 31:if(l=t.memoizedState,e===null||e.memoizedState!==null){if(a=Ea(t),l!==null){if(e===null){if(!a)throw Error(r(318));if(e=t.memoizedState,e=e!==null?e.dehydrated:null,!e)throw Error(r(557));e[We]=t}else kl(),(t.flags&128)===0&&(t.memoizedState=null),t.flags|=4;Oe(t),e=!1}else l=ic(),e!==null&&e.memoizedState!==null&&(e.memoizedState.hydrationErrors=l),e=!0;if(!e)return t.flags&256?(pt(t),t):(pt(t),null);if((t.flags&128)!==0)throw Error(r(558))}return Oe(t),null;case 13:if(a=t.memoizedState,e===null||e.memoizedState!==null&&e.memoizedState.dehydrated!==null){if(n=Ea(t),a!==null&&a.dehydrated!==null){if(e===null){if(!n)throw Error(r(318));if(n=t.memoizedState,n=n!==null?n.dehydrated:null,!n)throw Error(r(317));n[We]=t}else kl(),(t.flags&128)===0&&(t.memoizedState=null),t.flags|=4;Oe(t),n=!1}else n=ic(),e!==null&&e.memoizedState!==null&&(e.memoizedState.hydrationErrors=n),n=!0;if(!n)return t.flags&256?(pt(t),t):(pt(t),null)}return pt(t),(t.flags&128)!==0?(t.lanes=l,t):(l=a!==null,e=e!==null&&e.memoizedState!==null,l&&(a=t.child,n=null,a.alternate!==null&&a.alternate.memoizedState!==null&&a.alternate.memoizedState.cachePool!==null&&(n=a.alternate.memoizedState.cachePool.pool),u=null,a.memoizedState!==null&&a.memoizedState.cachePool!==null&&(u=a.memoizedState.cachePool.pool),u!==n&&(a.flags|=2048)),l!==e&&l&&(t.child.flags|=8192),Xu(t,t.updateQueue),Oe(t),null);case 4:return Be(),e===null&&gr(t.stateNode.containerInfo),Oe(t),null;case 10:return It(t.type),Oe(t),null;case 19:if(U(qe),a=t.memoizedState,a===null)return Oe(t),null;if(n=(t.flags&128)!==0,u=a.rendering,u===null)if(n)_n(a,!1);else{if(we!==0||e!==null&&(e.flags&128)!==0)for(e=t.child;e!==null;){if(u=Cu(e),u!==null){for(t.flags|=128,_n(a,!1),e=u.updateQueue,t.updateQueue=e,Xu(t,e),t.subtreeFlags=0,e=l,l=t.child;l!==null;)is(l,e),l=l.sibling;return Y(qe,qe.current&1|2),he&&Wt(t,a.treeForkCount),t.child}e=e.sibling}a.tail!==null&&be()>Ju&&(t.flags|=128,n=!0,_n(a,!1),t.lanes=4194304)}else{if(!n)if(e=Cu(u),e!==null){if(t.flags|=128,n=!0,e=e.updateQueue,t.updateQueue=e,Xu(t,e),_n(a,!0),a.tail===null&&a.tailMode==="hidden"&&!u.alternate&&!he)return Oe(t),null}else 2*be()-a.renderingStartTime>Ju&&l!==536870912&&(t.flags|=128,n=!0,_n(a,!1),t.lanes=4194304);a.isBackwards?(u.sibling=t.child,t.child=u):(e=a.last,e!==null?e.sibling=u:t.child=u,a.last=u)}return a.tail!==null?(e=a.tail,a.rendering=e,a.tail=e.sibling,a.renderingStartTime=be(),e.sibling=null,l=qe.current,Y(qe,n?l&1|2:l&1),he&&Wt(t,a.treeForkCount),e):(Oe(t),null);case 22:case 23:return pt(t),bc(),a=t.memoizedState!==null,e!==null?e.memoizedState!==null!==a&&(t.flags|=8192):a&&(t.flags|=8192),a?(l&536870912)!==0&&(t.flags&128)===0&&(Oe(t),t.subtreeFlags&6&&(t.flags|=8192)):Oe(t),l=t.updateQueue,l!==null&&Xu(t,l.retryQueue),l=null,e!==null&&e.memoizedState!==null&&e.memoizedState.cachePool!==null&&(l=e.memoizedState.cachePool.pool),a=null,t.memoizedState!==null&&t.memoizedState.cachePool!==null&&(a=t.memoizedState.cachePool.pool),a!==l&&(t.flags|=2048),e!==null&&U(Fl),null;case 24:return l=null,e!==null&&(l=e.memoizedState.cache),t.memoizedState.cache!==l&&(t.flags|=2048),It(Ge),Oe(t),null;case 25:return null;case 30:return null}throw Error(r(156,t.tag))}function xv(e,t){switch(nc(t),t.tag){case 1:return e=t.flags,e&65536?(t.flags=e&-65537|128,t):null;case 3:return It(Ge),Be(),e=t.flags,(e&65536)!==0&&(e&128)===0?(t.flags=e&-65537|128,t):null;case 26:case 27:case 5:return Yl(t),null;case 31:if(t.memoizedState!==null){if(pt(t),t.alternate===null)throw Error(r(340));kl()}return e=t.flags,e&65536?(t.flags=e&-65537|128,t):null;case 13:if(pt(t),e=t.memoizedState,e!==null&&e.dehydrated!==null){if(t.alternate===null)throw Error(r(340));kl()}return e=t.flags,e&65536?(t.flags=e&-65537|128,t):null;case 19:return U(qe),null;case 4:return Be(),null;case 10:return It(t.type),null;case 22:case 23:return pt(t),bc(),e!==null&&U(Fl),e=t.flags,e&65536?(t.flags=e&-65537|128,t):null;case 24:return It(Ge),null;case 25:return null;default:return null}}function Uo(e,t){switch(nc(t),t.tag){case 3:It(Ge),Be();break;case 26:case 27:case 5:Yl(t);break;case 4:Be();break;case 31:t.memoizedState!==null&&pt(t);break;case 13:pt(t);break;case 19:U(qe);break;case 10:It(t.type);break;case 22:case 23:pt(t),bc(),e!==null&&U(Fl);break;case 24:It(Ge)}}function An(e,t){try{var l=t.updateQueue,a=l!==null?l.lastEffect:null;if(a!==null){var n=a.next;l=n;do{if((l.tag&e)===e){a=void 0;var u=l.create,c=l.inst;a=u(),c.destroy=a}l=l.next}while(l!==n)}}catch(o){Te(t,t.return,o)}}function zl(e,t,l){try{var a=t.updateQueue,n=a!==null?a.lastEffect:null;if(n!==null){var u=n.next;a=u;do{if((a.tag&e)===e){var c=a.inst,o=c.destroy;if(o!==void 0){c.destroy=void 0,n=t;var v=l,j=o;try{j()}catch(M){Te(n,v,M)}}}a=a.next}while(a!==u)}}catch(M){Te(t,t.return,M)}}function Ho(e){var t=e.updateQueue;if(t!==null){var l=e.stateNode;try{Ns(t,l)}catch(a){Te(e,e.return,a)}}}function Bo(e,t,l){l.props=la(e.type,e.memoizedProps),l.state=e.memoizedState;try{l.componentWillUnmount()}catch(a){Te(e,t,a)}}function Cn(e,t){try{var l=e.ref;if(l!==null){switch(e.tag){case 26:case 27:case 5:var a=e.stateNode;break;case 30:a=e.stateNode;break;default:a=e.stateNode}typeof l=="function"?e.refCleanup=l(a):l.current=a}}catch(n){Te(e,t,n)}}function Qt(e,t){var l=e.ref,a=e.refCleanup;if(l!==null)if(typeof a=="function")try{a()}catch(n){Te(e,t,n)}finally{e.refCleanup=null,e=e.alternate,e!=null&&(e.refCleanup=null)}else if(typeof l=="function")try{l(null)}catch(n){Te(e,t,n)}else l.current=null}function Lo(e){var t=e.type,l=e.memoizedProps,a=e.stateNode;try{e:switch(t){case"button":case"input":case"select":case"textarea":l.autoFocus&&a.focus();break e;case"img":l.src?a.src=l.src:l.srcSet&&(a.srcset=l.srcSet)}}catch(n){Te(e,e.return,n)}}function Fc(e,t,l){try{var a=e.stateNode;Xv(a,e.type,l,t),a[ut]=t}catch(n){Te(e,e.return,n)}}function wo(e){return e.tag===5||e.tag===3||e.tag===26||e.tag===27&&Ml(e.type)||e.tag===4}function Ic(e){e:for(;;){for(;e.sibling===null;){if(e.return===null||wo(e.return))return null;e=e.return}for(e.sibling.return=e.return,e=e.sibling;e.tag!==5&&e.tag!==6&&e.tag!==18;){if(e.tag===27&&Ml(e.type)||e.flags&2||e.child===null||e.tag===4)continue e;e.child.return=e,e=e.child}if(!(e.flags&2))return e.stateNode}}function Pc(e,t,l){var a=e.tag;if(a===5||a===6)e=e.stateNode,t?(l.nodeType===9?l.body:l.nodeName==="HTML"?l.ownerDocument.body:l).insertBefore(e,t):(t=l.nodeType===9?l.body:l.nodeName==="HTML"?l.ownerDocument.body:l,t.appendChild(e),l=l._reactRootContainer,l!=null||t.onclick!==null||(t.onclick=Jt));else if(a!==4&&(a===27&&Ml(e.type)&&(l=e.stateNode,t=null),e=e.child,e!==null))for(Pc(e,t,l),e=e.sibling;e!==null;)Pc(e,t,l),e=e.sibling}function Qu(e,t,l){var a=e.tag;if(a===5||a===6)e=e.stateNode,t?l.insertBefore(e,t):l.appendChild(e);else if(a!==4&&(a===27&&Ml(e.type)&&(l=e.stateNode),e=e.child,e!==null))for(Qu(e,t,l),e=e.sibling;e!==null;)Qu(e,t,l),e=e.sibling}function qo(e){var t=e.stateNode,l=e.memoizedProps;try{for(var a=e.type,n=t.attributes;n.length;)t.removeAttributeNode(n[0]);et(t,a,l),t[We]=e,t[ut]=l}catch(u){Te(e,e.return,u)}}var al=!1,Ze=!1,er=!1,Yo=typeof WeakSet=="function"?WeakSet:Set,ke=null;function Sv(e,t){if(e=e.containerInfo,Sr=si,e=Ff(e),Ji(e)){if("selectionStart"in e)var l={start:e.selectionStart,end:e.selectionEnd};else e:{l=(l=e.ownerDocument)&&l.defaultView||window;var a=l.getSelection&&l.getSelection();if(a&&a.rangeCount!==0){l=a.anchorNode;var n=a.anchorOffset,u=a.focusNode;a=a.focusOffset;try{l.nodeType,u.nodeType}catch{l=null;break e}var c=0,o=-1,v=-1,j=0,M=0,H=e,_=null;t:for(;;){for(var C;H!==l||n!==0&&H.nodeType!==3||(o=c+n),H!==u||a!==0&&H.nodeType!==3||(v=c+a),H.nodeType===3&&(c+=H.nodeValue.length),(C=H.firstChild)!==null;)_=H,H=C;for(;;){if(H===e)break t;if(_===l&&++j===n&&(o=c),_===u&&++M===a&&(v=c),(C=H.nextSibling)!==null)break;H=_,_=H.parentNode}H=C}l=o===-1||v===-1?null:{start:o,end:v}}else l=null}l=l||{start:0,end:0}}else l=null;for(Er={focusedElem:e,selectionRange:l},si=!1,ke=t;ke!==null;)if(t=ke,e=t.child,(t.subtreeFlags&1028)!==0&&e!==null)e.return=t,ke=e;else for(;ke!==null;){switch(t=ke,u=t.alternate,e=t.flags,t.tag){case 0:if((e&4)!==0&&(e=t.updateQueue,e=e!==null?e.events:null,e!==null))for(l=0;l<e.length;l++)n=e[l],n.ref.impl=n.nextImpl;break;case 11:case 15:break;case 1:if((e&1024)!==0&&u!==null){e=void 0,l=t,n=u.memoizedProps,u=u.memoizedState,a=l.stateNode;try{var V=la(l.type,n);e=a.getSnapshotBeforeUpdate(V,u),a.__reactInternalSnapshotBeforeUpdate=e}catch(P){Te(l,l.return,P)}}break;case 3:if((e&1024)!==0){if(e=t.stateNode.containerInfo,l=e.nodeType,l===9)zr(e);else if(l===1)switch(e.nodeName){case"HEAD":case"HTML":case"BODY":zr(e);break;default:e.textContent=""}}break;case 5:case 26:case 27:case 6:case 4:case 17:break;default:if((e&1024)!==0)throw Error(r(163))}if(e=t.sibling,e!==null){e.return=t.return,ke=e;break}ke=t.return}}function Go(e,t,l){var a=l.flags;switch(l.tag){case 0:case 11:case 15:ul(e,l),a&4&&An(5,l);break;case 1:if(ul(e,l),a&4)if(e=l.stateNode,t===null)try{e.componentDidMount()}catch(c){Te(l,l.return,c)}else{var n=la(l.type,t.memoizedProps);t=t.memoizedState;try{e.componentDidUpdate(n,t,e.__reactInternalSnapshotBeforeUpdate)}catch(c){Te(l,l.return,c)}}a&64&&Ho(l),a&512&&Cn(l,l.return);break;case 3:if(ul(e,l),a&64&&(e=l.updateQueue,e!==null)){if(t=null,l.child!==null)switch(l.child.tag){case 27:case 5:t=l.child.stateNode;break;case 1:t=l.child.stateNode}try{Ns(e,t)}catch(c){Te(l,l.return,c)}}break;case 27:t===null&&a&4&&qo(l);case 26:case 5:ul(e,l),t===null&&a&4&&Lo(l),a&512&&Cn(l,l.return);break;case 12:ul(e,l);break;case 31:ul(e,l),a&4&&Zo(e,l);break;case 13:ul(e,l),a&4&&Vo(e,l),a&64&&(e=l.memoizedState,e!==null&&(e=e.dehydrated,e!==null&&(l=Rv.bind(null,l),Wv(e,l))));break;case 22:if(a=l.memoizedState!==null||al,!a){t=t!==null&&t.memoizedState!==null||Ze,n=al;var u=Ze;al=a,(Ze=t)&&!u?il(e,l,(l.subtreeFlags&8772)!==0):ul(e,l),al=n,Ze=u}break;case 30:break;default:ul(e,l)}}function Xo(e){var t=e.alternate;t!==null&&(e.alternate=null,Xo(t)),e.child=null,e.deletions=null,e.sibling=null,e.tag===5&&(t=e.stateNode,t!==null&&Ri(t)),e.stateNode=null,e.return=null,e.dependencies=null,e.memoizedProps=null,e.memoizedState=null,e.pendingProps=null,e.stateNode=null,e.updateQueue=null}var De=null,ct=!1;function nl(e,t,l){for(l=l.child;l!==null;)Qo(e,t,l),l=l.sibling}function Qo(e,t,l){if(dt&&typeof dt.onCommitFiberUnmount=="function")try{dt.onCommitFiberUnmount(Ia,l)}catch{}switch(l.tag){case 26:Ze||Qt(l,t),nl(e,t,l),l.memoizedState?l.memoizedState.count--:l.stateNode&&(l=l.stateNode,l.parentNode.removeChild(l));break;case 27:Ze||Qt(l,t);var a=De,n=ct;Ml(l.type)&&(De=l.stateNode,ct=!1),nl(e,t,l),wn(l.stateNode),De=a,ct=n;break;case 5:Ze||Qt(l,t);case 6:if(a=De,n=ct,De=null,nl(e,t,l),De=a,ct=n,De!==null)if(ct)try{(De.nodeType===9?De.body:De.nodeName==="HTML"?De.ownerDocument.body:De).removeChild(l.stateNode)}catch(u){Te(l,t,u)}else try{De.removeChild(l.stateNode)}catch(u){Te(l,t,u)}break;case 18:De!==null&&(ct?(e=De,Hd(e.nodeType===9?e.body:e.nodeName==="HTML"?e.ownerDocument.body:e,l.stateNode),Qa(e)):Hd(De,l.stateNode));break;case 4:a=De,n=ct,De=l.stateNode.containerInfo,ct=!0,nl(e,t,l),De=a,ct=n;break;case 0:case 11:case 14:case 15:zl(2,l,t),Ze||zl(4,l,t),nl(e,t,l);break;case 1:Ze||(Qt(l,t),a=l.stateNode,typeof a.componentWillUnmount=="function"&&Bo(l,t,a)),nl(e,t,l);break;case 21:nl(e,t,l);break;case 22:Ze=(a=Ze)||l.memoizedState!==null,nl(e,t,l),Ze=a;break;default:nl(e,t,l)}}function Zo(e,t){if(t.memoizedState===null&&(e=t.alternate,e!==null&&(e=e.memoizedState,e!==null))){e=e.dehydrated;try{Qa(e)}catch(l){Te(t,t.return,l)}}}function Vo(e,t){if(t.memoizedState===null&&(e=t.alternate,e!==null&&(e=e.memoizedState,e!==null&&(e=e.dehydrated,e!==null))))try{Qa(e)}catch(l){Te(t,t.return,l)}}function Ev(e){switch(e.tag){case 31:case 13:case 19:var t=e.stateNode;return t===null&&(t=e.stateNode=new Yo),t;case 22:return e=e.stateNode,t=e._retryCache,t===null&&(t=e._retryCache=new Yo),t;default:throw Error(r(435,e.tag))}}function Zu(e,t){var l=Ev(e);t.forEach(function(a){if(!l.has(a)){l.add(a);var n=Ov.bind(null,e,a);a.then(n,n)}})}function rt(e,t){var l=t.deletions;if(l!==null)for(var a=0;a<l.length;a++){var n=l[a],u=e,c=t,o=c;e:for(;o!==null;){switch(o.tag){case 27:if(Ml(o.type)){De=o.stateNode,ct=!1;break e}break;case 5:De=o.stateNode,ct=!1;break e;case 3:case 4:De=o.stateNode.containerInfo,ct=!0;break e}o=o.return}if(De===null)throw Error(r(160));Qo(u,c,n),De=null,ct=!1,u=n.alternate,u!==null&&(u.return=null),n.return=null}if(t.subtreeFlags&13886)for(t=t.child;t!==null;)Ko(t,e),t=t.sibling}var Ht=null;function Ko(e,t){var l=e.alternate,a=e.flags;switch(e.tag){case 0:case 11:case 14:case 15:rt(t,e),ft(e),a&4&&(zl(3,e,e.return),An(3,e),zl(5,e,e.return));break;case 1:rt(t,e),ft(e),a&512&&(Ze||l===null||Qt(l,l.return)),a&64&&al&&(e=e.updateQueue,e!==null&&(a=e.callbacks,a!==null&&(l=e.shared.hiddenCallbacks,e.shared.hiddenCallbacks=l===null?a:l.concat(a))));break;case 26:var n=Ht;if(rt(t,e),ft(e),a&512&&(Ze||l===null||Qt(l,l.return)),a&4){var u=l!==null?l.memoizedState:null;if(a=e.memoizedState,l===null)if(a===null)if(e.stateNode===null){e:{a=e.type,l=e.memoizedProps,n=n.ownerDocument||n;t:switch(a){case"title":u=n.getElementsByTagName("title")[0],(!u||u[tn]||u[We]||u.namespaceURI==="http://www.w3.org/2000/svg"||u.hasAttribute("itemprop"))&&(u=n.createElement(a),n.head.insertBefore(u,n.querySelector("head > title"))),et(u,a,l),u[We]=e,Je(u),a=u;break e;case"link":var c=Kd("link","href",n).get(a+(l.href||""));if(c){for(var o=0;o<c.length;o++)if(u=c[o],u.getAttribute("href")===(l.href==null||l.href===""?null:l.href)&&u.getAttribute("rel")===(l.rel==null?null:l.rel)&&u.getAttribute("title")===(l.title==null?null:l.title)&&u.getAttribute("crossorigin")===(l.crossOrigin==null?null:l.crossOrigin)){c.splice(o,1);break t}}u=n.createElement(a),et(u,a,l),n.head.appendChild(u);break;case"meta":if(c=Kd("meta","content",n).get(a+(l.content||""))){for(o=0;o<c.length;o++)if(u=c[o],u.getAttribute("content")===(l.content==null?null:""+l.content)&&u.getAttribute("name")===(l.name==null?null:l.name)&&u.getAttribute("property")===(l.property==null?null:l.property)&&u.getAttribute("http-equiv")===(l.httpEquiv==null?null:l.httpEquiv)&&u.getAttribute("charset")===(l.charSet==null?null:l.charSet)){c.splice(o,1);break t}}u=n.createElement(a),et(u,a,l),n.head.appendChild(u);break;default:throw Error(r(468,a))}u[We]=e,Je(u),a=u}e.stateNode=a}else Jd(n,e.type,e.stateNode);else e.stateNode=Vd(n,a,e.memoizedProps);else u!==a?(u===null?l.stateNode!==null&&(l=l.stateNode,l.parentNode.removeChild(l)):u.count--,a===null?Jd(n,e.type,e.stateNode):Vd(n,a,e.memoizedProps)):a===null&&e.stateNode!==null&&Fc(e,e.memoizedProps,l.memoizedProps)}break;case 27:rt(t,e),ft(e),a&512&&(Ze||l===null||Qt(l,l.return)),l!==null&&a&4&&Fc(e,e.memoizedProps,l.memoizedProps);break;case 5:if(rt(t,e),ft(e),a&512&&(Ze||l===null||Qt(l,l.return)),e.flags&32){n=e.stateNode;try{da(n,"")}catch(V){Te(e,e.return,V)}}a&4&&e.stateNode!=null&&(n=e.memoizedProps,Fc(e,n,l!==null?l.memoizedProps:n)),a&1024&&(er=!0);break;case 6:if(rt(t,e),ft(e),a&4){if(e.stateNode===null)throw Error(r(162));a=e.memoizedProps,l=e.stateNode;try{l.nodeValue=a}catch(V){Te(e,e.return,V)}}break;case 3:if(ii=null,n=Ht,Ht=ni(t.containerInfo),rt(t,e),Ht=n,ft(e),a&4&&l!==null&&l.memoizedState.isDehydrated)try{Qa(t.containerInfo)}catch(V){Te(e,e.return,V)}er&&(er=!1,Jo(e));break;case 4:a=Ht,Ht=ni(e.stateNode.containerInfo),rt(t,e),ft(e),Ht=a;break;case 12:rt(t,e),ft(e);break;case 31:rt(t,e),ft(e),a&4&&(a=e.updateQueue,a!==null&&(e.updateQueue=null,Zu(e,a)));break;case 13:rt(t,e),ft(e),e.child.flags&8192&&e.memoizedState!==null!=(l!==null&&l.memoizedState!==null)&&(Ku=be()),a&4&&(a=e.updateQueue,a!==null&&(e.updateQueue=null,Zu(e,a)));break;case 22:n=e.memoizedState!==null;var v=l!==null&&l.memoizedState!==null,j=al,M=Ze;if(al=j||n,Ze=M||v,rt(t,e),Ze=M,al=j,ft(e),a&8192)e:for(t=e.stateNode,t._visibility=n?t._visibility&-2:t._visibility|1,n&&(l===null||v||al||Ze||aa(e)),l=null,t=e;;){if(t.tag===5||t.tag===26){if(l===null){v=l=t;try{if(u=v.stateNode,n)c=u.style,typeof c.setProperty=="function"?c.setProperty("display","none","important"):c.display="none";else{o=v.stateNode;var H=v.memoizedProps.style,_=H!=null&&H.hasOwnProperty("display")?H.display:null;o.style.display=_==null||typeof _=="boolean"?"":(""+_).trim()}}catch(V){Te(v,v.return,V)}}}else if(t.tag===6){if(l===null){v=t;try{v.stateNode.nodeValue=n?"":v.memoizedProps}catch(V){Te(v,v.return,V)}}}else if(t.tag===18){if(l===null){v=t;try{var C=v.stateNode;n?Bd(C,!0):Bd(v.stateNode,!1)}catch(V){Te(v,v.return,V)}}}else if((t.tag!==22&&t.tag!==23||t.memoizedState===null||t===e)&&t.child!==null){t.child.return=t,t=t.child;continue}if(t===e)break e;for(;t.sibling===null;){if(t.return===null||t.return===e)break e;l===t&&(l=null),t=t.return}l===t&&(l=null),t.sibling.return=t.return,t=t.sibling}a&4&&(a=e.updateQueue,a!==null&&(l=a.retryQueue,l!==null&&(a.retryQueue=null,Zu(e,l))));break;case 19:rt(t,e),ft(e),a&4&&(a=e.updateQueue,a!==null&&(e.updateQueue=null,Zu(e,a)));break;case 30:break;case 21:break;default:rt(t,e),ft(e)}}function ft(e){var t=e.flags;if(t&2){try{for(var l,a=e.return;a!==null;){if(wo(a)){l=a;break}a=a.return}if(l==null)throw Error(r(160));switch(l.tag){case 27:var n=l.stateNode,u=Ic(e);Qu(e,u,n);break;case 5:var c=l.stateNode;l.flags&32&&(da(c,""),l.flags&=-33);var o=Ic(e);Qu(e,o,c);break;case 3:case 4:var v=l.stateNode.containerInfo,j=Ic(e);Pc(e,j,v);break;default:throw Error(r(161))}}catch(M){Te(e,e.return,M)}e.flags&=-3}t&4096&&(e.flags&=-4097)}function Jo(e){if(e.subtreeFlags&1024)for(e=e.child;e!==null;){var t=e;Jo(t),t.tag===5&&t.flags&1024&&t.stateNode.reset(),e=e.sibling}}function ul(e,t){if(t.subtreeFlags&8772)for(t=t.child;t!==null;)Go(e,t.alternate,t),t=t.sibling}function aa(e){for(e=e.child;e!==null;){var t=e;switch(t.tag){case 0:case 11:case 14:case 15:zl(4,t,t.return),aa(t);break;case 1:Qt(t,t.return);var l=t.stateNode;typeof l.componentWillUnmount=="function"&&Bo(t,t.return,l),aa(t);break;case 27:wn(t.stateNode);case 26:case 5:Qt(t,t.return),aa(t);break;case 22:t.memoizedState===null&&aa(t);break;case 30:aa(t);break;default:aa(t)}e=e.sibling}}function il(e,t,l){for(l=l&&(t.subtreeFlags&8772)!==0,t=t.child;t!==null;){var a=t.alternate,n=e,u=t,c=u.flags;switch(u.tag){case 0:case 11:case 15:il(n,u,l),An(4,u);break;case 1:if(il(n,u,l),a=u,n=a.stateNode,typeof n.componentDidMount=="function")try{n.componentDidMount()}catch(j){Te(a,a.return,j)}if(a=u,n=a.updateQueue,n!==null){var o=a.stateNode;try{var v=n.shared.hiddenCallbacks;if(v!==null)for(n.shared.hiddenCallbacks=null,n=0;n<v.length;n++)Ts(v[n],o)}catch(j){Te(a,a.return,j)}}l&&c&64&&Ho(u),Cn(u,u.return);break;case 27:qo(u);case 26:case 5:il(n,u,l),l&&a===null&&c&4&&Lo(u),Cn(u,u.return);break;case 12:il(n,u,l);break;case 31:il(n,u,l),l&&c&4&&Zo(n,u);break;case 13:il(n,u,l),l&&c&4&&Vo(n,u);break;case 22:u.memoizedState===null&&il(n,u,l),Cn(u,u.return);break;case 30:break;default:il(n,u,l)}t=t.sibling}}function tr(e,t){var l=null;e!==null&&e.memoizedState!==null&&e.memoizedState.cachePool!==null&&(l=e.memoizedState.cachePool.pool),e=null,t.memoizedState!==null&&t.memoizedState.cachePool!==null&&(e=t.memoizedState.cachePool.pool),e!==l&&(e!=null&&e.refCount++,l!=null&&vn(l))}function lr(e,t){e=null,t.alternate!==null&&(e=t.alternate.memoizedState.cache),t=t.memoizedState.cache,t!==e&&(t.refCount++,e!=null&&vn(e))}function Bt(e,t,l,a){if(t.subtreeFlags&10256)for(t=t.child;t!==null;)ko(e,t,l,a),t=t.sibling}function ko(e,t,l,a){var n=t.flags;switch(t.tag){case 0:case 11:case 15:Bt(e,t,l,a),n&2048&&An(9,t);break;case 1:Bt(e,t,l,a);break;case 3:Bt(e,t,l,a),n&2048&&(e=null,t.alternate!==null&&(e=t.alternate.memoizedState.cache),t=t.memoizedState.cache,t!==e&&(t.refCount++,e!=null&&vn(e)));break;case 12:if(n&2048){Bt(e,t,l,a),e=t.stateNode;try{var u=t.memoizedProps,c=u.id,o=u.onPostCommit;typeof o=="function"&&o(c,t.alternate===null?"mount":"update",e.passiveEffectDuration,-0)}catch(v){Te(t,t.return,v)}}else Bt(e,t,l,a);break;case 31:Bt(e,t,l,a);break;case 13:Bt(e,t,l,a);break;case 23:break;case 22:u=t.stateNode,c=t.alternate,t.memoizedState!==null?u._visibility&2?Bt(e,t,l,a):Rn(e,t):u._visibility&2?Bt(e,t,l,a):(u._visibility|=2,Ma(e,t,l,a,(t.subtreeFlags&10256)!==0||!1)),n&2048&&tr(c,t);break;case 24:Bt(e,t,l,a),n&2048&&lr(t.alternate,t);break;default:Bt(e,t,l,a)}}function Ma(e,t,l,a,n){for(n=n&&((t.subtreeFlags&10256)!==0||!1),t=t.child;t!==null;){var u=e,c=t,o=l,v=a,j=c.flags;switch(c.tag){case 0:case 11:case 15:Ma(u,c,o,v,n),An(8,c);break;case 23:break;case 22:var M=c.stateNode;c.memoizedState!==null?M._visibility&2?Ma(u,c,o,v,n):Rn(u,c):(M._visibility|=2,Ma(u,c,o,v,n)),n&&j&2048&&tr(c.alternate,c);break;case 24:Ma(u,c,o,v,n),n&&j&2048&&lr(c.alternate,c);break;default:Ma(u,c,o,v,n)}t=t.sibling}}function Rn(e,t){if(t.subtreeFlags&10256)for(t=t.child;t!==null;){var l=e,a=t,n=a.flags;switch(a.tag){case 22:Rn(l,a),n&2048&&tr(a.alternate,a);break;case 24:Rn(l,a),n&2048&&lr(a.alternate,a);break;default:Rn(l,a)}t=t.sibling}}var On=8192;function Da(e,t,l){if(e.subtreeFlags&On)for(e=e.child;e!==null;)$o(e,t,l),e=e.sibling}function $o(e,t,l){switch(e.tag){case 26:Da(e,t,l),e.flags&On&&e.memoizedState!==null&&ry(l,Ht,e.memoizedState,e.memoizedProps);break;case 5:Da(e,t,l);break;case 3:case 4:var a=Ht;Ht=ni(e.stateNode.containerInfo),Da(e,t,l),Ht=a;break;case 22:e.memoizedState===null&&(a=e.alternate,a!==null&&a.memoizedState!==null?(a=On,On=16777216,Da(e,t,l),On=a):Da(e,t,l));break;default:Da(e,t,l)}}function Wo(e){var t=e.alternate;if(t!==null&&(e=t.child,e!==null)){t.child=null;do t=e.sibling,e.sibling=null,e=t;while(e!==null)}}function Mn(e){var t=e.deletions;if((e.flags&16)!==0){if(t!==null)for(var l=0;l<t.length;l++){var a=t[l];ke=a,Io(a,e)}Wo(e)}if(e.subtreeFlags&10256)for(e=e.child;e!==null;)Fo(e),e=e.sibling}function Fo(e){switch(e.tag){case 0:case 11:case 15:Mn(e),e.flags&2048&&zl(9,e,e.return);break;case 3:Mn(e);break;case 12:Mn(e);break;case 22:var t=e.stateNode;e.memoizedState!==null&&t._visibility&2&&(e.return===null||e.return.tag!==13)?(t._visibility&=-3,Vu(e)):Mn(e);break;default:Mn(e)}}function Vu(e){var t=e.deletions;if((e.flags&16)!==0){if(t!==null)for(var l=0;l<t.length;l++){var a=t[l];ke=a,Io(a,e)}Wo(e)}for(e=e.child;e!==null;){switch(t=e,t.tag){case 0:case 11:case 15:zl(8,t,t.return),Vu(t);break;case 22:l=t.stateNode,l._visibility&2&&(l._visibility&=-3,Vu(t));break;default:Vu(t)}e=e.sibling}}function Io(e,t){for(;ke!==null;){var l=ke;switch(l.tag){case 0:case 11:case 15:zl(8,l,t);break;case 23:case 22:if(l.memoizedState!==null&&l.memoizedState.cachePool!==null){var a=l.memoizedState.cachePool.pool;a!=null&&a.refCount++}break;case 24:vn(l.memoizedState.cache)}if(a=l.child,a!==null)a.return=l,ke=a;else e:for(l=e;ke!==null;){a=ke;var n=a.sibling,u=a.return;if(Xo(a),a===l){ke=null;break e}if(n!==null){n.return=u,ke=n;break e}ke=u}}}var Tv={getCacheForType:function(e){var t=Ie(Ge),l=t.data.get(e);return l===void 0&&(l=e(),t.data.set(e,l)),l},cacheSignal:function(){return Ie(Ge).controller.signal}},Nv=typeof WeakMap=="function"?WeakMap:Map,xe=0,Ae=null,se=null,de=0,Ee=0,gt=null,jl=!1,Ua=!1,ar=!1,cl=0,we=0,_l=0,na=0,nr=0,bt=0,Ha=0,Dn=null,st=null,ur=!1,Ku=0,Po=0,Ju=1/0,ku=null,Al=null,Ke=0,Cl=null,Ba=null,rl=0,ir=0,cr=null,ed=null,Un=0,rr=null;function xt(){return(xe&2)!==0&&de!==0?de&-de:O.T!==null?hr():vf()}function td(){if(bt===0)if((de&536870912)===0||he){var e=lu;lu<<=1,(lu&3932160)===0&&(lu=262144),bt=e}else bt=536870912;return e=yt.current,e!==null&&(e.flags|=32),bt}function ot(e,t,l){(e===Ae&&(Ee===2||Ee===9)||e.cancelPendingCommit!==null)&&(La(e,0),Rl(e,de,bt,!1)),en(e,l),((xe&2)===0||e!==Ae)&&(e===Ae&&((xe&2)===0&&(na|=l),we===4&&Rl(e,de,bt,!1)),Zt(e))}function ld(e,t,l){if((xe&6)!==0)throw Error(r(327));var a=!l&&(t&127)===0&&(t&e.expiredLanes)===0||Pa(e,t),n=a?_v(e,t):sr(e,t,!0),u=a;do{if(n===0){Ua&&!a&&Rl(e,t,0,!1);break}else{if(l=e.current.alternate,u&&!zv(l)){n=sr(e,t,!1),u=!1;continue}if(n===2){if(u=t,e.errorRecoveryDisabledLanes&u)var c=0;else c=e.pendingLanes&-536870913,c=c!==0?c:c&536870912?536870912:0;if(c!==0){t=c;e:{var o=e;n=Dn;var v=o.current.memoizedState.isDehydrated;if(v&&(La(o,c).flags|=256),c=sr(o,c,!1),c!==2){if(ar&&!v){o.errorRecoveryDisabledLanes|=u,na|=u,n=4;break e}u=st,st=n,u!==null&&(st===null?st=u:st.push.apply(st,u))}n=c}if(u=!1,n!==2)continue}}if(n===1){La(e,0),Rl(e,t,0,!0);break}e:{switch(a=e,u=n,u){case 0:case 1:throw Error(r(345));case 4:if((t&4194048)!==t)break;case 6:Rl(a,t,bt,!jl);break e;case 2:st=null;break;case 3:case 5:break;default:throw Error(r(329))}if((t&62914560)===t&&(n=Ku+300-be(),10<n)){if(Rl(a,t,bt,!jl),nu(a,0,!0)!==0)break e;rl=t,a.timeoutHandle=Dd(ad.bind(null,a,l,st,ku,ur,t,bt,na,Ha,jl,u,"Throttled",-0,0),n);break e}ad(a,l,st,ku,ur,t,bt,na,Ha,jl,u,null,-0,0)}}break}while(!0);Zt(e)}function ad(e,t,l,a,n,u,c,o,v,j,M,H,_,C){if(e.timeoutHandle=-1,H=t.subtreeFlags,H&8192||(H&16785408)===16785408){H={stylesheets:null,count:0,imgCount:0,imgBytes:0,suspenseyImages:[],waitingForImages:!0,waitingForViewTransition:!1,unsuspend:Jt},$o(t,u,H);var V=(u&62914560)===u?Ku-be():(u&4194048)===u?Po-be():0;if(V=fy(H,V),V!==null){rl=u,e.cancelPendingCommit=V(od.bind(null,e,t,u,l,a,n,c,o,v,M,H,null,_,C)),Rl(e,u,c,!j);return}}od(e,t,u,l,a,n,c,o,v)}function zv(e){for(var t=e;;){var l=t.tag;if((l===0||l===11||l===15)&&t.flags&16384&&(l=t.updateQueue,l!==null&&(l=l.stores,l!==null)))for(var a=0;a<l.length;a++){var n=l[a],u=n.getSnapshot;n=n.value;try{if(!ht(u(),n))return!1}catch{return!1}}if(l=t.child,t.subtreeFlags&16384&&l!==null)l.return=t,t=l;else{if(t===e)break;for(;t.sibling===null;){if(t.return===null||t.return===e)return!0;t=t.return}t.sibling.return=t.return,t=t.sibling}}return!0}function Rl(e,t,l,a){t&=~nr,t&=~na,e.suspendedLanes|=t,e.pingedLanes&=~t,a&&(e.warmLanes|=t),a=e.expirationTimes;for(var n=t;0<n;){var u=31-mt(n),c=1<<u;a[u]=-1,n&=~c}l!==0&&df(e,l,t)}function $u(){return(xe&6)===0?(Hn(0),!1):!0}function fr(){if(se!==null){if(Ee===0)var e=se.return;else e=se,Ft=$l=null,zc(e),_a=null,pn=0,e=se;for(;e!==null;)Uo(e.alternate,e),e=e.return;se=null}}function La(e,t){var l=e.timeoutHandle;l!==-1&&(e.timeoutHandle=-1,Vv(l)),l=e.cancelPendingCommit,l!==null&&(e.cancelPendingCommit=null,l()),rl=0,fr(),Ae=e,se=l=$t(e.current,null),de=t,Ee=0,gt=null,jl=!1,Ua=Pa(e,t),ar=!1,Ha=bt=nr=na=_l=we=0,st=Dn=null,ur=!1,(t&8)!==0&&(t|=t&32);var a=e.entangledLanes;if(a!==0)for(e=e.entanglements,a&=t;0<a;){var n=31-mt(a),u=1<<n;t|=e[n],a&=~u}return cl=t,yu(),l}function nd(e,t){ue=null,O.H=zn,t===ja||t===Nu?(t=bs(),Ee=3):t===mc?(t=bs(),Ee=4):Ee=t===Gc?8:t!==null&&typeof t=="object"&&typeof t.then=="function"?6:1,gt=t,se===null&&(we=1,wu(e,zt(t,e.current)))}function ud(){var e=yt.current;return e===null?!0:(de&4194048)===de?Ct===null:(de&62914560)===de||(de&536870912)!==0?e===Ct:!1}function id(){var e=O.H;return O.H=zn,e===null?zn:e}function cd(){var e=O.A;return O.A=Tv,e}function Wu(){we=4,jl||(de&4194048)!==de&&yt.current!==null||(Ua=!0),(_l&134217727)===0&&(na&134217727)===0||Ae===null||Rl(Ae,de,bt,!1)}function sr(e,t,l){var a=xe;xe|=2;var n=id(),u=cd();(Ae!==e||de!==t)&&(ku=null,La(e,t)),t=!1;var c=we;e:do try{if(Ee!==0&&se!==null){var o=se,v=gt;switch(Ee){case 8:fr(),c=6;break e;case 3:case 2:case 9:case 6:yt.current===null&&(t=!0);var j=Ee;if(Ee=0,gt=null,wa(e,o,v,j),l&&Ua){c=0;break e}break;default:j=Ee,Ee=0,gt=null,wa(e,o,v,j)}}jv(),c=we;break}catch(M){nd(e,M)}while(!0);return t&&e.shellSuspendCounter++,Ft=$l=null,xe=a,O.H=n,O.A=u,se===null&&(Ae=null,de=0,yu()),c}function jv(){for(;se!==null;)rd(se)}function _v(e,t){var l=xe;xe|=2;var a=id(),n=cd();Ae!==e||de!==t?(ku=null,Ju=be()+500,La(e,t)):Ua=Pa(e,t);e:do try{if(Ee!==0&&se!==null){t=se;var u=gt;t:switch(Ee){case 1:Ee=0,gt=null,wa(e,t,u,1);break;case 2:case 9:if(ps(u)){Ee=0,gt=null,fd(t);break}t=function(){Ee!==2&&Ee!==9||Ae!==e||(Ee=7),Zt(e)},u.then(t,t);break e;case 3:Ee=7;break e;case 4:Ee=5;break e;case 7:ps(u)?(Ee=0,gt=null,fd(t)):(Ee=0,gt=null,wa(e,t,u,7));break;case 5:var c=null;switch(se.tag){case 26:c=se.memoizedState;case 5:case 27:var o=se;if(c?kd(c):o.stateNode.complete){Ee=0,gt=null;var v=o.sibling;if(v!==null)se=v;else{var j=o.return;j!==null?(se=j,Fu(j)):se=null}break t}}Ee=0,gt=null,wa(e,t,u,5);break;case 6:Ee=0,gt=null,wa(e,t,u,6);break;case 8:fr(),we=6;break e;default:throw Error(r(462))}}Av();break}catch(M){nd(e,M)}while(!0);return Ft=$l=null,O.H=a,O.A=n,xe=l,se!==null?0:(Ae=null,de=0,yu(),we)}function Av(){for(;se!==null&&!In();)rd(se)}function rd(e){var t=Mo(e.alternate,e,cl);e.memoizedProps=e.pendingProps,t===null?Fu(e):se=t}function fd(e){var t=e,l=t.alternate;switch(t.tag){case 15:case 0:t=jo(l,t,t.pendingProps,t.type,void 0,de);break;case 11:t=jo(l,t,t.pendingProps,t.type.render,t.ref,de);break;case 5:zc(t);default:Uo(l,t),t=se=is(t,cl),t=Mo(l,t,cl)}e.memoizedProps=e.pendingProps,t===null?Fu(e):se=t}function wa(e,t,l,a){Ft=$l=null,zc(t),_a=null,pn=0;var n=t.return;try{if(yv(e,n,t,l,de)){we=1,wu(e,zt(l,e.current)),se=null;return}}catch(u){if(n!==null)throw se=n,u;we=1,wu(e,zt(l,e.current)),se=null;return}t.flags&32768?(he||a===1?e=!0:Ua||(de&536870912)!==0?e=!1:(jl=e=!0,(a===2||a===9||a===3||a===6)&&(a=yt.current,a!==null&&a.tag===13&&(a.flags|=16384))),sd(t,e)):Fu(t)}function Fu(e){var t=e;do{if((t.flags&32768)!==0){sd(t,jl);return}e=t.return;var l=bv(t.alternate,t,cl);if(l!==null){se=l;return}if(t=t.sibling,t!==null){se=t;return}se=t=e}while(t!==null);we===0&&(we=5)}function sd(e,t){do{var l=xv(e.alternate,e);if(l!==null){l.flags&=32767,se=l;return}if(l=e.return,l!==null&&(l.flags|=32768,l.subtreeFlags=0,l.deletions=null),!t&&(e=e.sibling,e!==null)){se=e;return}se=e=l}while(e!==null);we=6,se=null}function od(e,t,l,a,n,u,c,o,v){e.cancelPendingCommit=null;do Iu();while(Ke!==0);if((xe&6)!==0)throw Error(r(327));if(t!==null){if(t===e.current)throw Error(r(177));if(u=t.lanes|t.childLanes,u|=Ii,ch(e,l,u,c,o,v),e===Ae&&(se=Ae=null,de=0),Ba=t,Cl=e,rl=l,ir=u,cr=n,ed=a,(t.subtreeFlags&10256)!==0||(t.flags&10256)!==0?(e.callbackNode=null,e.callbackPriority=0,Mv(eu,function(){return yd(),null})):(e.callbackNode=null,e.callbackPriority=0),a=(t.flags&13878)!==0,(t.subtreeFlags&13878)!==0||a){a=O.T,O.T=null,n=G.p,G.p=2,c=xe,xe|=4;try{Sv(e,t,l)}finally{xe=c,G.p=n,O.T=a}}Ke=1,dd(),md(),hd()}}function dd(){if(Ke===1){Ke=0;var e=Cl,t=Ba,l=(t.flags&13878)!==0;if((t.subtreeFlags&13878)!==0||l){l=O.T,O.T=null;var a=G.p;G.p=2;var n=xe;xe|=4;try{Ko(t,e);var u=Er,c=Ff(e.containerInfo),o=u.focusedElem,v=u.selectionRange;if(c!==o&&o&&o.ownerDocument&&Wf(o.ownerDocument.documentElement,o)){if(v!==null&&Ji(o)){var j=v.start,M=v.end;if(M===void 0&&(M=j),"selectionStart"in o)o.selectionStart=j,o.selectionEnd=Math.min(M,o.value.length);else{var H=o.ownerDocument||document,_=H&&H.defaultView||window;if(_.getSelection){var C=_.getSelection(),V=o.textContent.length,P=Math.min(v.start,V),je=v.end===void 0?P:Math.min(v.end,V);!C.extend&&P>je&&(c=je,je=P,P=c);var T=$f(o,P),p=$f(o,je);if(T&&p&&(C.rangeCount!==1||C.anchorNode!==T.node||C.anchorOffset!==T.offset||C.focusNode!==p.node||C.focusOffset!==p.offset)){var z=H.createRange();z.setStart(T.node,T.offset),C.removeAllRanges(),P>je?(C.addRange(z),C.extend(p.node,p.offset)):(z.setEnd(p.node,p.offset),C.addRange(z))}}}}for(H=[],C=o;C=C.parentNode;)C.nodeType===1&&H.push({element:C,left:C.scrollLeft,top:C.scrollTop});for(typeof o.focus=="function"&&o.focus(),o=0;o<H.length;o++){var D=H[o];D.element.scrollLeft=D.left,D.element.scrollTop=D.top}}si=!!Sr,Er=Sr=null}finally{xe=n,G.p=a,O.T=l}}e.current=t,Ke=2}}function md(){if(Ke===2){Ke=0;var e=Cl,t=Ba,l=(t.flags&8772)!==0;if((t.subtreeFlags&8772)!==0||l){l=O.T,O.T=null;var a=G.p;G.p=2;var n=xe;xe|=4;try{Go(e,t.alternate,t)}finally{xe=n,G.p=a,O.T=l}}Ke=3}}function hd(){if(Ke===4||Ke===3){Ke=0,Pn();var e=Cl,t=Ba,l=rl,a=ed;(t.subtreeFlags&10256)!==0||(t.flags&10256)!==0?Ke=5:(Ke=0,Ba=Cl=null,vd(e,e.pendingLanes));var n=e.pendingLanes;if(n===0&&(Al=null),Ai(l),t=t.stateNode,dt&&typeof dt.onCommitFiberRoot=="function")try{dt.onCommitFiberRoot(Ia,t,void 0,(t.current.flags&128)===128)}catch{}if(a!==null){t=O.T,n=G.p,G.p=2,O.T=null;try{for(var u=e.onRecoverableError,c=0;c<a.length;c++){var o=a[c];u(o.value,{componentStack:o.stack})}}finally{O.T=t,G.p=n}}(rl&3)!==0&&Iu(),Zt(e),n=e.pendingLanes,(l&261930)!==0&&(n&42)!==0?e===rr?Un++:(Un=0,rr=e):Un=0,Hn(0)}}function vd(e,t){(e.pooledCacheLanes&=t)===0&&(t=e.pooledCache,t!=null&&(e.pooledCache=null,vn(t)))}function Iu(){return dd(),md(),hd(),yd()}function yd(){if(Ke!==5)return!1;var e=Cl,t=ir;ir=0;var l=Ai(rl),a=O.T,n=G.p;try{G.p=32>l?32:l,O.T=null,l=cr,cr=null;var u=Cl,c=rl;if(Ke=0,Ba=Cl=null,rl=0,(xe&6)!==0)throw Error(r(331));var o=xe;if(xe|=4,Fo(u.current),ko(u,u.current,c,l),xe=o,Hn(0,!1),dt&&typeof dt.onPostCommitFiberRoot=="function")try{dt.onPostCommitFiberRoot(Ia,u)}catch{}return!0}finally{G.p=n,O.T=a,vd(e,t)}}function pd(e,t,l){t=zt(l,t),t=Yc(e.stateNode,t,2),e=El(e,t,2),e!==null&&(en(e,2),Zt(e))}function Te(e,t,l){if(e.tag===3)pd(e,e,l);else for(;t!==null;){if(t.tag===3){pd(t,e,l);break}else if(t.tag===1){var a=t.stateNode;if(typeof t.type.getDerivedStateFromError=="function"||typeof a.componentDidCatch=="function"&&(Al===null||!Al.has(a))){e=zt(l,e),l=go(2),a=El(t,l,2),a!==null&&(bo(l,a,t,e),en(a,2),Zt(a));break}}t=t.return}}function or(e,t,l){var a=e.pingCache;if(a===null){a=e.pingCache=new Nv;var n=new Set;a.set(t,n)}else n=a.get(t),n===void 0&&(n=new Set,a.set(t,n));n.has(l)||(ar=!0,n.add(l),e=Cv.bind(null,e,t,l),t.then(e,e))}function Cv(e,t,l){var a=e.pingCache;a!==null&&a.delete(t),e.pingedLanes|=e.suspendedLanes&l,e.warmLanes&=~l,Ae===e&&(de&l)===l&&(we===4||we===3&&(de&62914560)===de&&300>be()-Ku?(xe&2)===0&&La(e,0):nr|=l,Ha===de&&(Ha=0)),Zt(e)}function gd(e,t){t===0&&(t=of()),e=Kl(e,t),e!==null&&(en(e,t),Zt(e))}function Rv(e){var t=e.memoizedState,l=0;t!==null&&(l=t.retryLane),gd(e,l)}function Ov(e,t){var l=0;switch(e.tag){case 31:case 13:var a=e.stateNode,n=e.memoizedState;n!==null&&(l=n.retryLane);break;case 19:a=e.stateNode;break;case 22:a=e.stateNode._retryCache;break;default:throw Error(r(314))}a!==null&&a.delete(t),gd(e,l)}function Mv(e,t){return Dt(e,t)}var Pu=null,qa=null,dr=!1,ei=!1,mr=!1,Ol=0;function Zt(e){e!==qa&&e.next===null&&(qa===null?Pu=qa=e:qa=qa.next=e),ei=!0,dr||(dr=!0,Uv())}function Hn(e,t){if(!mr&&ei){mr=!0;do for(var l=!1,a=Pu;a!==null;){if(e!==0){var n=a.pendingLanes;if(n===0)var u=0;else{var c=a.suspendedLanes,o=a.pingedLanes;u=(1<<31-mt(42|e)+1)-1,u&=n&~(c&~o),u=u&201326741?u&201326741|1:u?u|2:0}u!==0&&(l=!0,Ed(a,u))}else u=de,u=nu(a,a===Ae?u:0,a.cancelPendingCommit!==null||a.timeoutHandle!==-1),(u&3)===0||Pa(a,u)||(l=!0,Ed(a,u));a=a.next}while(l);mr=!1}}function Dv(){bd()}function bd(){ei=dr=!1;var e=0;Ol!==0&&Zv()&&(e=Ol);for(var t=be(),l=null,a=Pu;a!==null;){var n=a.next,u=xd(a,t);u===0?(a.next=null,l===null?Pu=n:l.next=n,n===null&&(qa=l)):(l=a,(e!==0||(u&3)!==0)&&(ei=!0)),a=n}Ke!==0&&Ke!==5||Hn(e),Ol!==0&&(Ol=0)}function xd(e,t){for(var l=e.suspendedLanes,a=e.pingedLanes,n=e.expirationTimes,u=e.pendingLanes&-62914561;0<u;){var c=31-mt(u),o=1<<c,v=n[c];v===-1?((o&l)===0||(o&a)!==0)&&(n[c]=ih(o,t)):v<=t&&(e.expiredLanes|=o),u&=~o}if(t=Ae,l=de,l=nu(e,e===t?l:0,e.cancelPendingCommit!==null||e.timeoutHandle!==-1),a=e.callbackNode,l===0||e===t&&(Ee===2||Ee===9)||e.cancelPendingCommit!==null)return a!==null&&a!==null&&Yt(a),e.callbackNode=null,e.callbackPriority=0;if((l&3)===0||Pa(e,l)){if(t=l&-l,t===e.callbackPriority)return t;switch(a!==null&&Yt(a),Ai(l)){case 2:case 8:l=ff;break;case 32:l=eu;break;case 268435456:l=sf;break;default:l=eu}return a=Sd.bind(null,e),l=Dt(l,a),e.callbackPriority=t,e.callbackNode=l,t}return a!==null&&a!==null&&Yt(a),e.callbackPriority=2,e.callbackNode=null,2}function Sd(e,t){if(Ke!==0&&Ke!==5)return e.callbackNode=null,e.callbackPriority=0,null;var l=e.callbackNode;if(Iu()&&e.callbackNode!==l)return null;var a=de;return a=nu(e,e===Ae?a:0,e.cancelPendingCommit!==null||e.timeoutHandle!==-1),a===0?null:(ld(e,a,t),xd(e,be()),e.callbackNode!=null&&e.callbackNode===l?Sd.bind(null,e):null)}function Ed(e,t){if(Iu())return null;ld(e,t,!0)}function Uv(){Kv(function(){(xe&6)!==0?Dt(rf,Dv):bd()})}function hr(){if(Ol===0){var e=Na;e===0&&(e=tu,tu<<=1,(tu&261888)===0&&(tu=256)),Ol=e}return Ol}function Td(e){return e==null||typeof e=="symbol"||typeof e=="boolean"?null:typeof e=="function"?e:ru(""+e)}function Nd(e,t){var l=t.ownerDocument.createElement("input");return l.name=t.name,l.value=t.value,e.id&&l.setAttribute("form",e.id),t.parentNode.insertBefore(l,t),e=new FormData(e),l.parentNode.removeChild(l),e}function Hv(e,t,l,a,n){if(t==="submit"&&l&&l.stateNode===n){var u=Td((n[ut]||null).action),c=a.submitter;c&&(t=(t=c[ut]||null)?Td(t.formAction):c.getAttribute("formAction"),t!==null&&(u=t,c=null));var o=new du("action","action",null,a,n);e.push({event:o,listeners:[{instance:null,listener:function(){if(a.defaultPrevented){if(Ol!==0){var v=c?Nd(n,c):new FormData(n);Uc(l,{pending:!0,data:v,method:n.method,action:u},null,v)}}else typeof u=="function"&&(o.preventDefault(),v=c?Nd(n,c):new FormData(n),Uc(l,{pending:!0,data:v,method:n.method,action:u},u,v))},currentTarget:n}]})}}for(var vr=0;vr<Fi.length;vr++){var yr=Fi[vr],Bv=yr.toLowerCase(),Lv=yr[0].toUpperCase()+yr.slice(1);Ut(Bv,"on"+Lv)}Ut(es,"onAnimationEnd"),Ut(ts,"onAnimationIteration"),Ut(ls,"onAnimationStart"),Ut("dblclick","onDoubleClick"),Ut("focusin","onFocus"),Ut("focusout","onBlur"),Ut(Ph,"onTransitionRun"),Ut(ev,"onTransitionStart"),Ut(tv,"onTransitionCancel"),Ut(as,"onTransitionEnd"),sa("onMouseEnter",["mouseout","mouseover"]),sa("onMouseLeave",["mouseout","mouseover"]),sa("onPointerEnter",["pointerout","pointerover"]),sa("onPointerLeave",["pointerout","pointerover"]),Xl("onChange","change click focusin focusout input keydown keyup selectionchange".split(" ")),Xl("onSelect","focusout contextmenu dragend focusin keydown keyup mousedown mouseup selectionchange".split(" ")),Xl("onBeforeInput",["compositionend","keypress","textInput","paste"]),Xl("onCompositionEnd","compositionend focusout keydown keypress keyup mousedown".split(" ")),Xl("onCompositionStart","compositionstart focusout keydown keypress keyup mousedown".split(" ")),Xl("onCompositionUpdate","compositionupdate focusout keydown keypress keyup mousedown".split(" "));var Bn="abort canplay canplaythrough durationchange emptied encrypted ended error loadeddata loadedmetadata loadstart pause play playing progress ratechange resize seeked seeking stalled suspend timeupdate volumechange waiting".split(" "),wv=new Set("beforetoggle cancel close invalid load scroll scrollend toggle".split(" ").concat(Bn));function zd(e,t){t=(t&4)!==0;for(var l=0;l<e.length;l++){var a=e[l],n=a.event;a=a.listeners;e:{var u=void 0;if(t)for(var c=a.length-1;0<=c;c--){var o=a[c],v=o.instance,j=o.currentTarget;if(o=o.listener,v!==u&&n.isPropagationStopped())break e;u=o,n.currentTarget=j;try{u(n)}catch(M){vu(M)}n.currentTarget=null,u=v}else for(c=0;c<a.length;c++){if(o=a[c],v=o.instance,j=o.currentTarget,o=o.listener,v!==u&&n.isPropagationStopped())break e;u=o,n.currentTarget=j;try{u(n)}catch(M){vu(M)}n.currentTarget=null,u=v}}}}function oe(e,t){var l=t[Ci];l===void 0&&(l=t[Ci]=new Set);var a=e+"__bubble";l.has(a)||(jd(t,e,2,!1),l.add(a))}function pr(e,t,l){var a=0;t&&(a|=4),jd(l,e,a,t)}var ti="_reactListening"+Math.random().toString(36).slice(2);function gr(e){if(!e[ti]){e[ti]=!0,gf.forEach(function(l){l!=="selectionchange"&&(wv.has(l)||pr(l,!1,e),pr(l,!0,e))});var t=e.nodeType===9?e:e.ownerDocument;t===null||t[ti]||(t[ti]=!0,pr("selectionchange",!1,t))}}function jd(e,t,l,a){switch(tm(t)){case 2:var n=dy;break;case 8:n=my;break;default:n=Dr}l=n.bind(null,t,l,e),n=void 0,!wi||t!=="touchstart"&&t!=="touchmove"&&t!=="wheel"||(n=!0),a?n!==void 0?e.addEventListener(t,l,{capture:!0,passive:n}):e.addEventListener(t,l,!0):n!==void 0?e.addEventListener(t,l,{passive:n}):e.addEventListener(t,l,!1)}function br(e,t,l,a,n){var u=a;if((t&1)===0&&(t&2)===0&&a!==null)e:for(;;){if(a===null)return;var c=a.tag;if(c===3||c===4){var o=a.stateNode.containerInfo;if(o===n)break;if(c===4)for(c=a.return;c!==null;){var v=c.tag;if((v===3||v===4)&&c.stateNode.containerInfo===n)return;c=c.return}for(;o!==null;){if(c=ca(o),c===null)return;if(v=c.tag,v===5||v===6||v===26||v===27){a=u=c;continue e}o=o.parentNode}}a=a.return}Rf(function(){var j=u,M=Bi(l),H=[];e:{var _=ns.get(e);if(_!==void 0){var C=du,V=e;switch(e){case"keypress":if(su(l)===0)break e;case"keydown":case"keyup":C=Oh;break;case"focusin":V="focus",C=Xi;break;case"focusout":V="blur",C=Xi;break;case"beforeblur":case"afterblur":C=Xi;break;case"click":if(l.button===2)break e;case"auxclick":case"dblclick":case"mousedown":case"mousemove":case"mouseup":case"mouseout":case"mouseover":case"contextmenu":C=Df;break;case"drag":case"dragend":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"dragstart":case"drop":C=bh;break;case"touchcancel":case"touchend":case"touchmove":case"touchstart":C=Uh;break;case es:case ts:case ls:C=Eh;break;case as:C=Bh;break;case"scroll":case"scrollend":C=ph;break;case"wheel":C=wh;break;case"copy":case"cut":case"paste":C=Nh;break;case"gotpointercapture":case"lostpointercapture":case"pointercancel":case"pointerdown":case"pointermove":case"pointerout":case"pointerover":case"pointerup":C=Hf;break;case"toggle":case"beforetoggle":C=Yh}var P=(t&4)!==0,je=!P&&(e==="scroll"||e==="scrollend"),T=P?_!==null?_+"Capture":null:_;P=[];for(var p=j,z;p!==null;){var D=p;if(z=D.stateNode,D=D.tag,D!==5&&D!==26&&D!==27||z===null||T===null||(D=an(p,T),D!=null&&P.push(Ln(p,D,z))),je)break;p=p.return}0<P.length&&(_=new C(_,V,null,l,M),H.push({event:_,listeners:P}))}}if((t&7)===0){e:{if(_=e==="mouseover"||e==="pointerover",C=e==="mouseout"||e==="pointerout",_&&l!==Hi&&(V=l.relatedTarget||l.fromElement)&&(ca(V)||V[ia]))break e;if((C||_)&&(_=M.window===M?M:(_=M.ownerDocument)?_.defaultView||_.parentWindow:window,C?(V=l.relatedTarget||l.toElement,C=j,V=V?ca(V):null,V!==null&&(je=h(V),P=V.tag,V!==je||P!==5&&P!==27&&P!==6)&&(V=null)):(C=null,V=j),C!==V)){if(P=Df,D="onMouseLeave",T="onMouseEnter",p="mouse",(e==="pointerout"||e==="pointerover")&&(P=Hf,D="onPointerLeave",T="onPointerEnter",p="pointer"),je=C==null?_:ln(C),z=V==null?_:ln(V),_=new P(D,p+"leave",C,l,M),_.target=je,_.relatedTarget=z,D=null,ca(M)===j&&(P=new P(T,p+"enter",V,l,M),P.target=z,P.relatedTarget=je,D=P),je=D,C&&V)t:{for(P=qv,T=C,p=V,z=0,D=T;D;D=P(D))z++;D=0;for(var W=p;W;W=P(W))D++;for(;0<z-D;)T=P(T),z--;for(;0<D-z;)p=P(p),D--;for(;z--;){if(T===p||p!==null&&T===p.alternate){P=T;break t}T=P(T),p=P(p)}P=null}else P=null;C!==null&&_d(H,_,C,P,!1),V!==null&&je!==null&&_d(H,je,V,P,!0)}}e:{if(_=j?ln(j):window,C=_.nodeName&&_.nodeName.toLowerCase(),C==="select"||C==="input"&&_.type==="file")var ye=Qf;else if(Gf(_))if(Zf)ye=Wh;else{ye=kh;var J=Jh}else C=_.nodeName,!C||C.toLowerCase()!=="input"||_.type!=="checkbox"&&_.type!=="radio"?j&&Ui(j.elementType)&&(ye=Qf):ye=$h;if(ye&&(ye=ye(e,j))){Xf(H,ye,l,M);break e}J&&J(e,_,j),e==="focusout"&&j&&_.type==="number"&&j.memoizedProps.value!=null&&Di(_,"number",_.value)}switch(J=j?ln(j):window,e){case"focusin":(Gf(J)||J.contentEditable==="true")&&(ya=J,ki=j,dn=null);break;case"focusout":dn=ki=ya=null;break;case"mousedown":$i=!0;break;case"contextmenu":case"mouseup":case"dragend":$i=!1,If(H,l,M);break;case"selectionchange":if(Ih)break;case"keydown":case"keyup":If(H,l,M)}var ie;if(Zi)e:{switch(e){case"compositionstart":var me="onCompositionStart";break e;case"compositionend":me="onCompositionEnd";break e;case"compositionupdate":me="onCompositionUpdate";break e}me=void 0}else va?qf(e,l)&&(me="onCompositionEnd"):e==="keydown"&&l.keyCode===229&&(me="onCompositionStart");me&&(Bf&&l.locale!=="ko"&&(va||me!=="onCompositionStart"?me==="onCompositionEnd"&&va&&(ie=Of()):(vl=M,qi="value"in vl?vl.value:vl.textContent,va=!0)),J=li(j,me),0<J.length&&(me=new Uf(me,e,null,l,M),H.push({event:me,listeners:J}),ie?me.data=ie:(ie=Yf(l),ie!==null&&(me.data=ie)))),(ie=Xh?Qh(e,l):Zh(e,l))&&(me=li(j,"onBeforeInput"),0<me.length&&(J=new Uf("onBeforeInput","beforeinput",null,l,M),H.push({event:J,listeners:me}),J.data=ie)),Hv(H,e,j,l,M)}zd(H,t)})}function Ln(e,t,l){return{instance:e,listener:t,currentTarget:l}}function li(e,t){for(var l=t+"Capture",a=[];e!==null;){var n=e,u=n.stateNode;if(n=n.tag,n!==5&&n!==26&&n!==27||u===null||(n=an(e,l),n!=null&&a.unshift(Ln(e,n,u)),n=an(e,t),n!=null&&a.push(Ln(e,n,u))),e.tag===3)return a;e=e.return}return[]}function qv(e){if(e===null)return null;do e=e.return;while(e&&e.tag!==5&&e.tag!==27);return e||null}function _d(e,t,l,a,n){for(var u=t._reactName,c=[];l!==null&&l!==a;){var o=l,v=o.alternate,j=o.stateNode;if(o=o.tag,v!==null&&v===a)break;o!==5&&o!==26&&o!==27||j===null||(v=j,n?(j=an(l,u),j!=null&&c.unshift(Ln(l,j,v))):n||(j=an(l,u),j!=null&&c.push(Ln(l,j,v)))),l=l.return}c.length!==0&&e.push({event:t,listeners:c})}var Yv=/\r\n?/g,Gv=/\u0000|\uFFFD/g;function Ad(e){return(typeof e=="string"?e:""+e).replace(Yv,`
`).replace(Gv,"")}function Cd(e,t){return t=Ad(t),Ad(e)===t}function ze(e,t,l,a,n,u){switch(l){case"children":typeof a=="string"?t==="body"||t==="textarea"&&a===""||da(e,a):(typeof a=="number"||typeof a=="bigint")&&t!=="body"&&da(e,""+a);break;case"className":iu(e,"class",a);break;case"tabIndex":iu(e,"tabindex",a);break;case"dir":case"role":case"viewBox":case"width":case"height":iu(e,l,a);break;case"style":Af(e,a,u);break;case"data":if(t!=="object"){iu(e,"data",a);break}case"src":case"href":if(a===""&&(t!=="a"||l!=="href")){e.removeAttribute(l);break}if(a==null||typeof a=="function"||typeof a=="symbol"||typeof a=="boolean"){e.removeAttribute(l);break}a=ru(""+a),e.setAttribute(l,a);break;case"action":case"formAction":if(typeof a=="function"){e.setAttribute(l,"javascript:throw new Error('A React form was unexpectedly submitted. If you called form.submit() manually, consider using form.requestSubmit() instead. If you\\'re trying to use event.stopPropagation() in a submit event handler, consider also calling event.preventDefault().')");break}else typeof u=="function"&&(l==="formAction"?(t!=="input"&&ze(e,t,"name",n.name,n,null),ze(e,t,"formEncType",n.formEncType,n,null),ze(e,t,"formMethod",n.formMethod,n,null),ze(e,t,"formTarget",n.formTarget,n,null)):(ze(e,t,"encType",n.encType,n,null),ze(e,t,"method",n.method,n,null),ze(e,t,"target",n.target,n,null)));if(a==null||typeof a=="symbol"||typeof a=="boolean"){e.removeAttribute(l);break}a=ru(""+a),e.setAttribute(l,a);break;case"onClick":a!=null&&(e.onclick=Jt);break;case"onScroll":a!=null&&oe("scroll",e);break;case"onScrollEnd":a!=null&&oe("scrollend",e);break;case"dangerouslySetInnerHTML":if(a!=null){if(typeof a!="object"||!("__html"in a))throw Error(r(61));if(l=a.__html,l!=null){if(n.children!=null)throw Error(r(60));e.innerHTML=l}}break;case"multiple":e.multiple=a&&typeof a!="function"&&typeof a!="symbol";break;case"muted":e.muted=a&&typeof a!="function"&&typeof a!="symbol";break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"defaultValue":case"defaultChecked":case"innerHTML":case"ref":break;case"autoFocus":break;case"xlinkHref":if(a==null||typeof a=="function"||typeof a=="boolean"||typeof a=="symbol"){e.removeAttribute("xlink:href");break}l=ru(""+a),e.setAttributeNS("http://www.w3.org/1999/xlink","xlink:href",l);break;case"contentEditable":case"spellCheck":case"draggable":case"value":case"autoReverse":case"externalResourcesRequired":case"focusable":case"preserveAlpha":a!=null&&typeof a!="function"&&typeof a!="symbol"?e.setAttribute(l,""+a):e.removeAttribute(l);break;case"inert":case"allowFullScreen":case"async":case"autoPlay":case"controls":case"default":case"defer":case"disabled":case"disablePictureInPicture":case"disableRemotePlayback":case"formNoValidate":case"hidden":case"loop":case"noModule":case"noValidate":case"open":case"playsInline":case"readOnly":case"required":case"reversed":case"scoped":case"seamless":case"itemScope":a&&typeof a!="function"&&typeof a!="symbol"?e.setAttribute(l,""):e.removeAttribute(l);break;case"capture":case"download":a===!0?e.setAttribute(l,""):a!==!1&&a!=null&&typeof a!="function"&&typeof a!="symbol"?e.setAttribute(l,a):e.removeAttribute(l);break;case"cols":case"rows":case"size":case"span":a!=null&&typeof a!="function"&&typeof a!="symbol"&&!isNaN(a)&&1<=a?e.setAttribute(l,a):e.removeAttribute(l);break;case"rowSpan":case"start":a==null||typeof a=="function"||typeof a=="symbol"||isNaN(a)?e.removeAttribute(l):e.setAttribute(l,a);break;case"popover":oe("beforetoggle",e),oe("toggle",e),uu(e,"popover",a);break;case"xlinkActuate":Kt(e,"http://www.w3.org/1999/xlink","xlink:actuate",a);break;case"xlinkArcrole":Kt(e,"http://www.w3.org/1999/xlink","xlink:arcrole",a);break;case"xlinkRole":Kt(e,"http://www.w3.org/1999/xlink","xlink:role",a);break;case"xlinkShow":Kt(e,"http://www.w3.org/1999/xlink","xlink:show",a);break;case"xlinkTitle":Kt(e,"http://www.w3.org/1999/xlink","xlink:title",a);break;case"xlinkType":Kt(e,"http://www.w3.org/1999/xlink","xlink:type",a);break;case"xmlBase":Kt(e,"http://www.w3.org/XML/1998/namespace","xml:base",a);break;case"xmlLang":Kt(e,"http://www.w3.org/XML/1998/namespace","xml:lang",a);break;case"xmlSpace":Kt(e,"http://www.w3.org/XML/1998/namespace","xml:space",a);break;case"is":uu(e,"is",a);break;case"innerText":case"textContent":break;default:(!(2<l.length)||l[0]!=="o"&&l[0]!=="O"||l[1]!=="n"&&l[1]!=="N")&&(l=vh.get(l)||l,uu(e,l,a))}}function xr(e,t,l,a,n,u){switch(l){case"style":Af(e,a,u);break;case"dangerouslySetInnerHTML":if(a!=null){if(typeof a!="object"||!("__html"in a))throw Error(r(61));if(l=a.__html,l!=null){if(n.children!=null)throw Error(r(60));e.innerHTML=l}}break;case"children":typeof a=="string"?da(e,a):(typeof a=="number"||typeof a=="bigint")&&da(e,""+a);break;case"onScroll":a!=null&&oe("scroll",e);break;case"onScrollEnd":a!=null&&oe("scrollend",e);break;case"onClick":a!=null&&(e.onclick=Jt);break;case"suppressContentEditableWarning":case"suppressHydrationWarning":case"innerHTML":case"ref":break;case"innerText":case"textContent":break;default:if(!bf.hasOwnProperty(l))e:{if(l[0]==="o"&&l[1]==="n"&&(n=l.endsWith("Capture"),t=l.slice(2,n?l.length-7:void 0),u=e[ut]||null,u=u!=null?u[l]:null,typeof u=="function"&&e.removeEventListener(t,u,n),typeof a=="function")){typeof u!="function"&&u!==null&&(l in e?e[l]=null:e.hasAttribute(l)&&e.removeAttribute(l)),e.addEventListener(t,a,n);break e}l in e?e[l]=a:a===!0?e.setAttribute(l,""):uu(e,l,a)}}}function et(e,t,l){switch(t){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"img":oe("error",e),oe("load",e);var a=!1,n=!1,u;for(u in l)if(l.hasOwnProperty(u)){var c=l[u];if(c!=null)switch(u){case"src":a=!0;break;case"srcSet":n=!0;break;case"children":case"dangerouslySetInnerHTML":throw Error(r(137,t));default:ze(e,t,u,c,l,null)}}n&&ze(e,t,"srcSet",l.srcSet,l,null),a&&ze(e,t,"src",l.src,l,null);return;case"input":oe("invalid",e);var o=u=c=n=null,v=null,j=null;for(a in l)if(l.hasOwnProperty(a)){var M=l[a];if(M!=null)switch(a){case"name":n=M;break;case"type":c=M;break;case"checked":v=M;break;case"defaultChecked":j=M;break;case"value":u=M;break;case"defaultValue":o=M;break;case"children":case"dangerouslySetInnerHTML":if(M!=null)throw Error(r(137,t));break;default:ze(e,t,a,M,l,null)}}Nf(e,u,o,v,j,c,n,!1);return;case"select":oe("invalid",e),a=c=u=null;for(n in l)if(l.hasOwnProperty(n)&&(o=l[n],o!=null))switch(n){case"value":u=o;break;case"defaultValue":c=o;break;case"multiple":a=o;default:ze(e,t,n,o,l,null)}t=u,l=c,e.multiple=!!a,t!=null?oa(e,!!a,t,!1):l!=null&&oa(e,!!a,l,!0);return;case"textarea":oe("invalid",e),u=n=a=null;for(c in l)if(l.hasOwnProperty(c)&&(o=l[c],o!=null))switch(c){case"value":a=o;break;case"defaultValue":n=o;break;case"children":u=o;break;case"dangerouslySetInnerHTML":if(o!=null)throw Error(r(91));break;default:ze(e,t,c,o,l,null)}jf(e,a,n,u);return;case"option":for(v in l)if(l.hasOwnProperty(v)&&(a=l[v],a!=null))switch(v){case"selected":e.selected=a&&typeof a!="function"&&typeof a!="symbol";break;default:ze(e,t,v,a,l,null)}return;case"dialog":oe("beforetoggle",e),oe("toggle",e),oe("cancel",e),oe("close",e);break;case"iframe":case"object":oe("load",e);break;case"video":case"audio":for(a=0;a<Bn.length;a++)oe(Bn[a],e);break;case"image":oe("error",e),oe("load",e);break;case"details":oe("toggle",e);break;case"embed":case"source":case"link":oe("error",e),oe("load",e);case"area":case"base":case"br":case"col":case"hr":case"keygen":case"meta":case"param":case"track":case"wbr":case"menuitem":for(j in l)if(l.hasOwnProperty(j)&&(a=l[j],a!=null))switch(j){case"children":case"dangerouslySetInnerHTML":throw Error(r(137,t));default:ze(e,t,j,a,l,null)}return;default:if(Ui(t)){for(M in l)l.hasOwnProperty(M)&&(a=l[M],a!==void 0&&xr(e,t,M,a,l,void 0));return}}for(o in l)l.hasOwnProperty(o)&&(a=l[o],a!=null&&ze(e,t,o,a,l,null))}function Xv(e,t,l,a){switch(t){case"div":case"span":case"svg":case"path":case"a":case"g":case"p":case"li":break;case"input":var n=null,u=null,c=null,o=null,v=null,j=null,M=null;for(C in l){var H=l[C];if(l.hasOwnProperty(C)&&H!=null)switch(C){case"checked":break;case"value":break;case"defaultValue":v=H;default:a.hasOwnProperty(C)||ze(e,t,C,null,a,H)}}for(var _ in a){var C=a[_];if(H=l[_],a.hasOwnProperty(_)&&(C!=null||H!=null))switch(_){case"type":u=C;break;case"name":n=C;break;case"checked":j=C;break;case"defaultChecked":M=C;break;case"value":c=C;break;case"defaultValue":o=C;break;case"children":case"dangerouslySetInnerHTML":if(C!=null)throw Error(r(137,t));break;default:C!==H&&ze(e,t,_,C,a,H)}}Mi(e,c,o,v,j,M,u,n);return;case"select":C=c=o=_=null;for(u in l)if(v=l[u],l.hasOwnProperty(u)&&v!=null)switch(u){case"value":break;case"multiple":C=v;default:a.hasOwnProperty(u)||ze(e,t,u,null,a,v)}for(n in a)if(u=a[n],v=l[n],a.hasOwnProperty(n)&&(u!=null||v!=null))switch(n){case"value":_=u;break;case"defaultValue":o=u;break;case"multiple":c=u;default:u!==v&&ze(e,t,n,u,a,v)}t=o,l=c,a=C,_!=null?oa(e,!!l,_,!1):!!a!=!!l&&(t!=null?oa(e,!!l,t,!0):oa(e,!!l,l?[]:"",!1));return;case"textarea":C=_=null;for(o in l)if(n=l[o],l.hasOwnProperty(o)&&n!=null&&!a.hasOwnProperty(o))switch(o){case"value":break;case"children":break;default:ze(e,t,o,null,a,n)}for(c in a)if(n=a[c],u=l[c],a.hasOwnProperty(c)&&(n!=null||u!=null))switch(c){case"value":_=n;break;case"defaultValue":C=n;break;case"children":break;case"dangerouslySetInnerHTML":if(n!=null)throw Error(r(91));break;default:n!==u&&ze(e,t,c,n,a,u)}zf(e,_,C);return;case"option":for(var V in l)if(_=l[V],l.hasOwnProperty(V)&&_!=null&&!a.hasOwnProperty(V))switch(V){case"selected":e.selected=!1;break;default:ze(e,t,V,null,a,_)}for(v in a)if(_=a[v],C=l[v],a.hasOwnProperty(v)&&_!==C&&(_!=null||C!=null))switch(v){case"selected":e.selected=_&&typeof _!="function"&&typeof _!="symbol";break;default:ze(e,t,v,_,a,C)}return;case"img":case"link":case"area":case"base":case"br":case"col":case"embed":case"hr":case"keygen":case"meta":case"param":case"source":case"track":case"wbr":case"menuitem":for(var P in l)_=l[P],l.hasOwnProperty(P)&&_!=null&&!a.hasOwnProperty(P)&&ze(e,t,P,null,a,_);for(j in a)if(_=a[j],C=l[j],a.hasOwnProperty(j)&&_!==C&&(_!=null||C!=null))switch(j){case"children":case"dangerouslySetInnerHTML":if(_!=null)throw Error(r(137,t));break;default:ze(e,t,j,_,a,C)}return;default:if(Ui(t)){for(var je in l)_=l[je],l.hasOwnProperty(je)&&_!==void 0&&!a.hasOwnProperty(je)&&xr(e,t,je,void 0,a,_);for(M in a)_=a[M],C=l[M],!a.hasOwnProperty(M)||_===C||_===void 0&&C===void 0||xr(e,t,M,_,a,C);return}}for(var T in l)_=l[T],l.hasOwnProperty(T)&&_!=null&&!a.hasOwnProperty(T)&&ze(e,t,T,null,a,_);for(H in a)_=a[H],C=l[H],!a.hasOwnProperty(H)||_===C||_==null&&C==null||ze(e,t,H,_,a,C)}function Rd(e){switch(e){case"css":case"script":case"font":case"img":case"image":case"input":case"link":return!0;default:return!1}}function Qv(){if(typeof performance.getEntriesByType=="function"){for(var e=0,t=0,l=performance.getEntriesByType("resource"),a=0;a<l.length;a++){var n=l[a],u=n.transferSize,c=n.initiatorType,o=n.duration;if(u&&o&&Rd(c)){for(c=0,o=n.responseEnd,a+=1;a<l.length;a++){var v=l[a],j=v.startTime;if(j>o)break;var M=v.transferSize,H=v.initiatorType;M&&Rd(H)&&(v=v.responseEnd,c+=M*(v<o?1:(o-j)/(v-j)))}if(--a,t+=8*(u+c)/(n.duration/1e3),e++,10<e)break}}if(0<e)return t/e/1e6}return navigator.connection&&(e=navigator.connection.downlink,typeof e=="number")?e:5}var Sr=null,Er=null;function ai(e){return e.nodeType===9?e:e.ownerDocument}function Od(e){switch(e){case"http://www.w3.org/2000/svg":return 1;case"http://www.w3.org/1998/Math/MathML":return 2;default:return 0}}function Md(e,t){if(e===0)switch(t){case"svg":return 1;case"math":return 2;default:return 0}return e===1&&t==="foreignObject"?0:e}function Tr(e,t){return e==="textarea"||e==="noscript"||typeof t.children=="string"||typeof t.children=="number"||typeof t.children=="bigint"||typeof t.dangerouslySetInnerHTML=="object"&&t.dangerouslySetInnerHTML!==null&&t.dangerouslySetInnerHTML.__html!=null}var Nr=null;function Zv(){var e=window.event;return e&&e.type==="popstate"?e===Nr?!1:(Nr=e,!0):(Nr=null,!1)}var Dd=typeof setTimeout=="function"?setTimeout:void 0,Vv=typeof clearTimeout=="function"?clearTimeout:void 0,Ud=typeof Promise=="function"?Promise:void 0,Kv=typeof queueMicrotask=="function"?queueMicrotask:typeof Ud<"u"?function(e){return Ud.resolve(null).then(e).catch(Jv)}:Dd;function Jv(e){setTimeout(function(){throw e})}function Ml(e){return e==="head"}function Hd(e,t){var l=t,a=0;do{var n=l.nextSibling;if(e.removeChild(l),n&&n.nodeType===8)if(l=n.data,l==="/$"||l==="/&"){if(a===0){e.removeChild(n),Qa(t);return}a--}else if(l==="$"||l==="$?"||l==="$~"||l==="$!"||l==="&")a++;else if(l==="html")wn(e.ownerDocument.documentElement);else if(l==="head"){l=e.ownerDocument.head,wn(l);for(var u=l.firstChild;u;){var c=u.nextSibling,o=u.nodeName;u[tn]||o==="SCRIPT"||o==="STYLE"||o==="LINK"&&u.rel.toLowerCase()==="stylesheet"||l.removeChild(u),u=c}}else l==="body"&&wn(e.ownerDocument.body);l=n}while(l);Qa(t)}function Bd(e,t){var l=e;e=0;do{var a=l.nextSibling;if(l.nodeType===1?t?(l._stashedDisplay=l.style.display,l.style.display="none"):(l.style.display=l._stashedDisplay||"",l.getAttribute("style")===""&&l.removeAttribute("style")):l.nodeType===3&&(t?(l._stashedText=l.nodeValue,l.nodeValue=""):l.nodeValue=l._stashedText||""),a&&a.nodeType===8)if(l=a.data,l==="/$"){if(e===0)break;e--}else l!=="$"&&l!=="$?"&&l!=="$~"&&l!=="$!"||e++;l=a}while(l)}function zr(e){var t=e.firstChild;for(t&&t.nodeType===10&&(t=t.nextSibling);t;){var l=t;switch(t=t.nextSibling,l.nodeName){case"HTML":case"HEAD":case"BODY":zr(l),Ri(l);continue;case"SCRIPT":case"STYLE":continue;case"LINK":if(l.rel.toLowerCase()==="stylesheet")continue}e.removeChild(l)}}function kv(e,t,l,a){for(;e.nodeType===1;){var n=l;if(e.nodeName.toLowerCase()!==t.toLowerCase()){if(!a&&(e.nodeName!=="INPUT"||e.type!=="hidden"))break}else if(a){if(!e[tn])switch(t){case"meta":if(!e.hasAttribute("itemprop"))break;return e;case"link":if(u=e.getAttribute("rel"),u==="stylesheet"&&e.hasAttribute("data-precedence"))break;if(u!==n.rel||e.getAttribute("href")!==(n.href==null||n.href===""?null:n.href)||e.getAttribute("crossorigin")!==(n.crossOrigin==null?null:n.crossOrigin)||e.getAttribute("title")!==(n.title==null?null:n.title))break;return e;case"style":if(e.hasAttribute("data-precedence"))break;return e;case"script":if(u=e.getAttribute("src"),(u!==(n.src==null?null:n.src)||e.getAttribute("type")!==(n.type==null?null:n.type)||e.getAttribute("crossorigin")!==(n.crossOrigin==null?null:n.crossOrigin))&&u&&e.hasAttribute("async")&&!e.hasAttribute("itemprop"))break;return e;default:return e}}else if(t==="input"&&e.type==="hidden"){var u=n.name==null?null:""+n.name;if(n.type==="hidden"&&e.getAttribute("name")===u)return e}else return e;if(e=Rt(e.nextSibling),e===null)break}return null}function $v(e,t,l){if(t==="")return null;for(;e.nodeType!==3;)if((e.nodeType!==1||e.nodeName!=="INPUT"||e.type!=="hidden")&&!l||(e=Rt(e.nextSibling),e===null))return null;return e}function Ld(e,t){for(;e.nodeType!==8;)if((e.nodeType!==1||e.nodeName!=="INPUT"||e.type!=="hidden")&&!t||(e=Rt(e.nextSibling),e===null))return null;return e}function jr(e){return e.data==="$?"||e.data==="$~"}function _r(e){return e.data==="$!"||e.data==="$?"&&e.ownerDocument.readyState!=="loading"}function Wv(e,t){var l=e.ownerDocument;if(e.data==="$~")e._reactRetry=t;else if(e.data!=="$?"||l.readyState!=="loading")t();else{var a=function(){t(),l.removeEventListener("DOMContentLoaded",a)};l.addEventListener("DOMContentLoaded",a),e._reactRetry=a}}function Rt(e){for(;e!=null;e=e.nextSibling){var t=e.nodeType;if(t===1||t===3)break;if(t===8){if(t=e.data,t==="$"||t==="$!"||t==="$?"||t==="$~"||t==="&"||t==="F!"||t==="F")break;if(t==="/$"||t==="/&")return null}}return e}var Ar=null;function wd(e){e=e.nextSibling;for(var t=0;e;){if(e.nodeType===8){var l=e.data;if(l==="/$"||l==="/&"){if(t===0)return Rt(e.nextSibling);t--}else l!=="$"&&l!=="$!"&&l!=="$?"&&l!=="$~"&&l!=="&"||t++}e=e.nextSibling}return null}function qd(e){e=e.previousSibling;for(var t=0;e;){if(e.nodeType===8){var l=e.data;if(l==="$"||l==="$!"||l==="$?"||l==="$~"||l==="&"){if(t===0)return e;t--}else l!=="/$"&&l!=="/&"||t++}e=e.previousSibling}return null}function Yd(e,t,l){switch(t=ai(l),e){case"html":if(e=t.documentElement,!e)throw Error(r(452));return e;case"head":if(e=t.head,!e)throw Error(r(453));return e;case"body":if(e=t.body,!e)throw Error(r(454));return e;default:throw Error(r(451))}}function wn(e){for(var t=e.attributes;t.length;)e.removeAttributeNode(t[0]);Ri(e)}var Ot=new Map,Gd=new Set;function ni(e){return typeof e.getRootNode=="function"?e.getRootNode():e.nodeType===9?e:e.ownerDocument}var fl=G.d;G.d={f:Fv,r:Iv,D:Pv,C:ey,L:ty,m:ly,X:ny,S:ay,M:uy};function Fv(){var e=fl.f(),t=$u();return e||t}function Iv(e){var t=ra(e);t!==null&&t.tag===5&&t.type==="form"?ao(t):fl.r(e)}var Ya=typeof document>"u"?null:document;function Xd(e,t,l){var a=Ya;if(a&&typeof t=="string"&&t){var n=Tt(t);n='link[rel="'+e+'"][href="'+n+'"]',typeof l=="string"&&(n+='[crossorigin="'+l+'"]'),Gd.has(n)||(Gd.add(n),e={rel:e,crossOrigin:l,href:t},a.querySelector(n)===null&&(t=a.createElement("link"),et(t,"link",e),Je(t),a.head.appendChild(t)))}}function Pv(e){fl.D(e),Xd("dns-prefetch",e,null)}function ey(e,t){fl.C(e,t),Xd("preconnect",e,t)}function ty(e,t,l){fl.L(e,t,l);var a=Ya;if(a&&e&&t){var n='link[rel="preload"][as="'+Tt(t)+'"]';t==="image"&&l&&l.imageSrcSet?(n+='[imagesrcset="'+Tt(l.imageSrcSet)+'"]',typeof l.imageSizes=="string"&&(n+='[imagesizes="'+Tt(l.imageSizes)+'"]')):n+='[href="'+Tt(e)+'"]';var u=n;switch(t){case"style":u=Ga(e);break;case"script":u=Xa(e)}Ot.has(u)||(e=E({rel:"preload",href:t==="image"&&l&&l.imageSrcSet?void 0:e,as:t},l),Ot.set(u,e),a.querySelector(n)!==null||t==="style"&&a.querySelector(qn(u))||t==="script"&&a.querySelector(Yn(u))||(t=a.createElement("link"),et(t,"link",e),Je(t),a.head.appendChild(t)))}}function ly(e,t){fl.m(e,t);var l=Ya;if(l&&e){var a=t&&typeof t.as=="string"?t.as:"script",n='link[rel="modulepreload"][as="'+Tt(a)+'"][href="'+Tt(e)+'"]',u=n;switch(a){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":u=Xa(e)}if(!Ot.has(u)&&(e=E({rel:"modulepreload",href:e},t),Ot.set(u,e),l.querySelector(n)===null)){switch(a){case"audioworklet":case"paintworklet":case"serviceworker":case"sharedworker":case"worker":case"script":if(l.querySelector(Yn(u)))return}a=l.createElement("link"),et(a,"link",e),Je(a),l.head.appendChild(a)}}}function ay(e,t,l){fl.S(e,t,l);var a=Ya;if(a&&e){var n=fa(a).hoistableStyles,u=Ga(e);t=t||"default";var c=n.get(u);if(!c){var o={loading:0,preload:null};if(c=a.querySelector(qn(u)))o.loading=5;else{e=E({rel:"stylesheet",href:e,"data-precedence":t},l),(l=Ot.get(u))&&Cr(e,l);var v=c=a.createElement("link");Je(v),et(v,"link",e),v._p=new Promise(function(j,M){v.onload=j,v.onerror=M}),v.addEventListener("load",function(){o.loading|=1}),v.addEventListener("error",function(){o.loading|=2}),o.loading|=4,ui(c,t,a)}c={type:"stylesheet",instance:c,count:1,state:o},n.set(u,c)}}}function ny(e,t){fl.X(e,t);var l=Ya;if(l&&e){var a=fa(l).hoistableScripts,n=Xa(e),u=a.get(n);u||(u=l.querySelector(Yn(n)),u||(e=E({src:e,async:!0},t),(t=Ot.get(n))&&Rr(e,t),u=l.createElement("script"),Je(u),et(u,"link",e),l.head.appendChild(u)),u={type:"script",instance:u,count:1,state:null},a.set(n,u))}}function uy(e,t){fl.M(e,t);var l=Ya;if(l&&e){var a=fa(l).hoistableScripts,n=Xa(e),u=a.get(n);u||(u=l.querySelector(Yn(n)),u||(e=E({src:e,async:!0,type:"module"},t),(t=Ot.get(n))&&Rr(e,t),u=l.createElement("script"),Je(u),et(u,"link",e),l.head.appendChild(u)),u={type:"script",instance:u,count:1,state:null},a.set(n,u))}}function Qd(e,t,l,a){var n=(n=te.current)?ni(n):null;if(!n)throw Error(r(446));switch(e){case"meta":case"title":return null;case"style":return typeof l.precedence=="string"&&typeof l.href=="string"?(t=Ga(l.href),l=fa(n).hoistableStyles,a=l.get(t),a||(a={type:"style",instance:null,count:0,state:null},l.set(t,a)),a):{type:"void",instance:null,count:0,state:null};case"link":if(l.rel==="stylesheet"&&typeof l.href=="string"&&typeof l.precedence=="string"){e=Ga(l.href);var u=fa(n).hoistableStyles,c=u.get(e);if(c||(n=n.ownerDocument||n,c={type:"stylesheet",instance:null,count:0,state:{loading:0,preload:null}},u.set(e,c),(u=n.querySelector(qn(e)))&&!u._p&&(c.instance=u,c.state.loading=5),Ot.has(e)||(l={rel:"preload",as:"style",href:l.href,crossOrigin:l.crossOrigin,integrity:l.integrity,media:l.media,hrefLang:l.hrefLang,referrerPolicy:l.referrerPolicy},Ot.set(e,l),u||iy(n,e,l,c.state))),t&&a===null)throw Error(r(528,""));return c}if(t&&a!==null)throw Error(r(529,""));return null;case"script":return t=l.async,l=l.src,typeof l=="string"&&t&&typeof t!="function"&&typeof t!="symbol"?(t=Xa(l),l=fa(n).hoistableScripts,a=l.get(t),a||(a={type:"script",instance:null,count:0,state:null},l.set(t,a)),a):{type:"void",instance:null,count:0,state:null};default:throw Error(r(444,e))}}function Ga(e){return'href="'+Tt(e)+'"'}function qn(e){return'link[rel="stylesheet"]['+e+"]"}function Zd(e){return E({},e,{"data-precedence":e.precedence,precedence:null})}function iy(e,t,l,a){e.querySelector('link[rel="preload"][as="style"]['+t+"]")?a.loading=1:(t=e.createElement("link"),a.preload=t,t.addEventListener("load",function(){return a.loading|=1}),t.addEventListener("error",function(){return a.loading|=2}),et(t,"link",l),Je(t),e.head.appendChild(t))}function Xa(e){return'[src="'+Tt(e)+'"]'}function Yn(e){return"script[async]"+e}function Vd(e,t,l){if(t.count++,t.instance===null)switch(t.type){case"style":var a=e.querySelector('style[data-href~="'+Tt(l.href)+'"]');if(a)return t.instance=a,Je(a),a;var n=E({},l,{"data-href":l.href,"data-precedence":l.precedence,href:null,precedence:null});return a=(e.ownerDocument||e).createElement("style"),Je(a),et(a,"style",n),ui(a,l.precedence,e),t.instance=a;case"stylesheet":n=Ga(l.href);var u=e.querySelector(qn(n));if(u)return t.state.loading|=4,t.instance=u,Je(u),u;a=Zd(l),(n=Ot.get(n))&&Cr(a,n),u=(e.ownerDocument||e).createElement("link"),Je(u);var c=u;return c._p=new Promise(function(o,v){c.onload=o,c.onerror=v}),et(u,"link",a),t.state.loading|=4,ui(u,l.precedence,e),t.instance=u;case"script":return u=Xa(l.src),(n=e.querySelector(Yn(u)))?(t.instance=n,Je(n),n):(a=l,(n=Ot.get(u))&&(a=E({},l),Rr(a,n)),e=e.ownerDocument||e,n=e.createElement("script"),Je(n),et(n,"link",a),e.head.appendChild(n),t.instance=n);case"void":return null;default:throw Error(r(443,t.type))}else t.type==="stylesheet"&&(t.state.loading&4)===0&&(a=t.instance,t.state.loading|=4,ui(a,l.precedence,e));return t.instance}function ui(e,t,l){for(var a=l.querySelectorAll('link[rel="stylesheet"][data-precedence],style[data-precedence]'),n=a.length?a[a.length-1]:null,u=n,c=0;c<a.length;c++){var o=a[c];if(o.dataset.precedence===t)u=o;else if(u!==n)break}u?u.parentNode.insertBefore(e,u.nextSibling):(t=l.nodeType===9?l.head:l,t.insertBefore(e,t.firstChild))}function Cr(e,t){e.crossOrigin==null&&(e.crossOrigin=t.crossOrigin),e.referrerPolicy==null&&(e.referrerPolicy=t.referrerPolicy),e.title==null&&(e.title=t.title)}function Rr(e,t){e.crossOrigin==null&&(e.crossOrigin=t.crossOrigin),e.referrerPolicy==null&&(e.referrerPolicy=t.referrerPolicy),e.integrity==null&&(e.integrity=t.integrity)}var ii=null;function Kd(e,t,l){if(ii===null){var a=new Map,n=ii=new Map;n.set(l,a)}else n=ii,a=n.get(l),a||(a=new Map,n.set(l,a));if(a.has(e))return a;for(a.set(e,null),l=l.getElementsByTagName(e),n=0;n<l.length;n++){var u=l[n];if(!(u[tn]||u[We]||e==="link"&&u.getAttribute("rel")==="stylesheet")&&u.namespaceURI!=="http://www.w3.org/2000/svg"){var c=u.getAttribute(t)||"";c=e+c;var o=a.get(c);o?o.push(u):a.set(c,[u])}}return a}function Jd(e,t,l){e=e.ownerDocument||e,e.head.insertBefore(l,t==="title"?e.querySelector("head > title"):null)}function cy(e,t,l){if(l===1||t.itemProp!=null)return!1;switch(e){case"meta":case"title":return!0;case"style":if(typeof t.precedence!="string"||typeof t.href!="string"||t.href==="")break;return!0;case"link":if(typeof t.rel!="string"||typeof t.href!="string"||t.href===""||t.onLoad||t.onError)break;switch(t.rel){case"stylesheet":return e=t.disabled,typeof t.precedence=="string"&&e==null;default:return!0}case"script":if(t.async&&typeof t.async!="function"&&typeof t.async!="symbol"&&!t.onLoad&&!t.onError&&t.src&&typeof t.src=="string")return!0}return!1}function kd(e){return!(e.type==="stylesheet"&&(e.state.loading&3)===0)}function ry(e,t,l,a){if(l.type==="stylesheet"&&(typeof a.media!="string"||matchMedia(a.media).matches!==!1)&&(l.state.loading&4)===0){if(l.instance===null){var n=Ga(a.href),u=t.querySelector(qn(n));if(u){t=u._p,t!==null&&typeof t=="object"&&typeof t.then=="function"&&(e.count++,e=ci.bind(e),t.then(e,e)),l.state.loading|=4,l.instance=u,Je(u);return}u=t.ownerDocument||t,a=Zd(a),(n=Ot.get(n))&&Cr(a,n),u=u.createElement("link"),Je(u);var c=u;c._p=new Promise(function(o,v){c.onload=o,c.onerror=v}),et(u,"link",a),l.instance=u}e.stylesheets===null&&(e.stylesheets=new Map),e.stylesheets.set(l,t),(t=l.state.preload)&&(l.state.loading&3)===0&&(e.count++,l=ci.bind(e),t.addEventListener("load",l),t.addEventListener("error",l))}}var Or=0;function fy(e,t){return e.stylesheets&&e.count===0&&fi(e,e.stylesheets),0<e.count||0<e.imgCount?function(l){var a=setTimeout(function(){if(e.stylesheets&&fi(e,e.stylesheets),e.unsuspend){var u=e.unsuspend;e.unsuspend=null,u()}},6e4+t);0<e.imgBytes&&Or===0&&(Or=62500*Qv());var n=setTimeout(function(){if(e.waitingForImages=!1,e.count===0&&(e.stylesheets&&fi(e,e.stylesheets),e.unsuspend)){var u=e.unsuspend;e.unsuspend=null,u()}},(e.imgBytes>Or?50:800)+t);return e.unsuspend=l,function(){e.unsuspend=null,clearTimeout(a),clearTimeout(n)}}:null}function ci(){if(this.count--,this.count===0&&(this.imgCount===0||!this.waitingForImages)){if(this.stylesheets)fi(this,this.stylesheets);else if(this.unsuspend){var e=this.unsuspend;this.unsuspend=null,e()}}}var ri=null;function fi(e,t){e.stylesheets=null,e.unsuspend!==null&&(e.count++,ri=new Map,t.forEach(sy,e),ri=null,ci.call(e))}function sy(e,t){if(!(t.state.loading&4)){var l=ri.get(e);if(l)var a=l.get(null);else{l=new Map,ri.set(e,l);for(var n=e.querySelectorAll("link[data-precedence],style[data-precedence]"),u=0;u<n.length;u++){var c=n[u];(c.nodeName==="LINK"||c.getAttribute("media")!=="not all")&&(l.set(c.dataset.precedence,c),a=c)}a&&l.set(null,a)}n=t.instance,c=n.getAttribute("data-precedence"),u=l.get(c)||a,u===a&&l.set(null,n),l.set(c,n),this.count++,a=ci.bind(this),n.addEventListener("load",a),n.addEventListener("error",a),u?u.parentNode.insertBefore(n,u.nextSibling):(e=e.nodeType===9?e.head:e,e.insertBefore(n,e.firstChild)),t.state.loading|=4}}var Gn={$$typeof:K,Provider:null,Consumer:null,_currentValue:I,_currentValue2:I,_threadCount:0};function oy(e,t,l,a,n,u,c,o,v){this.tag=1,this.containerInfo=e,this.pingCache=this.current=this.pendingChildren=null,this.timeoutHandle=-1,this.callbackNode=this.next=this.pendingContext=this.context=this.cancelPendingCommit=null,this.callbackPriority=0,this.expirationTimes=ji(-1),this.entangledLanes=this.shellSuspendCounter=this.errorRecoveryDisabledLanes=this.expiredLanes=this.warmLanes=this.pingedLanes=this.suspendedLanes=this.pendingLanes=0,this.entanglements=ji(0),this.hiddenUpdates=ji(null),this.identifierPrefix=a,this.onUncaughtError=n,this.onCaughtError=u,this.onRecoverableError=c,this.pooledCache=null,this.pooledCacheLanes=0,this.formState=v,this.incompleteTransitions=new Map}function $d(e,t,l,a,n,u,c,o,v,j,M,H){return e=new oy(e,t,l,c,v,j,M,H,o),t=1,u===!0&&(t|=24),u=vt(3,null,null,t),e.current=u,u.stateNode=e,t=sc(),t.refCount++,e.pooledCache=t,t.refCount++,u.memoizedState={element:a,isDehydrated:l,cache:t},hc(u),e}function Wd(e){return e?(e=ba,e):ba}function Fd(e,t,l,a,n,u){n=Wd(n),a.context===null?a.context=n:a.pendingContext=n,a=Sl(t),a.payload={element:l},u=u===void 0?null:u,u!==null&&(a.callback=u),l=El(e,a,t),l!==null&&(ot(l,e,t),bn(l,e,t))}function Id(e,t){if(e=e.memoizedState,e!==null&&e.dehydrated!==null){var l=e.retryLane;e.retryLane=l!==0&&l<t?l:t}}function Mr(e,t){Id(e,t),(e=e.alternate)&&Id(e,t)}function Pd(e){if(e.tag===13||e.tag===31){var t=Kl(e,67108864);t!==null&&ot(t,e,67108864),Mr(e,67108864)}}function em(e){if(e.tag===13||e.tag===31){var t=xt();t=_i(t);var l=Kl(e,t);l!==null&&ot(l,e,t),Mr(e,t)}}var si=!0;function dy(e,t,l,a){var n=O.T;O.T=null;var u=G.p;try{G.p=2,Dr(e,t,l,a)}finally{G.p=u,O.T=n}}function my(e,t,l,a){var n=O.T;O.T=null;var u=G.p;try{G.p=8,Dr(e,t,l,a)}finally{G.p=u,O.T=n}}function Dr(e,t,l,a){if(si){var n=Ur(a);if(n===null)br(e,t,a,oi,l),lm(e,a);else if(vy(n,e,t,l,a))a.stopPropagation();else if(lm(e,a),t&4&&-1<hy.indexOf(e)){for(;n!==null;){var u=ra(n);if(u!==null)switch(u.tag){case 3:if(u=u.stateNode,u.current.memoizedState.isDehydrated){var c=Gl(u.pendingLanes);if(c!==0){var o=u;for(o.pendingLanes|=2,o.entangledLanes|=2;c;){var v=1<<31-mt(c);o.entanglements[1]|=v,c&=~v}Zt(u),(xe&6)===0&&(Ju=be()+500,Hn(0))}}break;case 31:case 13:o=Kl(u,2),o!==null&&ot(o,u,2),$u(),Mr(u,2)}if(u=Ur(a),u===null&&br(e,t,a,oi,l),u===n)break;n=u}n!==null&&a.stopPropagation()}else br(e,t,a,null,l)}}function Ur(e){return e=Bi(e),Hr(e)}var oi=null;function Hr(e){if(oi=null,e=ca(e),e!==null){var t=h(e);if(t===null)e=null;else{var l=t.tag;if(l===13){if(e=x(t),e!==null)return e;e=null}else if(l===31){if(e=N(t),e!==null)return e;e=null}else if(l===3){if(t.stateNode.current.memoizedState.isDehydrated)return t.tag===3?t.stateNode.containerInfo:null;e=null}else t!==e&&(e=null)}}return oi=e,null}function tm(e){switch(e){case"beforetoggle":case"cancel":case"click":case"close":case"contextmenu":case"copy":case"cut":case"auxclick":case"dblclick":case"dragend":case"dragstart":case"drop":case"focusin":case"focusout":case"input":case"invalid":case"keydown":case"keypress":case"keyup":case"mousedown":case"mouseup":case"paste":case"pause":case"play":case"pointercancel":case"pointerdown":case"pointerup":case"ratechange":case"reset":case"resize":case"seeked":case"submit":case"toggle":case"touchcancel":case"touchend":case"touchstart":case"volumechange":case"change":case"selectionchange":case"textInput":case"compositionstart":case"compositionend":case"compositionupdate":case"beforeblur":case"afterblur":case"beforeinput":case"blur":case"fullscreenchange":case"focus":case"hashchange":case"popstate":case"select":case"selectstart":return 2;case"drag":case"dragenter":case"dragexit":case"dragleave":case"dragover":case"mousemove":case"mouseout":case"mouseover":case"pointermove":case"pointerout":case"pointerover":case"scroll":case"touchmove":case"wheel":case"mouseenter":case"mouseleave":case"pointerenter":case"pointerleave":return 8;case"message":switch(Pm()){case rf:return 2;case ff:return 8;case eu:case eh:return 32;case sf:return 268435456;default:return 32}default:return 32}}var Br=!1,Dl=null,Ul=null,Hl=null,Xn=new Map,Qn=new Map,Bl=[],hy="mousedown mouseup touchcancel touchend touchstart auxclick dblclick pointercancel pointerdown pointerup dragend dragstart drop compositionend compositionstart keydown keypress keyup input textInput copy cut paste click change contextmenu reset".split(" ");function lm(e,t){switch(e){case"focusin":case"focusout":Dl=null;break;case"dragenter":case"dragleave":Ul=null;break;case"mouseover":case"mouseout":Hl=null;break;case"pointerover":case"pointerout":Xn.delete(t.pointerId);break;case"gotpointercapture":case"lostpointercapture":Qn.delete(t.pointerId)}}function Zn(e,t,l,a,n,u){return e===null||e.nativeEvent!==u?(e={blockedOn:t,domEventName:l,eventSystemFlags:a,nativeEvent:u,targetContainers:[n]},t!==null&&(t=ra(t),t!==null&&Pd(t)),e):(e.eventSystemFlags|=a,t=e.targetContainers,n!==null&&t.indexOf(n)===-1&&t.push(n),e)}function vy(e,t,l,a,n){switch(t){case"focusin":return Dl=Zn(Dl,e,t,l,a,n),!0;case"dragenter":return Ul=Zn(Ul,e,t,l,a,n),!0;case"mouseover":return Hl=Zn(Hl,e,t,l,a,n),!0;case"pointerover":var u=n.pointerId;return Xn.set(u,Zn(Xn.get(u)||null,e,t,l,a,n)),!0;case"gotpointercapture":return u=n.pointerId,Qn.set(u,Zn(Qn.get(u)||null,e,t,l,a,n)),!0}return!1}function am(e){var t=ca(e.target);if(t!==null){var l=h(t);if(l!==null){if(t=l.tag,t===13){if(t=x(l),t!==null){e.blockedOn=t,yf(e.priority,function(){em(l)});return}}else if(t===31){if(t=N(l),t!==null){e.blockedOn=t,yf(e.priority,function(){em(l)});return}}else if(t===3&&l.stateNode.current.memoizedState.isDehydrated){e.blockedOn=l.tag===3?l.stateNode.containerInfo:null;return}}}e.blockedOn=null}function di(e){if(e.blockedOn!==null)return!1;for(var t=e.targetContainers;0<t.length;){var l=Ur(e.nativeEvent);if(l===null){l=e.nativeEvent;var a=new l.constructor(l.type,l);Hi=a,l.target.dispatchEvent(a),Hi=null}else return t=ra(l),t!==null&&Pd(t),e.blockedOn=l,!1;t.shift()}return!0}function nm(e,t,l){di(e)&&l.delete(t)}function yy(){Br=!1,Dl!==null&&di(Dl)&&(Dl=null),Ul!==null&&di(Ul)&&(Ul=null),Hl!==null&&di(Hl)&&(Hl=null),Xn.forEach(nm),Qn.forEach(nm)}function mi(e,t){e.blockedOn===t&&(e.blockedOn=null,Br||(Br=!0,i.unstable_scheduleCallback(i.unstable_NormalPriority,yy)))}var hi=null;function um(e){hi!==e&&(hi=e,i.unstable_scheduleCallback(i.unstable_NormalPriority,function(){hi===e&&(hi=null);for(var t=0;t<e.length;t+=3){var l=e[t],a=e[t+1],n=e[t+2];if(typeof a!="function"){if(Hr(a||l)===null)continue;break}var u=ra(l);u!==null&&(e.splice(t,3),t-=3,Uc(u,{pending:!0,data:n,method:l.method,action:a},a,n))}}))}function Qa(e){function t(v){return mi(v,e)}Dl!==null&&mi(Dl,e),Ul!==null&&mi(Ul,e),Hl!==null&&mi(Hl,e),Xn.forEach(t),Qn.forEach(t);for(var l=0;l<Bl.length;l++){var a=Bl[l];a.blockedOn===e&&(a.blockedOn=null)}for(;0<Bl.length&&(l=Bl[0],l.blockedOn===null);)am(l),l.blockedOn===null&&Bl.shift();if(l=(e.ownerDocument||e).$$reactFormReplay,l!=null)for(a=0;a<l.length;a+=3){var n=l[a],u=l[a+1],c=n[ut]||null;if(typeof u=="function")c||um(l);else if(c){var o=null;if(u&&u.hasAttribute("formAction")){if(n=u,c=u[ut]||null)o=c.formAction;else if(Hr(n)!==null)continue}else o=c.action;typeof o=="function"?l[a+1]=o:(l.splice(a,3),a-=3),um(l)}}}function im(){function e(u){u.canIntercept&&u.info==="react-transition"&&u.intercept({handler:function(){return new Promise(function(c){return n=c})},focusReset:"manual",scroll:"manual"})}function t(){n!==null&&(n(),n=null),a||setTimeout(l,20)}function l(){if(!a&&!navigation.transition){var u=navigation.currentEntry;u&&u.url!=null&&navigation.navigate(u.url,{state:u.getState(),info:"react-transition",history:"replace"})}}if(typeof navigation=="object"){var a=!1,n=null;return navigation.addEventListener("navigate",e),navigation.addEventListener("navigatesuccess",t),navigation.addEventListener("navigateerror",t),setTimeout(l,100),function(){a=!0,navigation.removeEventListener("navigate",e),navigation.removeEventListener("navigatesuccess",t),navigation.removeEventListener("navigateerror",t),n!==null&&(n(),n=null)}}}function Lr(e){this._internalRoot=e}vi.prototype.render=Lr.prototype.render=function(e){var t=this._internalRoot;if(t===null)throw Error(r(409));var l=t.current,a=xt();Fd(l,a,e,t,null,null)},vi.prototype.unmount=Lr.prototype.unmount=function(){var e=this._internalRoot;if(e!==null){this._internalRoot=null;var t=e.containerInfo;Fd(e.current,2,null,e,null,null),$u(),t[ia]=null}};function vi(e){this._internalRoot=e}vi.prototype.unstable_scheduleHydration=function(e){if(e){var t=vf();e={blockedOn:null,target:e,priority:t};for(var l=0;l<Bl.length&&t!==0&&t<Bl[l].priority;l++);Bl.splice(l,0,e),l===0&&am(e)}};var cm=f.version;if(cm!=="19.2.4")throw Error(r(527,cm,"19.2.4"));G.findDOMNode=function(e){var t=e._reactInternals;if(t===void 0)throw typeof e.render=="function"?Error(r(188)):(e=Object.keys(e).join(","),Error(r(268,e)));return e=y(t),e=e!==null?A(e):null,e=e===null?null:e.stateNode,e};var py={bundleType:0,version:"19.2.4",rendererPackageName:"react-dom",currentDispatcherRef:O,reconcilerVersion:"19.2.4"};if(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__<"u"){var yi=__REACT_DEVTOOLS_GLOBAL_HOOK__;if(!yi.isDisabled&&yi.supportsFiber)try{Ia=yi.inject(py),dt=yi}catch{}}return Kn.createRoot=function(e,t){if(!m(e))throw Error(r(299));var l=!1,a="",n=ho,u=vo,c=yo;return t!=null&&(t.unstable_strictMode===!0&&(l=!0),t.identifierPrefix!==void 0&&(a=t.identifierPrefix),t.onUncaughtError!==void 0&&(n=t.onUncaughtError),t.onCaughtError!==void 0&&(u=t.onCaughtError),t.onRecoverableError!==void 0&&(c=t.onRecoverableError)),t=$d(e,1,!1,null,null,l,a,null,n,u,c,im),e[ia]=t.current,gr(e),new Lr(t)},Kn.hydrateRoot=function(e,t,l){if(!m(e))throw Error(r(299));var a=!1,n="",u=ho,c=vo,o=yo,v=null;return l!=null&&(l.unstable_strictMode===!0&&(a=!0),l.identifierPrefix!==void 0&&(n=l.identifierPrefix),l.onUncaughtError!==void 0&&(u=l.onUncaughtError),l.onCaughtError!==void 0&&(c=l.onCaughtError),l.onRecoverableError!==void 0&&(o=l.onRecoverableError),l.formState!==void 0&&(v=l.formState)),t=$d(e,1,!0,t,l??null,a,n,v,u,c,o,im),t.context=Wd(null),l=t.current,a=xt(),a=_i(a),n=Sl(a),n.callback=null,El(l,n,a),l=a,t.current.lanes=l,en(t,l),Zt(t),e[ia]=t.current,gr(e),new vi(t)},Kn.version="19.2.4",Kn}var pm;function Ay(){if(pm)return Yr.exports;pm=1;function i(){if(!(typeof __REACT_DEVTOOLS_GLOBAL_HOOK__>"u"||typeof __REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE!="function"))try{__REACT_DEVTOOLS_GLOBAL_HOOK__.checkDCE(i)}catch(f){console.error(f)}}return i(),Yr.exports=_y(),Yr.exports}var Cy=Ay();/**
 * react-router v7.13.2
 *
 * Copyright (c) Remix Software Inc.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE.md file in the root directory of this source tree.
 *
 * @license MIT
 */var gm="popstate";function bm(i){return typeof i=="object"&&i!=null&&"pathname"in i&&"search"in i&&"hash"in i&&"state"in i&&"key"in i}function Ry(i={}){function f(r,m){var y;let h=(y=m.state)==null?void 0:y.masked,{pathname:x,search:N,hash:S}=h||r.location;return Jr("",{pathname:x,search:N,hash:S},m.state&&m.state.usr||null,m.state&&m.state.key||"default",h?{pathname:r.location.pathname,search:r.location.search,hash:r.location.hash}:void 0)}function s(r,m){return typeof m=="string"?m:kn(m)}return My(f,s,null,i)}function Ue(i,f){if(i===!1||i===null||typeof i>"u")throw new Error(f)}function Lt(i,f){if(!i){typeof console<"u"&&console.warn(f);try{throw new Error(f)}catch{}}}function Oy(){return Math.random().toString(36).substring(2,10)}function xm(i,f){return{usr:i.state,key:i.key,idx:f,masked:i.unstable_mask?{pathname:i.pathname,search:i.search,hash:i.hash}:void 0}}function Jr(i,f,s=null,r,m){return{pathname:typeof i=="string"?i:i.pathname,search:"",hash:"",...typeof f=="string"?Va(f):f,state:s,key:f&&f.key||r||Oy(),unstable_mask:m}}function kn({pathname:i="/",search:f="",hash:s=""}){return f&&f!=="?"&&(i+=f.charAt(0)==="?"?f:"?"+f),s&&s!=="#"&&(i+=s.charAt(0)==="#"?s:"#"+s),i}function Va(i){let f={};if(i){let s=i.indexOf("#");s>=0&&(f.hash=i.substring(s),i=i.substring(0,s));let r=i.indexOf("?");r>=0&&(f.search=i.substring(r),i=i.substring(0,r)),i&&(f.pathname=i)}return f}function My(i,f,s,r={}){let{window:m=document.defaultView,v5Compat:h=!1}=r,x=m.history,N="POP",S=null,y=A();y==null&&(y=0,x.replaceState({...x.state,idx:y},""));function A(){return(x.state||{idx:null}).idx}function E(){N="POP";let B=A(),w=B==null?null:B-y;y=B,S&&S({action:N,location:R.location,delta:w})}function L(B,w){N="PUSH";let k=bm(B)?B:Jr(R.location,B,w);y=A()+1;let K=xm(k,y),ce=R.createHref(k.unstable_mask||k);try{x.pushState(K,"",ce)}catch(le){if(le instanceof DOMException&&le.name==="DataCloneError")throw le;m.location.assign(ce)}h&&S&&S({action:N,location:R.location,delta:1})}function X(B,w){N="REPLACE";let k=bm(B)?B:Jr(R.location,B,w);y=A();let K=xm(k,y),ce=R.createHref(k.unstable_mask||k);x.replaceState(K,"",ce),h&&S&&S({action:N,location:R.location,delta:0})}function Q(B){return Dy(B)}let R={get action(){return N},get location(){return i(m,x)},listen(B){if(S)throw new Error("A history only accepts one active listener");return m.addEventListener(gm,E),S=B,()=>{m.removeEventListener(gm,E),S=null}},createHref(B){return f(m,B)},createURL:Q,encodeLocation(B){let w=Q(B);return{pathname:w.pathname,search:w.search,hash:w.hash}},push:L,replace:X,go(B){return x.go(B)}};return R}function Dy(i,f=!1){let s="http://localhost";typeof window<"u"&&(s=window.location.origin!=="null"?window.location.origin:window.location.href),Ue(s,"No window.location.(origin|href) available to create URL");let r=typeof i=="string"?i:kn(i);return r=r.replace(/ $/,"%20"),!f&&r.startsWith("//")&&(r=s+r),new URL(r,s)}function Cm(i,f,s="/"){return Uy(i,f,s,!1)}function Uy(i,f,s,r){let m=typeof f=="string"?Va(f):f,h=sl(m.pathname||"/",s);if(h==null)return null;let x=Rm(i);Hy(x);let N=null;for(let S=0;N==null&&S<x.length;++S){let y=Ky(h);N=Zy(x[S],y,r)}return N}function Rm(i,f=[],s=[],r="",m=!1){let h=(x,N,S=m,y)=>{let A={relativePath:y===void 0?x.path||"":y,caseSensitive:x.caseSensitive===!0,childrenIndex:N,route:x};if(A.relativePath.startsWith("/")){if(!A.relativePath.startsWith(r)&&S)return;Ue(A.relativePath.startsWith(r),`Absolute route path "${A.relativePath}" nested under path "${r}" is not valid. An absolute child route path must start with the combined path of all its parent routes.`),A.relativePath=A.relativePath.slice(r.length)}let E=Vt([r,A.relativePath]),L=s.concat(A);x.children&&x.children.length>0&&(Ue(x.index!==!0,`Index routes must not have child routes. Please remove all child routes from route path "${E}".`),Rm(x.children,f,L,E,S)),!(x.path==null&&!x.index)&&f.push({path:E,score:Xy(E,x.index),routesMeta:L})};return i.forEach((x,N)=>{var S;if(x.path===""||!((S=x.path)!=null&&S.includes("?")))h(x,N);else for(let y of Om(x.path))h(x,N,!0,y)}),f}function Om(i){let f=i.split("/");if(f.length===0)return[];let[s,...r]=f,m=s.endsWith("?"),h=s.replace(/\?$/,"");if(r.length===0)return m?[h,""]:[h];let x=Om(r.join("/")),N=[];return N.push(...x.map(S=>S===""?h:[h,S].join("/"))),m&&N.push(...x),N.map(S=>i.startsWith("/")&&S===""?"/":S)}function Hy(i){i.sort((f,s)=>f.score!==s.score?s.score-f.score:Qy(f.routesMeta.map(r=>r.childrenIndex),s.routesMeta.map(r=>r.childrenIndex)))}var By=/^:[\w-]+$/,Ly=3,wy=2,qy=1,Yy=10,Gy=-2,Sm=i=>i==="*";function Xy(i,f){let s=i.split("/"),r=s.length;return s.some(Sm)&&(r+=Gy),f&&(r+=wy),s.filter(m=>!Sm(m)).reduce((m,h)=>m+(By.test(h)?Ly:h===""?qy:Yy),r)}function Qy(i,f){return i.length===f.length&&i.slice(0,-1).every((r,m)=>r===f[m])?i[i.length-1]-f[f.length-1]:0}function Zy(i,f,s=!1){let{routesMeta:r}=i,m={},h="/",x=[];for(let N=0;N<r.length;++N){let S=r[N],y=N===r.length-1,A=h==="/"?f:f.slice(h.length)||"/",E=xi({path:S.relativePath,caseSensitive:S.caseSensitive,end:y},A),L=S.route;if(!E&&y&&s&&!r[r.length-1].route.index&&(E=xi({path:S.relativePath,caseSensitive:S.caseSensitive,end:!1},A)),!E)return null;Object.assign(m,E.params),x.push({params:m,pathname:Vt([h,E.pathname]),pathnameBase:Wy(Vt([h,E.pathnameBase])),route:L}),E.pathnameBase!=="/"&&(h=Vt([h,E.pathnameBase]))}return x}function xi(i,f){typeof i=="string"&&(i={path:i,caseSensitive:!1,end:!0});let[s,r]=Vy(i.path,i.caseSensitive,i.end),m=f.match(s);if(!m)return null;let h=m[0],x=h.replace(/(.)\/+$/,"$1"),N=m.slice(1);return{params:r.reduce((y,{paramName:A,isOptional:E},L)=>{if(A==="*"){let Q=N[L]||"";x=h.slice(0,h.length-Q.length).replace(/(.)\/+$/,"$1")}const X=N[L];return E&&!X?y[A]=void 0:y[A]=(X||"").replace(/%2F/g,"/"),y},{}),pathname:h,pathnameBase:x,pattern:i}}function Vy(i,f=!1,s=!0){Lt(i==="*"||!i.endsWith("*")||i.endsWith("/*"),`Route path "${i}" will be treated as if it were "${i.replace(/\*$/,"/*")}" because the \`*\` character must always follow a \`/\` in the pattern. To get rid of this warning, please change the route path to "${i.replace(/\*$/,"/*")}".`);let r=[],m="^"+i.replace(/\/*\*?$/,"").replace(/^\/*/,"/").replace(/[\\.*+^${}|()[\]]/g,"\\$&").replace(/\/:([\w-]+)(\?)?/g,(x,N,S,y,A)=>{if(r.push({paramName:N,isOptional:S!=null}),S){let E=A.charAt(y+x.length);return E&&E!=="/"?"/([^\\/]*)":"(?:/([^\\/]*))?"}return"/([^\\/]+)"}).replace(/\/([\w-]+)\?(\/|$)/g,"(/$1)?$2");return i.endsWith("*")?(r.push({paramName:"*"}),m+=i==="*"||i==="/*"?"(.*)$":"(?:\\/(.+)|\\/*)$"):s?m+="\\/*$":i!==""&&i!=="/"&&(m+="(?:(?=\\/|$))"),[new RegExp(m,f?void 0:"i"),r]}function Ky(i){try{return i.split("/").map(f=>decodeURIComponent(f).replace(/\//g,"%2F")).join("/")}catch(f){return Lt(!1,`The URL path "${i}" could not be decoded because it is a malformed URL segment. This is probably due to a bad percent encoding (${f}).`),i}}function sl(i,f){if(f==="/")return i;if(!i.toLowerCase().startsWith(f.toLowerCase()))return null;let s=f.endsWith("/")?f.length-1:f.length,r=i.charAt(s);return r&&r!=="/"?null:i.slice(s)||"/"}var Jy=/^(?:[a-z][a-z0-9+.-]*:|\/\/)/i;function ky(i,f="/"){let{pathname:s,search:r="",hash:m=""}=typeof i=="string"?Va(i):i,h;return s?(s=s.replace(/\/\/+/g,"/"),s.startsWith("/")?h=Em(s.substring(1),"/"):h=Em(s,f)):h=f,{pathname:h,search:Fy(r),hash:Iy(m)}}function Em(i,f){let s=f.replace(/\/+$/,"").split("/");return i.split("/").forEach(m=>{m===".."?s.length>1&&s.pop():m!=="."&&s.push(m)}),s.length>1?s.join("/"):"/"}function Zr(i,f,s,r){return`Cannot include a '${i}' character in a manually specified \`to.${f}\` field [${JSON.stringify(r)}].  Please separate it out to the \`to.${s}\` field. Alternatively you may provide the full path as a string in <Link to="..."> and the router will parse it for you.`}function $y(i){return i.filter((f,s)=>s===0||f.route.path&&f.route.path.length>0)}function Pr(i){let f=$y(i);return f.map((s,r)=>r===f.length-1?s.pathname:s.pathnameBase)}function Ti(i,f,s,r=!1){let m;typeof i=="string"?m=Va(i):(m={...i},Ue(!m.pathname||!m.pathname.includes("?"),Zr("?","pathname","search",m)),Ue(!m.pathname||!m.pathname.includes("#"),Zr("#","pathname","hash",m)),Ue(!m.search||!m.search.includes("#"),Zr("#","search","hash",m)));let h=i===""||m.pathname==="",x=h?"/":m.pathname,N;if(x==null)N=s;else{let E=f.length-1;if(!r&&x.startsWith("..")){let L=x.split("/");for(;L[0]==="..";)L.shift(),E-=1;m.pathname=L.join("/")}N=E>=0?f[E]:"/"}let S=ky(m,N),y=x&&x!=="/"&&x.endsWith("/"),A=(h||x===".")&&s.endsWith("/");return!S.pathname.endsWith("/")&&(y||A)&&(S.pathname+="/"),S}var Vt=i=>i.join("/").replace(/\/\/+/g,"/"),Wy=i=>i.replace(/\/+$/,"").replace(/^\/*/,"/"),Fy=i=>!i||i==="?"?"":i.startsWith("?")?i:"?"+i,Iy=i=>!i||i==="#"?"":i.startsWith("#")?i:"#"+i,Py=class{constructor(i,f,s,r=!1){this.status=i,this.statusText=f||"",this.internal=r,s instanceof Error?(this.data=s.toString(),this.error=s):this.data=s}};function e0(i){return i!=null&&typeof i.status=="number"&&typeof i.statusText=="string"&&typeof i.internal=="boolean"&&"data"in i}function t0(i){return i.map(f=>f.route.path).filter(Boolean).join("/").replace(/\/\/*/g,"/")||"/"}var Mm=typeof window<"u"&&typeof window.document<"u"&&typeof window.document.createElement<"u";function Dm(i,f){let s=i;if(typeof s!="string"||!Jy.test(s))return{absoluteURL:void 0,isExternal:!1,to:s};let r=s,m=!1;if(Mm)try{let h=new URL(window.location.href),x=s.startsWith("//")?new URL(h.protocol+s):new URL(s),N=sl(x.pathname,f);x.origin===h.origin&&N!=null?s=N+x.search+x.hash:m=!0}catch{Lt(!1,`<Link to="${s}"> contains an invalid URL which will probably break when clicked - please update to a valid URL path.`)}return{absoluteURL:r,isExternal:m,to:s}}Object.getOwnPropertyNames(Object.prototype).sort().join("\0");var Um=["POST","PUT","PATCH","DELETE"];new Set(Um);var l0=["GET",...Um];new Set(l0);var Ka=g.createContext(null);Ka.displayName="DataRouter";var Ni=g.createContext(null);Ni.displayName="DataRouterState";var a0=g.createContext(!1),Hm=g.createContext({isTransitioning:!1});Hm.displayName="ViewTransition";var n0=g.createContext(new Map);n0.displayName="Fetchers";var u0=g.createContext(null);u0.displayName="Await";var St=g.createContext(null);St.displayName="Navigation";var $n=g.createContext(null);$n.displayName="Location";var Mt=g.createContext({outlet:null,matches:[],isDataRoute:!1});Mt.displayName="Route";var ef=g.createContext(null);ef.displayName="RouteError";var Bm="REACT_ROUTER_ERROR",i0="REDIRECT",c0="ROUTE_ERROR_RESPONSE";function r0(i){if(i.startsWith(`${Bm}:${i0}:{`))try{let f=JSON.parse(i.slice(28));if(typeof f=="object"&&f&&typeof f.status=="number"&&typeof f.statusText=="string"&&typeof f.location=="string"&&typeof f.reloadDocument=="boolean"&&typeof f.replace=="boolean")return f}catch{}}function f0(i){if(i.startsWith(`${Bm}:${c0}:{`))try{let f=JSON.parse(i.slice(40));if(typeof f=="object"&&f&&typeof f.status=="number"&&typeof f.statusText=="string")return new Py(f.status,f.statusText,f.data)}catch{}}function s0(i,{relative:f}={}){Ue(Ja(),"useHref() may be used only in the context of a <Router> component.");let{basename:s,navigator:r}=g.useContext(St),{hash:m,pathname:h,search:x}=Fn(i,{relative:f}),N=h;return s!=="/"&&(N=h==="/"?s:Vt([s,h])),r.createHref({pathname:N,search:x,hash:m})}function Ja(){return g.useContext($n)!=null}function ol(){return Ue(Ja(),"useLocation() may be used only in the context of a <Router> component."),g.useContext($n).location}var Lm="You should call navigate() in a React.useEffect(), not when your component is first rendered.";function wm(i){g.useContext(St).static||g.useLayoutEffect(i)}function Wn(){let{isDataRoute:i}=g.useContext(Mt);return i?j0():o0()}function o0(){Ue(Ja(),"useNavigate() may be used only in the context of a <Router> component.");let i=g.useContext(Ka),{basename:f,navigator:s}=g.useContext(St),{matches:r}=g.useContext(Mt),{pathname:m}=ol(),h=JSON.stringify(Pr(r)),x=g.useRef(!1);return wm(()=>{x.current=!0}),g.useCallback((S,y={})=>{if(Lt(x.current,Lm),!x.current)return;if(typeof S=="number"){s.go(S);return}let A=Ti(S,JSON.parse(h),m,y.relative==="path");i==null&&f!=="/"&&(A.pathname=A.pathname==="/"?f:Vt([f,A.pathname])),(y.replace?s.replace:s.push)(A,y.state,y)},[f,s,h,m,i])}var d0=g.createContext(null);function m0(i){let f=g.useContext(Mt).outlet;return g.useMemo(()=>f&&g.createElement(d0.Provider,{value:i},f),[f,i])}function h0(){let{matches:i}=g.useContext(Mt),f=i[i.length-1];return f?f.params:{}}function Fn(i,{relative:f}={}){let{matches:s}=g.useContext(Mt),{pathname:r}=ol(),m=JSON.stringify(Pr(s));return g.useMemo(()=>Ti(i,JSON.parse(m),r,f==="path"),[i,m,r,f])}function v0(i,f){return qm(i,f)}function qm(i,f,s){var B;Ue(Ja(),"useRoutes() may be used only in the context of a <Router> component.");let{navigator:r}=g.useContext(St),{matches:m}=g.useContext(Mt),h=m[m.length-1],x=h?h.params:{},N=h?h.pathname:"/",S=h?h.pathnameBase:"/",y=h&&h.route;{let w=y&&y.path||"";Gm(N,!y||w.endsWith("*")||w.endsWith("*?"),`You rendered descendant <Routes> (or called \`useRoutes()\`) at "${N}" (under <Route path="${w}">) but the parent route path has no trailing "*". This means if you navigate deeper, the parent won't match anymore and therefore the child routes will never render.

Please change the parent <Route path="${w}"> to <Route path="${w==="/"?"*":`${w}/*`}">.`)}let A=ol(),E;if(f){let w=typeof f=="string"?Va(f):f;Ue(S==="/"||((B=w.pathname)==null?void 0:B.startsWith(S)),`When overriding the location using \`<Routes location>\` or \`useRoutes(routes, location)\`, the location pathname must begin with the portion of the URL pathname that was matched by all parent routes. The current pathname base is "${S}" but pathname "${w.pathname}" was given in the \`location\` prop.`),E=w}else E=A;let L=E.pathname||"/",X=L;if(S!=="/"){let w=S.replace(/^\//,"").split("/");X="/"+L.replace(/^\//,"").split("/").slice(w.length).join("/")}let Q=Cm(i,{pathname:X});Lt(y||Q!=null,`No routes matched location "${E.pathname}${E.search}${E.hash}" `),Lt(Q==null||Q[Q.length-1].route.element!==void 0||Q[Q.length-1].route.Component!==void 0||Q[Q.length-1].route.lazy!==void 0,`Matched leaf route at location "${E.pathname}${E.search}${E.hash}" does not have an element or Component. This means it will render an <Outlet /> with a null value by default resulting in an "empty" page.`);let R=x0(Q&&Q.map(w=>Object.assign({},w,{params:Object.assign({},x,w.params),pathname:Vt([S,r.encodeLocation?r.encodeLocation(w.pathname.replace(/%/g,"%25").replace(/\?/g,"%3F").replace(/#/g,"%23")).pathname:w.pathname]),pathnameBase:w.pathnameBase==="/"?S:Vt([S,r.encodeLocation?r.encodeLocation(w.pathnameBase.replace(/%/g,"%25").replace(/\?/g,"%3F").replace(/#/g,"%23")).pathname:w.pathnameBase])})),m,s);return f&&R?g.createElement($n.Provider,{value:{location:{pathname:"/",search:"",hash:"",state:null,key:"default",unstable_mask:void 0,...E},navigationType:"POP"}},R):R}function y0(){let i=z0(),f=e0(i)?`${i.status} ${i.statusText}`:i instanceof Error?i.message:JSON.stringify(i),s=i instanceof Error?i.stack:null,r="rgba(200,200,200, 0.5)",m={padding:"0.5rem",backgroundColor:r},h={padding:"2px 4px",backgroundColor:r},x=null;return console.error("Error handled by React Router default ErrorBoundary:",i),x=g.createElement(g.Fragment,null,g.createElement("p",null,"💿 Hey developer 👋"),g.createElement("p",null,"You can provide a way better UX than this when your app throws errors by providing your own ",g.createElement("code",{style:h},"ErrorBoundary")," or"," ",g.createElement("code",{style:h},"errorElement")," prop on your route.")),g.createElement(g.Fragment,null,g.createElement("h2",null,"Unexpected Application Error!"),g.createElement("h3",{style:{fontStyle:"italic"}},f),s?g.createElement("pre",{style:m},s):null,x)}var p0=g.createElement(y0,null),Ym=class extends g.Component{constructor(i){super(i),this.state={location:i.location,revalidation:i.revalidation,error:i.error}}static getDerivedStateFromError(i){return{error:i}}static getDerivedStateFromProps(i,f){return f.location!==i.location||f.revalidation!=="idle"&&i.revalidation==="idle"?{error:i.error,location:i.location,revalidation:i.revalidation}:{error:i.error!==void 0?i.error:f.error,location:f.location,revalidation:i.revalidation||f.revalidation}}componentDidCatch(i,f){this.props.onError?this.props.onError(i,f):console.error("React Router caught the following error during render",i)}render(){let i=this.state.error;if(this.context&&typeof i=="object"&&i&&"digest"in i&&typeof i.digest=="string"){const s=f0(i.digest);s&&(i=s)}let f=i!==void 0?g.createElement(Mt.Provider,{value:this.props.routeContext},g.createElement(ef.Provider,{value:i,children:this.props.component})):this.props.children;return this.context?g.createElement(g0,{error:i},f):f}};Ym.contextType=a0;var Vr=new WeakMap;function g0({children:i,error:f}){let{basename:s}=g.useContext(St);if(typeof f=="object"&&f&&"digest"in f&&typeof f.digest=="string"){let r=r0(f.digest);if(r){let m=Vr.get(f);if(m)throw m;let h=Dm(r.location,s);if(Mm&&!Vr.get(f))if(h.isExternal||r.reloadDocument)window.location.href=h.absoluteURL||h.to;else{const x=Promise.resolve().then(()=>window.__reactRouterDataRouter.navigate(h.to,{replace:r.replace}));throw Vr.set(f,x),x}return g.createElement("meta",{httpEquiv:"refresh",content:`0;url=${h.absoluteURL||h.to}`})}}return i}function b0({routeContext:i,match:f,children:s}){let r=g.useContext(Ka);return r&&r.static&&r.staticContext&&(f.route.errorElement||f.route.ErrorBoundary)&&(r.staticContext._deepestRenderedBoundaryId=f.route.id),g.createElement(Mt.Provider,{value:i},s)}function x0(i,f=[],s){let r=s==null?void 0:s.state;if(i==null){if(!r)return null;if(r.errors)i=r.matches;else if(f.length===0&&!r.initialized&&r.matches.length>0)i=r.matches;else return null}let m=i,h=r==null?void 0:r.errors;if(h!=null){let A=m.findIndex(E=>E.route.id&&(h==null?void 0:h[E.route.id])!==void 0);Ue(A>=0,`Could not find a matching route for errors on route IDs: ${Object.keys(h).join(",")}`),m=m.slice(0,Math.min(m.length,A+1))}let x=!1,N=-1;if(s&&r){x=r.renderFallback;for(let A=0;A<m.length;A++){let E=m[A];if((E.route.HydrateFallback||E.route.hydrateFallbackElement)&&(N=A),E.route.id){let{loaderData:L,errors:X}=r,Q=E.route.loader&&!L.hasOwnProperty(E.route.id)&&(!X||X[E.route.id]===void 0);if(E.route.lazy||Q){s.isStatic&&(x=!0),N>=0?m=m.slice(0,N+1):m=[m[0]];break}}}}let S=s==null?void 0:s.onError,y=r&&S?(A,E)=>{var L,X;S(A,{location:r.location,params:((X=(L=r.matches)==null?void 0:L[0])==null?void 0:X.params)??{},unstable_pattern:t0(r.matches),errorInfo:E})}:void 0;return m.reduceRight((A,E,L)=>{let X,Q=!1,R=null,B=null;r&&(X=h&&E.route.id?h[E.route.id]:void 0,R=E.route.errorElement||p0,x&&(N<0&&L===0?(Gm("route-fallback",!1,"No `HydrateFallback` element provided to render during initial hydration"),Q=!0,B=null):N===L&&(Q=!0,B=E.route.hydrateFallbackElement||null)));let w=f.concat(m.slice(0,L+1)),k=()=>{let K;return X?K=R:Q?K=B:E.route.Component?K=g.createElement(E.route.Component,null):E.route.element?K=E.route.element:K=A,g.createElement(b0,{match:E,routeContext:{outlet:A,matches:w,isDataRoute:r!=null},children:K})};return r&&(E.route.ErrorBoundary||E.route.errorElement||L===0)?g.createElement(Ym,{location:r.location,revalidation:r.revalidation,component:R,error:X,children:k(),routeContext:{outlet:null,matches:w,isDataRoute:!0},onError:y}):k()},null)}function tf(i){return`${i} must be used within a data router.  See https://reactrouter.com/en/main/routers/picking-a-router.`}function S0(i){let f=g.useContext(Ka);return Ue(f,tf(i)),f}function E0(i){let f=g.useContext(Ni);return Ue(f,tf(i)),f}function T0(i){let f=g.useContext(Mt);return Ue(f,tf(i)),f}function lf(i){let f=T0(i),s=f.matches[f.matches.length-1];return Ue(s.route.id,`${i} can only be used on routes that contain a unique "id"`),s.route.id}function N0(){return lf("useRouteId")}function z0(){var r;let i=g.useContext(ef),f=E0("useRouteError"),s=lf("useRouteError");return i!==void 0?i:(r=f.errors)==null?void 0:r[s]}function j0(){let{router:i}=S0("useNavigate"),f=lf("useNavigate"),s=g.useRef(!1);return wm(()=>{s.current=!0}),g.useCallback(async(m,h={})=>{Lt(s.current,Lm),s.current&&(typeof m=="number"?await i.navigate(m):await i.navigate(m,{fromRouteId:f,...h}))},[i,f])}var Tm={};function Gm(i,f,s){!f&&!Tm[i]&&(Tm[i]=!0,Lt(!1,s))}g.memo(_0);function _0({routes:i,future:f,state:s,isStatic:r,onError:m}){return qm(i,void 0,{state:s,isStatic:r,onError:m})}function kr({to:i,replace:f,state:s,relative:r}){Ue(Ja(),"<Navigate> may be used only in the context of a <Router> component.");let{static:m}=g.useContext(St);Lt(!m,"<Navigate> must not be used on the initial render in a <StaticRouter>. This is a no-op, but you should modify your code so the <Navigate> is only ever rendered in response to some user interaction or state change.");let{matches:h}=g.useContext(Mt),{pathname:x}=ol(),N=Wn(),S=Ti(i,Pr(h),x,r==="path"),y=JSON.stringify(S);return g.useEffect(()=>{N(JSON.parse(y),{replace:f,state:s,relative:r})},[N,y,r,f,s]),null}function A0(i){return m0(i.context)}function wl(i){Ue(!1,"A <Route> is only ever to be used as the child of <Routes> element, never rendered directly. Please wrap your <Route> in a <Routes>.")}function C0({basename:i="/",children:f=null,location:s,navigationType:r="POP",navigator:m,static:h=!1,unstable_useTransitions:x}){Ue(!Ja(),"You cannot render a <Router> inside another <Router>. You should never have more than one in your app.");let N=i.replace(/^\/*/,"/"),S=g.useMemo(()=>({basename:N,navigator:m,static:h,unstable_useTransitions:x,future:{}}),[N,m,h,x]);typeof s=="string"&&(s=Va(s));let{pathname:y="/",search:A="",hash:E="",state:L=null,key:X="default",unstable_mask:Q}=s,R=g.useMemo(()=>{let B=sl(y,N);return B==null?null:{location:{pathname:B,search:A,hash:E,state:L,key:X,unstable_mask:Q},navigationType:r}},[N,y,A,E,L,X,r,Q]);return Lt(R!=null,`<Router basename="${N}"> is not able to match the URL "${y}${A}${E}" because it does not start with the basename, so the <Router> won't render anything.`),R==null?null:g.createElement(St.Provider,{value:S},g.createElement($n.Provider,{children:f,value:R}))}function R0({children:i,location:f}){return v0($r(i),f)}function $r(i,f=[]){let s=[];return g.Children.forEach(i,(r,m)=>{if(!g.isValidElement(r))return;let h=[...f,m];if(r.type===g.Fragment){s.push.apply(s,$r(r.props.children,h));return}Ue(r.type===wl,`[${typeof r.type=="string"?r.type:r.type.name}] is not a <Route> component. All component children of <Routes> must be a <Route> or <React.Fragment>`),Ue(!r.props.index||!r.props.children,"An index route cannot have child routes.");let x={id:r.props.id||h.join("-"),caseSensitive:r.props.caseSensitive,element:r.props.element,Component:r.props.Component,index:r.props.index,path:r.props.path,middleware:r.props.middleware,loader:r.props.loader,action:r.props.action,hydrateFallbackElement:r.props.hydrateFallbackElement,HydrateFallback:r.props.HydrateFallback,errorElement:r.props.errorElement,ErrorBoundary:r.props.ErrorBoundary,hasErrorBoundary:r.props.hasErrorBoundary===!0||r.props.ErrorBoundary!=null||r.props.errorElement!=null,shouldRevalidate:r.props.shouldRevalidate,handle:r.props.handle,lazy:r.props.lazy};r.props.children&&(x.children=$r(r.props.children,h)),s.push(x)}),s}var gi="get",bi="application/x-www-form-urlencoded";function zi(i){return typeof HTMLElement<"u"&&i instanceof HTMLElement}function O0(i){return zi(i)&&i.tagName.toLowerCase()==="button"}function M0(i){return zi(i)&&i.tagName.toLowerCase()==="form"}function D0(i){return zi(i)&&i.tagName.toLowerCase()==="input"}function U0(i){return!!(i.metaKey||i.altKey||i.ctrlKey||i.shiftKey)}function H0(i,f){return i.button===0&&(!f||f==="_self")&&!U0(i)}var pi=null;function B0(){if(pi===null)try{new FormData(document.createElement("form"),0),pi=!1}catch{pi=!0}return pi}var L0=new Set(["application/x-www-form-urlencoded","multipart/form-data","text/plain"]);function Kr(i){return i!=null&&!L0.has(i)?(Lt(!1,`"${i}" is not a valid \`encType\` for \`<Form>\`/\`<fetcher.Form>\` and will default to "${bi}"`),null):i}function w0(i,f){let s,r,m,h,x;if(M0(i)){let N=i.getAttribute("action");r=N?sl(N,f):null,s=i.getAttribute("method")||gi,m=Kr(i.getAttribute("enctype"))||bi,h=new FormData(i)}else if(O0(i)||D0(i)&&(i.type==="submit"||i.type==="image")){let N=i.form;if(N==null)throw new Error('Cannot submit a <button> or <input type="submit"> without a <form>');let S=i.getAttribute("formaction")||N.getAttribute("action");if(r=S?sl(S,f):null,s=i.getAttribute("formmethod")||N.getAttribute("method")||gi,m=Kr(i.getAttribute("formenctype"))||Kr(N.getAttribute("enctype"))||bi,h=new FormData(N,i),!B0()){let{name:y,type:A,value:E}=i;if(A==="image"){let L=y?`${y}.`:"";h.append(`${L}x`,"0"),h.append(`${L}y`,"0")}else y&&h.append(y,E)}}else{if(zi(i))throw new Error('Cannot submit element that is not <form>, <button>, or <input type="submit|image">');s=gi,r=null,m=bi,x=i}return h&&m==="text/plain"&&(x=h,h=void 0),{action:r,method:s.toLowerCase(),encType:m,formData:h,body:x}}Object.getOwnPropertyNames(Object.prototype).sort().join("\0");function af(i,f){if(i===!1||i===null||typeof i>"u")throw new Error(f)}function q0(i,f,s,r){let m=typeof i=="string"?new URL(i,typeof window>"u"?"server://singlefetch/":window.location.origin):i;return s?m.pathname.endsWith("/")?m.pathname=`${m.pathname}_.${r}`:m.pathname=`${m.pathname}.${r}`:m.pathname==="/"?m.pathname=`_root.${r}`:f&&sl(m.pathname,f)==="/"?m.pathname=`${f.replace(/\/$/,"")}/_root.${r}`:m.pathname=`${m.pathname.replace(/\/$/,"")}.${r}`,m}async function Y0(i,f){if(i.id in f)return f[i.id];try{let s=await import(i.module);return f[i.id]=s,s}catch(s){return console.error(`Error loading route module \`${i.module}\`, reloading page...`),console.error(s),window.__reactRouterContext&&window.__reactRouterContext.isSpaMode,window.location.reload(),new Promise(()=>{})}}function G0(i){return i==null?!1:i.href==null?i.rel==="preload"&&typeof i.imageSrcSet=="string"&&typeof i.imageSizes=="string":typeof i.rel=="string"&&typeof i.href=="string"}async function X0(i,f,s){let r=await Promise.all(i.map(async m=>{let h=f.routes[m.route.id];if(h){let x=await Y0(h,s);return x.links?x.links():[]}return[]}));return K0(r.flat(1).filter(G0).filter(m=>m.rel==="stylesheet"||m.rel==="preload").map(m=>m.rel==="stylesheet"?{...m,rel:"prefetch",as:"style"}:{...m,rel:"prefetch"}))}function Nm(i,f,s,r,m,h){let x=(S,y)=>s[y]?S.route.id!==s[y].route.id:!0,N=(S,y)=>{var A;return s[y].pathname!==S.pathname||((A=s[y].route.path)==null?void 0:A.endsWith("*"))&&s[y].params["*"]!==S.params["*"]};return h==="assets"?f.filter((S,y)=>x(S,y)||N(S,y)):h==="data"?f.filter((S,y)=>{var E;let A=r.routes[S.route.id];if(!A||!A.hasLoader)return!1;if(x(S,y)||N(S,y))return!0;if(S.route.shouldRevalidate){let L=S.route.shouldRevalidate({currentUrl:new URL(m.pathname+m.search+m.hash,window.origin),currentParams:((E=s[0])==null?void 0:E.params)||{},nextUrl:new URL(i,window.origin),nextParams:S.params,defaultShouldRevalidate:!0});if(typeof L=="boolean")return L}return!0}):[]}function Q0(i,f,{includeHydrateFallback:s}={}){return Z0(i.map(r=>{let m=f.routes[r.route.id];if(!m)return[];let h=[m.module];return m.clientActionModule&&(h=h.concat(m.clientActionModule)),m.clientLoaderModule&&(h=h.concat(m.clientLoaderModule)),s&&m.hydrateFallbackModule&&(h=h.concat(m.hydrateFallbackModule)),m.imports&&(h=h.concat(m.imports)),h}).flat(1))}function Z0(i){return[...new Set(i)]}function V0(i){let f={},s=Object.keys(i).sort();for(let r of s)f[r]=i[r];return f}function K0(i,f){let s=new Set;return new Set(f),i.reduce((r,m)=>{let h=JSON.stringify(V0(m));return s.has(h)||(s.add(h),r.push({key:h,link:m})),r},[])}function Xm(){let i=g.useContext(Ka);return af(i,"You must render this element inside a <DataRouterContext.Provider> element"),i}function J0(){let i=g.useContext(Ni);return af(i,"You must render this element inside a <DataRouterStateContext.Provider> element"),i}var nf=g.createContext(void 0);nf.displayName="FrameworkContext";function Qm(){let i=g.useContext(nf);return af(i,"You must render this element inside a <HydratedRouter> element"),i}function k0(i,f){let s=g.useContext(nf),[r,m]=g.useState(!1),[h,x]=g.useState(!1),{onFocus:N,onBlur:S,onMouseEnter:y,onMouseLeave:A,onTouchStart:E}=f,L=g.useRef(null);g.useEffect(()=>{if(i==="render"&&x(!0),i==="viewport"){let R=w=>{w.forEach(k=>{x(k.isIntersecting)})},B=new IntersectionObserver(R,{threshold:.5});return L.current&&B.observe(L.current),()=>{B.disconnect()}}},[i]),g.useEffect(()=>{if(r){let R=setTimeout(()=>{x(!0)},100);return()=>{clearTimeout(R)}}},[r]);let X=()=>{m(!0)},Q=()=>{m(!1),x(!1)};return s?i!=="intent"?[h,L,{}]:[h,L,{onFocus:Jn(N,X),onBlur:Jn(S,Q),onMouseEnter:Jn(y,X),onMouseLeave:Jn(A,Q),onTouchStart:Jn(E,X)}]:[!1,L,{}]}function Jn(i,f){return s=>{i&&i(s),s.defaultPrevented||f(s)}}function $0({page:i,...f}){let{router:s}=Xm(),r=g.useMemo(()=>Cm(s.routes,i,s.basename),[s.routes,i,s.basename]);return r?g.createElement(F0,{page:i,matches:r,...f}):null}function W0(i){let{manifest:f,routeModules:s}=Qm(),[r,m]=g.useState([]);return g.useEffect(()=>{let h=!1;return X0(i,f,s).then(x=>{h||m(x)}),()=>{h=!0}},[i,f,s]),r}function F0({page:i,matches:f,...s}){let r=ol(),{future:m,manifest:h,routeModules:x}=Qm(),{basename:N}=Xm(),{loaderData:S,matches:y}=J0(),A=g.useMemo(()=>Nm(i,f,y,h,r,"data"),[i,f,y,h,r]),E=g.useMemo(()=>Nm(i,f,y,h,r,"assets"),[i,f,y,h,r]),L=g.useMemo(()=>{if(i===r.pathname+r.search+r.hash)return[];let R=new Set,B=!1;if(f.forEach(k=>{var ce;let K=h.routes[k.route.id];!K||!K.hasLoader||(!A.some(le=>le.route.id===k.route.id)&&k.route.id in S&&((ce=x[k.route.id])!=null&&ce.shouldRevalidate)||K.hasClientLoader?B=!0:R.add(k.route.id))}),R.size===0)return[];let w=q0(i,N,m.unstable_trailingSlashAwareDataRequests,"data");return B&&R.size>0&&w.searchParams.set("_routes",f.filter(k=>R.has(k.route.id)).map(k=>k.route.id).join(",")),[w.pathname+w.search]},[N,m.unstable_trailingSlashAwareDataRequests,S,r,h,A,f,i,x]),X=g.useMemo(()=>Q0(E,h),[E,h]),Q=W0(E);return g.createElement(g.Fragment,null,L.map(R=>g.createElement("link",{key:R,rel:"prefetch",as:"fetch",href:R,...s})),X.map(R=>g.createElement("link",{key:R,rel:"modulepreload",href:R,...s})),Q.map(({key:R,link:B})=>g.createElement("link",{key:R,nonce:s.nonce,...B,crossOrigin:B.crossOrigin??s.crossOrigin})))}function I0(...i){return f=>{i.forEach(s=>{typeof s=="function"?s(f):s!=null&&(s.current=f)})}}var P0=typeof window<"u"&&typeof window.document<"u"&&typeof window.document.createElement<"u";try{P0&&(window.__reactRouterVersion="7.13.2")}catch{}function ep({basename:i,children:f,unstable_useTransitions:s,window:r}){let m=g.useRef();m.current==null&&(m.current=Ry({window:r,v5Compat:!0}));let h=m.current,[x,N]=g.useState({action:h.action,location:h.location}),S=g.useCallback(y=>{s===!1?N(y):g.startTransition(()=>N(y))},[s]);return g.useLayoutEffect(()=>h.listen(S),[h,S]),g.createElement(C0,{basename:i,children:f,location:x.location,navigationType:x.action,navigator:h,unstable_useTransitions:s})}var Zm=/^(?:[a-z][a-z0-9+.-]*:|\/\/)/i,Vm=g.forwardRef(function({onClick:f,discover:s="render",prefetch:r="none",relative:m,reloadDocument:h,replace:x,unstable_mask:N,state:S,target:y,to:A,preventScrollReset:E,viewTransition:L,unstable_defaultShouldRevalidate:X,...Q},R){let{basename:B,navigator:w,unstable_useTransitions:k}=g.useContext(St),K=typeof A=="string"&&Zm.test(A),ce=Dm(A,B);A=ce.to;let le=s0(A,{relative:m}),re=ol(),$=null;if(N){let fe=Ti(N,[],re.unstable_mask?re.unstable_mask.pathname:"/",!0);B!=="/"&&(fe.pathname=fe.pathname==="/"?B:Vt([B,fe.pathname])),$=w.createHref(fe)}let[_e,He,at]=k0(r,Q),Ve=ap(A,{replace:x,unstable_mask:N,state:S,target:y,preventScrollReset:E,relative:m,viewTransition:L,unstable_defaultShouldRevalidate:X,unstable_useTransitions:k});function Ce(fe){f&&f(fe),fe.defaultPrevented||Ve(fe)}let F=!(ce.isExternal||h),Me=g.createElement("a",{...Q,...at,href:(F?$:void 0)||ce.absoluteURL||le,onClick:F?Ce:f,ref:I0(R,He),target:y,"data-discover":!K&&s==="render"?"true":void 0});return _e&&!K?g.createElement(g.Fragment,null,Me,g.createElement($0,{page:le})):Me});Vm.displayName="Link";var Km=g.forwardRef(function({"aria-current":f="page",caseSensitive:s=!1,className:r="",end:m=!1,style:h,to:x,viewTransition:N,children:S,...y},A){let E=Fn(x,{relative:y.relative}),L=ol(),X=g.useContext(Ni),{navigator:Q,basename:R}=g.useContext(St),B=X!=null&&rp(E)&&N===!0,w=Q.encodeLocation?Q.encodeLocation(E).pathname:E.pathname,k=L.pathname,K=X&&X.navigation&&X.navigation.location?X.navigation.location.pathname:null;s||(k=k.toLowerCase(),K=K?K.toLowerCase():null,w=w.toLowerCase()),K&&R&&(K=sl(K,R)||K);const ce=w!=="/"&&w.endsWith("/")?w.length-1:w.length;let le=k===w||!m&&k.startsWith(w)&&k.charAt(ce)==="/",re=K!=null&&(K===w||!m&&K.startsWith(w)&&K.charAt(w.length)==="/"),$={isActive:le,isPending:re,isTransitioning:B},_e=le?f:void 0,He;typeof r=="function"?He=r($):He=[r,le?"active":null,re?"pending":null,B?"transitioning":null].filter(Boolean).join(" ");let at=typeof h=="function"?h($):h;return g.createElement(Vm,{...y,"aria-current":_e,className:He,ref:A,style:at,to:x,viewTransition:N},typeof S=="function"?S($):S)});Km.displayName="NavLink";var tp=g.forwardRef(({discover:i="render",fetcherKey:f,navigate:s,reloadDocument:r,replace:m,state:h,method:x=gi,action:N,onSubmit:S,relative:y,preventScrollReset:A,viewTransition:E,unstable_defaultShouldRevalidate:L,...X},Q)=>{let{unstable_useTransitions:R}=g.useContext(St),B=ip(),w=cp(N,{relative:y}),k=x.toLowerCase()==="get"?"get":"post",K=typeof N=="string"&&Zm.test(N),ce=le=>{if(S&&S(le),le.defaultPrevented)return;le.preventDefault();let re=le.nativeEvent.submitter,$=(re==null?void 0:re.getAttribute("formmethod"))||x,_e=()=>B(re||le.currentTarget,{fetcherKey:f,method:$,navigate:s,replace:m,state:h,relative:y,preventScrollReset:A,viewTransition:E,unstable_defaultShouldRevalidate:L});R&&s!==!1?g.startTransition(()=>_e()):_e()};return g.createElement("form",{ref:Q,method:k,action:w,onSubmit:r?S:ce,...X,"data-discover":!K&&i==="render"?"true":void 0})});tp.displayName="Form";function lp(i){return`${i} must be used within a data router.  See https://reactrouter.com/en/main/routers/picking-a-router.`}function Jm(i){let f=g.useContext(Ka);return Ue(f,lp(i)),f}function ap(i,{target:f,replace:s,unstable_mask:r,state:m,preventScrollReset:h,relative:x,viewTransition:N,unstable_defaultShouldRevalidate:S,unstable_useTransitions:y}={}){let A=Wn(),E=ol(),L=Fn(i,{relative:x});return g.useCallback(X=>{if(H0(X,f)){X.preventDefault();let Q=s!==void 0?s:kn(E)===kn(L),R=()=>A(i,{replace:Q,unstable_mask:r,state:m,preventScrollReset:h,relative:x,viewTransition:N,unstable_defaultShouldRevalidate:S});y?g.startTransition(()=>R()):R()}},[E,A,L,s,r,m,f,i,h,x,N,S,y])}var np=0,up=()=>`__${String(++np)}__`;function ip(){let{router:i}=Jm("useSubmit"),{basename:f}=g.useContext(St),s=N0(),r=i.fetch,m=i.navigate;return g.useCallback(async(h,x={})=>{let{action:N,method:S,encType:y,formData:A,body:E}=w0(h,f);if(x.navigate===!1){let L=x.fetcherKey||up();await r(L,s,x.action||N,{unstable_defaultShouldRevalidate:x.unstable_defaultShouldRevalidate,preventScrollReset:x.preventScrollReset,formData:A,body:E,formMethod:x.method||S,formEncType:x.encType||y,flushSync:x.flushSync})}else await m(x.action||N,{unstable_defaultShouldRevalidate:x.unstable_defaultShouldRevalidate,preventScrollReset:x.preventScrollReset,formData:A,body:E,formMethod:x.method||S,formEncType:x.encType||y,replace:x.replace,state:x.state,fromRouteId:s,flushSync:x.flushSync,viewTransition:x.viewTransition})},[r,m,f,s])}function cp(i,{relative:f}={}){let{basename:s}=g.useContext(St),r=g.useContext(Mt);Ue(r,"useFormAction must be used inside a RouteContext");let[m]=r.matches.slice(-1),h={...Fn(i||".",{relative:f})},x=ol();if(i==null){h.search=x.search;let N=new URLSearchParams(h.search),S=N.getAll("index");if(S.some(A=>A==="")){N.delete("index"),S.filter(E=>E).forEach(E=>N.append("index",E));let A=N.toString();h.search=A?`?${A}`:""}}return(!i||i===".")&&m.route.index&&(h.search=h.search?h.search.replace(/^\?/,"?index&"):"?index"),s!=="/"&&(h.pathname=h.pathname==="/"?s:Vt([s,h.pathname])),kn(h)}function rp(i,{relative:f}={}){let s=g.useContext(Hm);Ue(s!=null,"`useViewTransitionState` must be used within `react-router-dom`'s `RouterProvider`.  Did you accidentally import `RouterProvider` from `react-router`?");let{basename:r}=Jm("useViewTransitionState"),m=Fn(i,{relative:f});if(!s.isTransitioning)return!1;let h=sl(s.currentLocation.pathname,r)||s.currentLocation.pathname,x=sl(s.nextLocation.pathname,r)||s.nextLocation.pathname;return xi(m.pathname,x)!=null||xi(m.pathname,h)!=null}class fp{constructor(f){this.opts=f}get baseUrl(){return this.opts.baseUrl}getToken(){return this.opts.getToken()}headers(f,s){const r=this.opts.getToken(),m={...f||{},...r?{Authorization:`Bearer ${r}`}:{}};return s instanceof FormData?m:{"Content-Type":"application/json",...m}}async request(f,s={}){var m;const r=await fetch(this.opts.baseUrl+f,{...s,headers:this.headers(s.headers,s.body??void 0)});if(r.status===401&&this.opts.onUnauthorized&&this.opts.onUnauthorized(),!r.ok){const h=await r.text();let x=h;try{const N=JSON.parse(h);x=N.detail||((m=N.error)==null?void 0:m.message)||h}catch{}throw new Error(x||`HTTP ${r.status}`)}return await r.json()}get(f){return this.request(f)}post(f,s){const r=s instanceof FormData,m=s===void 0?void 0:r?s:JSON.stringify(s);return this.request(f,{method:"POST",body:m})}postFormData(f,s){const r=this.opts.getToken();return this.request(f,{method:"POST",headers:r?{Authorization:`Bearer ${r}`}:void 0,body:s})}put(f,s){return this.request(f,{method:"PUT",body:JSON.stringify(s)})}delete(f){return this.request(f,{method:"DELETE"})}}const km=g.createContext(void 0),sp=({children:i})=>{const[f,s]=g.useState(localStorage.getItem("glyphh_token")),[r,m]=g.useState(localStorage.getItem("glyphh_org_id")),[h,x]=g.useState(()=>{const R=localStorage.getItem("glyphh_user");return R?JSON.parse(R):null}),[N,S]=g.useState(null),y=g.useCallback(()=>{s(null),m(null),x(null),localStorage.removeItem("glyphh_token"),localStorage.removeItem("glyphh_platform_token"),localStorage.removeItem("glyphh_refresh_token"),localStorage.removeItem("glyphh_org_id"),localStorage.removeItem("glyphh_user")},[]),A=g.useMemo(()=>new fp({baseUrl:"",getToken:()=>f,onUnauthorized:()=>{const R=localStorage.getItem("glyphh_refresh_token");if(!R){y();return}fetch("/ui/auth/refresh",{method:"POST",headers:{"Content-Type":"application/json"},body:JSON.stringify({refresh_token:R})}).then(B=>B.ok?B.json():Promise.reject()).then(B=>{const w=B.runtime_token||B.access_token;w?(s(w),localStorage.setItem("glyphh_token",w),B.access_token&&localStorage.setItem("glyphh_platform_token",B.access_token),B.refresh_token&&localStorage.setItem("glyphh_refresh_token",B.refresh_token)):y()}).catch(()=>y())}}),[f,y]),E=g.useCallback(async()=>{try{const R=await A.get("/ui/session");return R.version&&S(R.version),R.authenticated&&R.org_id?(m(R.org_id),localStorage.setItem("glyphh_org_id",R.org_id),!0):!1}catch{return!1}},[A]),L=g.useCallback(async()=>await A.post("/ui/auth/device/start"),[A]),X=g.useCallback(async R=>{const B=await A.post("/ui/auth/device/poll",{device_code:R});if(B.status==="approved"){const w=B.runtime_token||B.access_token||null,k=B.user||null,K=(k==null?void 0:k.org_id)||null;return w&&(s(w),localStorage.setItem("glyphh_token",w)),B.access_token&&localStorage.setItem("glyphh_platform_token",B.access_token),B.refresh_token&&localStorage.setItem("glyphh_refresh_token",B.refresh_token),k&&(x(k),localStorage.setItem("glyphh_user",JSON.stringify(k))),K&&(m(K),localStorage.setItem("glyphh_org_id",K)),"approved"}return B.status==="expired"?"expired":"pending"},[A]),Q=g.useCallback(()=>{y()},[y]);return d.jsx(km.Provider,{value:{user:h,token:f,orgId:r,api:A,version:N,login:L,pollLogin:X,logout:Q,checkSession:E},children:i})},ka=()=>{const i=g.useContext(km);if(!i)throw new Error("useAuth must be inside AuthProvider");return i},$m=g.createContext(void 0),zm=()=>window.matchMedia&&window.matchMedia("(prefers-color-scheme: light)").matches?"light":"dark",op=({children:i})=>{const[f,s]=g.useState(localStorage.getItem("theme")||"system"),[r,m]=g.useState(f==="system"?zm():f);return g.useEffect(()=>{if(f==="system"){const h=()=>m(zm());h();const x=window.matchMedia("(prefers-color-scheme: light)");return x.addEventListener("change",h),()=>x.removeEventListener("change",h)}else m(f)},[f]),g.useEffect(()=>{document.documentElement.setAttribute("data-theme",r),localStorage.setItem("theme",f)},[r,f]),d.jsx($m.Provider,{value:{theme:r,preference:f,setPreference:s},children:i})},Wm=()=>{const i=g.useContext($m);if(!i)throw new Error("useTheme must be used inside ThemeProvider");return i};var Fm={color:void 0,size:void 0,className:void 0,style:void 0,attr:void 0},jm=ua.createContext&&ua.createContext(Fm),dp=["attr","size","title"];function mp(i,f){if(i==null)return{};var s,r,m=hp(i,f);if(Object.getOwnPropertySymbols){var h=Object.getOwnPropertySymbols(i);for(r=0;r<h.length;r++)s=h[r],f.indexOf(s)===-1&&{}.propertyIsEnumerable.call(i,s)&&(m[s]=i[s])}return m}function hp(i,f){if(i==null)return{};var s={};for(var r in i)if({}.hasOwnProperty.call(i,r)){if(f.indexOf(r)!==-1)continue;s[r]=i[r]}return s}function Si(){return Si=Object.assign?Object.assign.bind():function(i){for(var f=1;f<arguments.length;f++){var s=arguments[f];for(var r in s)({}).hasOwnProperty.call(s,r)&&(i[r]=s[r])}return i},Si.apply(null,arguments)}function _m(i,f){var s=Object.keys(i);if(Object.getOwnPropertySymbols){var r=Object.getOwnPropertySymbols(i);f&&(r=r.filter(function(m){return Object.getOwnPropertyDescriptor(i,m).enumerable})),s.push.apply(s,r)}return s}function Ei(i){for(var f=1;f<arguments.length;f++){var s=arguments[f]!=null?arguments[f]:{};f%2?_m(Object(s),!0).forEach(function(r){vp(i,r,s[r])}):Object.getOwnPropertyDescriptors?Object.defineProperties(i,Object.getOwnPropertyDescriptors(s)):_m(Object(s)).forEach(function(r){Object.defineProperty(i,r,Object.getOwnPropertyDescriptor(s,r))})}return i}function vp(i,f,s){return(f=yp(f))in i?Object.defineProperty(i,f,{value:s,enumerable:!0,configurable:!0,writable:!0}):i[f]=s,i}function yp(i){var f=pp(i,"string");return typeof f=="symbol"?f:f+""}function pp(i,f){if(typeof i!="object"||!i)return i;var s=i[Symbol.toPrimitive];if(s!==void 0){var r=s.call(i,f);if(typeof r!="object")return r;throw new TypeError("@@toPrimitive must return a primitive value.")}return(f==="string"?String:Number)(i)}function Im(i){return i&&i.map((f,s)=>ua.createElement(f.tag,Ei({key:s},f.attr),Im(f.child)))}function wt(i){return f=>ua.createElement(gp,Si({attr:Ei({},i.attr)},f),Im(i.child))}function gp(i){var f=s=>{var{attr:r,size:m,title:h}=i,x=mp(i,dp),N=m||s.size||"1em",S;return s.className&&(S=s.className),i.className&&(S=(S?S+" ":"")+i.className),ua.createElement("svg",Si({stroke:"currentColor",fill:"currentColor",strokeWidth:"0"},s.attr,r,x,{className:S,style:Ei(Ei({color:i.color||s.color},s.style),i.style),height:N,width:N,xmlns:"http://www.w3.org/2000/svg"}),h&&ua.createElement("title",null,h),i.children)};return jm!==void 0?ua.createElement(jm.Consumer,null,s=>f(s)):f(Fm)}function bp(i){return wt({attr:{viewBox:"0 0 20 20",fill:"currentColor","aria-hidden":"true"},child:[{tag:"path",attr:{fillRule:"evenodd",d:"M16.707 5.293a1 1 0 010 1.414l-8 8a1 1 0 01-1.414 0l-4-4a1 1 0 011.414-1.414L8 12.586l7.293-7.293a1 1 0 011.414 0z",clipRule:"evenodd"},child:[]}]})(i)}function xp(i){return wt({attr:{fill:"none",viewBox:"0 0 24 24",strokeWidth:"2",stroke:"currentColor","aria-hidden":"true"},child:[{tag:"path",attr:{strokeLinecap:"round",strokeLinejoin:"round",d:"M6 18L18 6M6 6l12 12"},child:[]}]})(i)}function Am(i){return wt({attr:{fill:"none",viewBox:"0 0 24 24",strokeWidth:"2",stroke:"currentColor","aria-hidden":"true"},child:[{tag:"path",attr:{strokeLinecap:"round",strokeLinejoin:"round",d:"M5.121 17.804A13.937 13.937 0 0112 16c2.5 0 4.847.655 6.879 1.804M15 10a3 3 0 11-6 0 3 3 0 016 0zm6 2a9 9 0 11-18 0 9 9 0 0118 0z"},child:[]}]})(i)}function Sp(i){return wt({attr:{fill:"none",viewBox:"0 0 24 24",strokeWidth:"2",stroke:"currentColor","aria-hidden":"true"},child:[{tag:"path",attr:{strokeLinecap:"round",strokeLinejoin:"round",d:"M19 7l-.867 12.142A2 2 0 0116.138 21H7.862a2 2 0 01-1.995-1.858L5 7m5 4v6m4-6v6m1-10V4a1 1 0 00-1-1h-4a1 1 0 00-1 1v3M4 7h16"},child:[]}]})(i)}function Ep(i){return wt({attr:{fill:"none",viewBox:"0 0 24 24",strokeWidth:"2",stroke:"currentColor","aria-hidden":"true"},child:[{tag:"path",attr:{strokeLinecap:"round",strokeLinejoin:"round",d:"M15.232 5.232l3.536 3.536m-2.036-5.036a2.5 2.5 0 113.536 3.536L6.5 21.036H3v-3.572L16.732 3.732z"},child:[]}]})(i)}function Tp(i){return wt({attr:{fill:"none",viewBox:"0 0 24 24",strokeWidth:"2",stroke:"currentColor","aria-hidden":"true"},child:[{tag:"path",attr:{strokeLinecap:"round",strokeLinejoin:"round",d:"M20.354 15.354A9 9 0 018.646 3.646 9.003 9.003 0 0012 21a9.003 9.003 0 008.354-5.646z"},child:[]}]})(i)}function Np(i){return wt({attr:{fill:"none",viewBox:"0 0 24 24",strokeWidth:"2",stroke:"currentColor","aria-hidden":"true"},child:[{tag:"path",attr:{strokeLinecap:"round",strokeLinejoin:"round",d:"M12 15v2m-6 4h12a2 2 0 002-2v-6a2 2 0 00-2-2H6a2 2 0 00-2 2v6a2 2 0 002 2zm10-10V7a4 4 0 00-8 0v4h8z"},child:[]}]})(i)}function Wr(i){return wt({attr:{fill:"none",viewBox:"0 0 24 24",strokeWidth:"2",stroke:"currentColor","aria-hidden":"true"},child:[{tag:"path",attr:{strokeLinecap:"round",strokeLinejoin:"round",d:"M15 7a2 2 0 012 2m4 0a6 6 0 01-7.743 5.743L11 17H9v2H7v2H4a1 1 0 01-1-1v-2.586a1 1 0 01.293-.707l5.964-5.964A6 6 0 1121 9z"},child:[]}]})(i)}function zp(i){return wt({attr:{fill:"none",viewBox:"0 0 24 24",strokeWidth:"2",stroke:"currentColor","aria-hidden":"true"},child:[{tag:"path",attr:{strokeLinecap:"round",strokeLinejoin:"round",d:"M12 9v2m0 4h.01m-6.938 4h13.856c1.54 0 2.502-1.667 1.732-3L13.732 4c-.77-1.333-2.694-1.333-3.464 0L3.34 16c-.77 1.333.192 3 1.732 3z"},child:[]}]})(i)}function jp(i){return wt({attr:{fill:"none",viewBox:"0 0 24 24",strokeWidth:"2",stroke:"currentColor","aria-hidden":"true"},child:[{tag:"path",attr:{strokeLinecap:"round",strokeLinejoin:"round",d:"M8 16H6a2 2 0 01-2-2V6a2 2 0 012-2h8a2 2 0 012 2v2m-6 12h8a2 2 0 002-2v-8a2 2 0 00-2-2h-8a2 2 0 00-2 2v8a2 2 0 002 2z"},child:[]}]})(i)}function uf(i){return wt({attr:{fill:"none",viewBox:"0 0 24 24",strokeWidth:"2",stroke:"currentColor","aria-hidden":"true"},child:[{tag:"path",attr:{strokeLinecap:"round",strokeLinejoin:"round",d:"M14 10l-2 1m0 0l-2-1m2 1v2.5M20 7l-2 1m2-1l-2-1m2 1v2.5M14 4l-2-1-2 1M4 7l2-1M4 7l2 1M4 7v2.5M12 21l-2-1m2 1l2-1m-2 1v-2.5M6 18l-2-1v-2.5M18 18l2-1v-2.5"},child:[]}]})(i)}function _p(){const{theme:i,preference:f,setPreference:s}=Wm(),{user:r,logout:m,version:h}=ka(),[x,N]=g.useState(!1);g.useEffect(()=>{if(!x)return;const E=L=>{const X=L.target;X&&X.closest("[data-settings-modal]")||N(!1)};return document.addEventListener("mousedown",E),()=>document.removeEventListener("mousedown",E)},[x]);const S="flex flex-col items-center gap-1 px-2 py-1 rounded-2xl text-sm transition text-[var(--muted)]",y="flex items-center justify-center w-11 h-11 rounded-full border border-transparent transition",A="border-[var(--accent)] bg-[var(--accent-soft)] text-[var(--accent)]";return d.jsxs("aside",{className:"w-[64px] h-screen bg-[var(--sidebar)] border-r border-[var(--sidebar-border)] flex flex-col justify-between py-6",children:[d.jsxs("div",{className:"flex flex-col items-center gap-8",children:[d.jsx("div",{className:"flex flex-col items-center gap-1",children:d.jsx("img",{src:"/glyphh-logo-square.png",alt:"Glyphh",className:"w-10 h-10"})}),d.jsx("nav",{className:"flex flex-col items-center gap-2",children:[{to:"/models",icon:uf,label:"Models"},{to:"/tokens",icon:Wr,label:"Tokens"}].map(({to:E,icon:L,label:X})=>d.jsx(Km,{to:E,className:({isActive:Q})=>`${S} ${Q?"text-[var(--accent)]":"text-[var(--muted)]"}`,title:X,children:({isActive:Q})=>d.jsxs(d.Fragment,{children:[d.jsx("div",{className:`${y} ${Q?A:"border-[var(--border)] text-[var(--muted)] hover:border-[var(--accent)] hover:text-[var(--accent)]"}`,children:d.jsx(L,{size:22})}),d.jsx("span",{className:"text-[10px]",children:X})]})},E))})]}),d.jsx("div",{className:"flex flex-col items-center px-1",children:d.jsx("button",{type:"button",onClick:()=>N(!0),className:"flex items-center justify-center w-10 h-10 rounded-full hover:border-[var(--accent)] cursor-pointer",title:"Settings",children:d.jsx(Am,{size:30,className:"text-[var(--muted)]"})})}),x&&d.jsx("div",{className:"fixed inset-0 bg-black/50 backdrop-blur-sm flex items-center justify-center z-50",children:d.jsxs("div",{"data-settings-modal":!0,className:"w-full max-w-md bg-[var(--bg)] text-[var(--fg)] border border-[var(--border)] rounded-2xl shadow-2xl p-6 space-y-4",children:[d.jsxs("div",{className:"flex items-center justify-between mb-2",children:[d.jsxs("div",{className:"text-lg font-semibold flex items-center gap-2",children:[d.jsx(Am,{size:24,className:"text-[var(--accent)]"})," Settings"]}),d.jsx("button",{onClick:()=>N(!1),className:"text-xs text-[var(--muted)] hover:text-[var(--accent)] cursor-pointer",children:"Close"})]}),r&&d.jsxs("div",{className:"text-sm text-[var(--muted)] border-b border-[var(--border)] pb-3",children:[d.jsxs("div",{className:"font-medium text-[var(--fg)]",children:[r.first_name," ",r.last_name]}),d.jsx("div",{className:"text-xs",children:r.email})]}),d.jsxs("div",{className:"space-y-3",children:[d.jsxs("div",{children:[d.jsxs("div",{className:"text-xs font-semibold text-[var(--muted)] uppercase mb-2 flex items-center gap-1.5",children:[d.jsx(Tp,{size:14})," Theme"]}),d.jsx("div",{className:"flex gap-2",children:["light","dark","system"].map(E=>d.jsx("button",{onClick:()=>s(E),className:`px-3 py-2 text-xs rounded-xl border transition cursor-pointer ${f===E?"border-[var(--accent)] text-[var(--accent)]":"border-[var(--border)] text-[var(--muted)] hover:text-[var(--accent)] hover:border-[var(--accent)]"}`,children:E.charAt(0).toUpperCase()+E.slice(1)},E))}),d.jsxs("div",{className:"text-[11px] text-[var(--muted)] mt-1",children:["Current: ",i," (",f==="system"?"system":"manual",")"]})]}),h&&d.jsxs("div",{className:"text-xs text-[var(--muted)]",children:["Runtime v",h]}),d.jsxs("button",{onClick:()=>{N(!1),m()},className:"flex items-center gap-2 px-3 py-2 text-xs font-semibold rounded-xl border border-[var(--border)] text-[var(--muted)] hover:text-[var(--fg)] transition w-full cursor-pointer",children:[d.jsx(Np,{size:16}),"Log out"]})]})]})})]})}function Ap(){return d.jsxs("div",{className:"flex h-screen",children:[d.jsx(_p,{}),d.jsx("main",{className:"flex-1 flex flex-col h-screen overflow-hidden",children:d.jsx("div",{className:"flex-1 w-full overflow-y-auto",children:d.jsx(A0,{})})})]})}function Cp(){const{login:i,pollLogin:f,checkSession:s,version:r}=ka(),{theme:m}=Wm(),h=Wn(),[x,N]=g.useState("idle"),[S,y]=g.useState(""),[A,E]=g.useState(""),L=g.useRef(null);g.useEffect(()=>{s().then(R=>{R&&h("/models",{replace:!0})})},[s,h]),g.useEffect(()=>()=>{L.current&&clearInterval(L.current)},[]);const X=async()=>{N("polling"),E("");try{const R=await i();y(R.user_code),window.open(R.verification_url,"_blank"),L.current=setInterval(async()=>{try{const B=await f(R.device_code);B==="approved"?(L.current&&clearInterval(L.current),h("/models",{replace:!0})):B==="expired"&&(L.current&&clearInterval(L.current),N("error"),E("Code expired. Please try again."))}catch{}},(R.interval||5)*1e3)}catch(R){N("error"),E(R instanceof Error?R.message:"Could not start login.")}},Q=()=>{L.current&&clearInterval(L.current),N("idle"),y(""),E("")};return d.jsxs("div",{className:"flex flex-col items-center justify-center min-h-screen gap-8",children:[d.jsx("div",{className:"flex flex-col items-center gap-2",children:d.jsx("img",{src:m==="light"?"/glyphh-logo-dark.png":"/glyphh-logo.png",alt:"Glyphh",className:"h-12"})}),d.jsxs("div",{className:"w-full max-w-sm bg-[var(--card-bg)] border border-[var(--card-border)] rounded-2xl p-8 text-center",children:[x==="idle"&&d.jsxs(d.Fragment,{children:[d.jsxs("h2",{className:"text-lg font-semibold mb-2",children:["Glyphh Runtime",r?` v${r}`:""]}),d.jsx("p",{className:"text-sm text-[var(--muted)] mb-6",children:"Sign in to manage your models and data."}),d.jsx("button",{onClick:X,className:"w-full px-4 py-3 text-sm font-semibold rounded-xl bg-[var(--accent)] btn-primary shadow shadow-[var(--accent)]/30 hover:opacity-95 transition cursor-pointer",children:"Sign In"})]}),x==="polling"&&d.jsxs(d.Fragment,{children:[d.jsx("h2",{className:"text-lg font-semibold mb-2",children:"Authorize this device"}),d.jsx("p",{className:"text-sm text-[var(--muted)] mb-4",children:"Enter this code in the browser window that just opened:"}),d.jsx("div",{className:"font-mono text-3xl font-bold text-[var(--accent)] tracking-widest my-6",children:S}),d.jsxs("div",{className:"flex items-center justify-center gap-2 text-sm text-[var(--muted)]",children:[d.jsx("span",{className:"inline-block w-4 h-4 border-2 border-[var(--border)] border-t-[var(--accent)] rounded-full animate-spin"}),"Waiting for approval..."]})]}),x==="error"&&d.jsxs(d.Fragment,{children:[d.jsx("p",{className:"text-sm text-red-400 mb-4",children:A}),d.jsx("button",{onClick:Q,className:"px-4 py-2 text-sm rounded-xl border border-[var(--border)] text-[var(--muted)] hover:text-[var(--accent)] hover:border-[var(--accent)] transition cursor-pointer",children:"Try Again"})]})]})]})}function cf({title:i,subtitle:f,actions:s}){return d.jsx("div",{className:"pt-6 bg-[var(--page-header)] border-b border-[var(--page-header-border)]",children:d.jsxs("div",{className:"flex items-center justify-between gap-3 pb-2",children:[d.jsxs("div",{className:"px-4",children:[d.jsx("h1",{className:"text-lg font-semibold",children:i}),f&&d.jsx("p",{className:"text-sm text-[var(--muted)]",children:f})]}),s&&d.jsx("div",{className:"flex items-center gap-2 pr-4",children:s})]})})}function Rp(i,f){const s=Math.round(i*f);return"█".repeat(s)+"░".repeat(f-s)}function Op(i,f){const s=i%(f+1);return"█".repeat(s)+"░".repeat(f-s)}function Za({progress:i,label:f,width:s=16,indeterminate:r}){const m=Math.round(Math.min(Math.max(i,0),1)*100),[h,x]=g.useState(0);return g.useEffect(()=>{if(!r)return;const N=setInterval(()=>x(S=>S+1),150);return()=>clearInterval(N)},[r]),d.jsxs("div",{className:"flex items-center gap-3 font-mono text-xs",children:[d.jsxs("span",{className:"text-[#A96BFE] tracking-tight",children:["[",r?Op(h,s):Rp(i,s),"]"]}),!r&&d.jsxs("span",{className:"text-[#A96BFE] font-semibold tabular-nums w-8 text-right",children:[m,"%"]}),f&&d.jsx("span",{className:"text-[var(--fg)] opacity-80 truncate",children:f}),(r||i>0&&i<1)&&d.jsx("span",{className:"inline-block w-2 h-2 rounded-full bg-[#A96BFE] animate-pulse"})]})}function Mp(){const{api:i,orgId:f}=ka(),s=Wn(),[r,m]=g.useState([]),[h,x]=g.useState(!0),[N,S]=g.useState(null),y=g.useRef(null),A=g.useRef(null),E=g.useCallback(async()=>{if(f)try{const R=await i.get(`/${f}/models`);return m(R.models||[]),R.models||[]}catch{return m([]),[]}},[f,i]);g.useEffect(()=>{x(!0),E().finally(()=>x(!1))},[E]),g.useEffect(()=>{const B=r.some(w=>w.status==="encoding"||w.status==="locked")||N!==null;return B&&!y.current?y.current=setInterval(()=>{E()},2e3):!B&&y.current&&(clearInterval(y.current),y.current=null),()=>{y.current&&(clearInterval(y.current),y.current=null)}},[r,N,E]);const L=async R=>{var k;const B=(k=R.target.files)==null?void 0:k[0];if(!B||!f)return;R.target.value="";const w=B.name.replace(/\.glyphh$/,"");S(w);try{const K=new FormData;K.append("file",B,B.name),await i.postFormData(`/${f}/${w}/model/deploy`,K),await E()}catch(K){alert("Deploy failed: "+(K instanceof Error?K.message:"Unknown error"))}finally{S(null)}},X=R=>N===R.model_id||R.status==="encoding"||R.status==="locked",Q=R=>N===R.model_id?"Deploying...":R.status==="encoding"?"Encoding exemplars...":R.status==="locked"?"Re-encoding...":"";return d.jsxs("div",{className:"space-y-4",children:[d.jsx(cf,{title:d.jsxs("span",{className:"inline-flex items-center gap-2",children:[d.jsx(uf,{size:22,className:"text-[var(--accent)]"}),d.jsx("span",{children:"Models"})]}),subtitle:"Deployed models on this runtime.",actions:d.jsxs("div",{className:"flex items-center gap-2",children:[d.jsx("input",{ref:A,type:"file",accept:".glyphh",className:"hidden",onChange:L}),d.jsx("button",{onClick:()=>{var R;return(R=A.current)==null?void 0:R.click()},className:"px-3 py-2 text-sm font-semibold rounded-xl bg-[var(--accent)] btn-primary shadow shadow-[var(--accent)]/30 hover:opacity-95 transition cursor-pointer",children:"Deploy Model"})]})}),d.jsxs("div",{className:"grid grid-cols-1 sm:grid-cols-2 xl:grid-cols-3 gap-4 px-4",children:[h&&r.length===0&&d.jsx("div",{className:"col-span-full text-sm text-[var(--muted)]",children:"Loading..."}),N&&!r.some(R=>R.model_id===N)&&d.jsxs("div",{className:"p-4 border border-[var(--accent)]/40 rounded-xl bg-[var(--card-bg)] border-[var(--card-border)]",children:[d.jsx("div",{className:"font-semibold text-base mb-1",children:N}),d.jsx("div",{className:"text-xs text-[var(--muted)] font-mono mb-3",children:N}),d.jsx(Za,{progress:0,indeterminate:!0,label:"Deploying..."})]}),r.map(R=>d.jsxs("div",{onClick:()=>s(`/models/${R.model_id}`),className:"p-4 border border-[var(--border)] rounded-xl hover:border-[var(--accent)] transition cursor-pointer bg-[var(--card-bg)] border-[var(--card-border)]",children:[d.jsxs("div",{className:"flex items-start justify-between mb-2",children:[d.jsx("div",{className:"font-semibold text-base",children:R.name||R.model_id}),d.jsxs("span",{className:`text-xs px-2 py-1 rounded-full ${X(R)?"bg-amber-500/10 text-amber-400":"bg-[var(--accent-soft)] text-[var(--accent)]"}`,children:[X(R)?Q(R).replace("...",""):R.status||"unknown",!X(R)&&R.version?` • v${R.version}`:""]})]}),d.jsx("div",{className:"text-xs text-[var(--muted)] font-mono mb-3",children:R.model_id}),X(R)?d.jsx(Za,{progress:0,indeterminate:!0,label:Q(R)}):d.jsxs("div",{className:"grid grid-cols-2 gap-2 text-[11px]",children:[d.jsxs("div",{className:"p-2 rounded-lg bg-[var(--border)]/20 border border-[var(--border)]/60",children:[d.jsx("div",{className:"text-[var(--muted)]",children:"Glyphs"}),d.jsx("div",{className:"font-semibold text-sm",children:R.glyphs??0})]}),d.jsxs("div",{className:"p-2 rounded-lg bg-[var(--border)]/20 border border-[var(--border)]/60",children:[d.jsx("div",{className:"text-[var(--muted)]",children:"Status"}),d.jsx("div",{className:"font-semibold text-sm",children:R.status||"unknown"})]})]})]},R.model_id)),!h&&r.length===0&&!N&&d.jsxs("div",{className:"col-span-full text-center py-16",children:[d.jsx("p",{className:"text-sm text-[var(--muted)] mb-4",children:"No models deployed yet."}),d.jsx("button",{onClick:()=>{var R;return(R=A.current)==null?void 0:R.click()},className:"px-4 py-2 text-sm font-semibold rounded-xl bg-[var(--accent)] btn-primary shadow shadow-[var(--accent)]/30 hover:opacity-95 transition cursor-pointer",children:"Deploy your first model"})]})]})]})}function Fr({open:i,title:f,message:s,confirmLabel:r="Confirm",cancelLabel:m="Cancel",variant:h="danger",onConfirm:x,onCancel:N}){const S=g.useRef(null);g.useEffect(()=>{var E;i&&((E=S.current)==null||E.focus())},[i]);const y=g.useCallback(E=>{E.key==="Escape"&&N()},[N]);if(!i)return null;const A=h==="danger";return d.jsx("div",{className:"fixed inset-0 bg-black/50 backdrop-blur-sm flex items-center justify-center z-50",onClick:N,onKeyDown:y,children:d.jsxs("div",{className:"w-full max-w-sm bg-[var(--bg)] text-[var(--fg)] border border-[var(--border)] rounded-2xl shadow-2xl p-6 space-y-4",onClick:E=>E.stopPropagation(),children:[d.jsxs("div",{className:"flex items-center gap-3",children:[d.jsx("div",{className:`flex items-center justify-center w-10 h-10 rounded-full ${A?"bg-red-500/10 text-red-400":"bg-amber-500/10 text-amber-400"}`,children:d.jsx(zp,{size:22})}),d.jsx("div",{className:"text-base font-semibold",children:f})]}),d.jsx("p",{className:"text-sm text-[var(--muted)] leading-relaxed",children:s}),d.jsxs("div",{className:"flex items-center justify-end gap-2 pt-2",children:[d.jsx("button",{ref:S,onClick:N,className:"px-4 py-2 text-xs rounded-xl border border-[var(--border)] text-[var(--muted)] hover:text-[var(--fg)] hover:border-[var(--fg)]/30 transition cursor-pointer",children:m}),d.jsx("button",{onClick:x,className:`px-4 py-2 text-xs font-semibold rounded-xl shadow transition cursor-pointer ${A?"bg-red-500 text-white hover:bg-red-600 shadow-red-500/30":"bg-amber-500 text-white hover:bg-amber-600 shadow-amber-500/30"}`,children:r})]})]})})}function Dp(){const{modelId:i}=h0(),{api:f,orgId:s}=ka(),r=Wn(),[m,h]=g.useState(i||""),[x,N]=g.useState("-"),[S,y]=g.useState(0),[A,E]=g.useState(0),[L,X]=g.useState([]),[Q,R]=g.useState(0),[B,w]=g.useState(0),[k,K]=g.useState(!1),[ce,le]=g.useState("idle"),[re,$]=g.useState(""),[_e,He]=g.useState(0),[at,Ve]=g.useState(!1),Ce=g.useRef(null),[F,Me]=g.useState(null),[fe,O]=g.useState(null),[G,I]=g.useState(""),[ge,Se]=g.useState(!1),b=g.useRef(null),U=20,Y=Math.max(1,Math.ceil(Q/U)),Z=B*U,ee=g.useCallback(async()=>{if(!s||!i)return null;try{const[q,ve]=await Promise.all([f.get(`/${s}/${i}/ready`).catch(()=>null),f.get(`/${s}/${i}/data/count`).catch(()=>null)]);if(q){h(q.meta_name||i);const nt=q.ready?"Ready":q.status||"Unknown";N(nt)}return ve&&(y(ve.glyphs??0),E(ve.vectors??0)),(q==null?void 0:q.status)??null}catch{return null}},[s,i,f]),te=g.useCallback(async(q=B)=>{if(!(!s||!i)){K(!0);try{const ve=await f.get(`/${s}/${i}/data?limit=${U}&offset=${q*U}`);X(ve.glyphs||[]),R(ve.total||0),w(q)}catch{X([])}finally{K(!1)}}},[s,i,f,B]),ne=g.useRef(null);g.useEffect(()=>{ee(),te(0)},[s,i]),g.useEffect(()=>{const q=x==="encoding"||x==="locked";return q&&!ne.current?ne.current=setInterval(async()=>{const ve=await ee();ve!=="encoding"&&ve!=="locked"&&(ne.current&&(clearInterval(ne.current),ne.current=null),te(0))},2e3):!q&&ne.current&&(clearInterval(ne.current),ne.current=null),()=>{ne.current&&(clearInterval(ne.current),ne.current=null)}},[x,ee]);const $e=async()=>{if(!(!s||!i)){Ve(!0);try{await f.post(`/${s}/${i}/model/re-encode`);const q=setInterval(async()=>{try{(await f.get(`/${s}/${i}/ready`)).status!=="locked"&&(clearInterval(q),Ve(!1),await ee(),await te(0))}catch{clearInterval(q),Ve(!1)}},2e3)}catch(q){Ve(!1),alert("Re-encode failed: "+(q instanceof Error?q.message:""))}}},Be=g.useCallback(async()=>{if(!(!s||!i)){Me(null);try{await f.delete(`/${s}/${i}/data`),await ee(),await te(0)}catch(q){alert("Clear failed: "+(q instanceof Error?q.message:""))}}},[s,i,f]),ql=g.useCallback(async()=>{if(!(!s||!i)){Me(null);try{await f.delete(`/${s}/${i}/model`),r("/models",{replace:!0})}catch(q){alert("Delete failed: "+(q instanceof Error?q.message:""))}}},[s,i,f,r]),Yl=q=>{O(q),I(q.concept_text||"")},$a=async()=>{if(!(!s||!i||!fe)){Se(!0);try{await f.put(`/${s}/${i}/data/${fe.id}`,{concept_text:G}),O(null),await te(B)}catch(q){alert("Save failed: "+(q instanceof Error?q.message:""))}finally{Se(!1)}}},dl=()=>{Ce.current&&(clearInterval(Ce.current),Ce.current=null)},qt=()=>{le("finalizing"),$("Indexing vectors..."),Ce.current=setInterval(async()=>{try{const q=await ee();q!=="encoding"&&q!=="locked"&&(dl(),le("done"),He(1),$("Complete"),await te(0),setTimeout(()=>le("idle"),2e3))}catch{dl(),le("idle")}},2e3)},Wa=async q=>{var nt;const ve=(nt=q.target.files)==null?void 0:nt[0];if(!(!ve||!s||!i)){q.target.value="",le("parsing"),He(0),$("Parsing file...");try{const Dt=await ve.text();let Yt;const In=Dt.trim();try{const be=JSON.parse(In);if(Array.isArray(be))Yt=be;else if(be.records&&Array.isArray(be.records))Yt=be.records;else throw new Error("Expected array or {records: [...]}")}catch{Yt=In.split(`
`).filter(Boolean).map(be=>JSON.parse(be))}le("submitting"),$(`Submitting ${Yt.length.toLocaleString()} records...`);const Pn=await f.post(`/${s}/${i}/listener`,{records:Yt,batch_size:50});Pn.job_id?(le("processing"),He(0),$(`0 / ${Yt.length} records`),Ce.current=setInterval(async()=>{try{const be=await f.get(`/${s}/${i}/listener/jobs/${Pn.job_id}`);He((be.progress??0)/100),$(`${be.encoded??be.processed} / ${be.total} records`),be.status==="completed"||be.status==="done"?(dl(),qt()):(be.status==="error"||be.status==="failed")&&(dl(),le("error"),$(`Error: ${be.error||"Unknown"}`))}catch{dl(),le("error"),$("Connection lost during processing")}},1e3)):qt()}catch(Dt){le("error"),$("Error: "+(Dt instanceof Error?Dt.message:""))}}},Fa=()=>{if(Y<=7)return Array.from({length:Y},(ve,nt)=>nt);const q=[];if(B<=3){for(let ve=0;ve<5;ve++)q.push(ve);q.push("...",Y-1)}else if(B>=Y-4){q.push(0,"...");for(let ve=Y-5;ve<Y;ve++)q.push(ve)}else q.push(0,"...",B-1,B,B+1,"...",Y-1);return q};return d.jsxs("div",{className:"space-y-4 pb-12",children:[d.jsx(cf,{title:d.jsxs("span",{className:"inline-flex items-center gap-2",children:[d.jsx(uf,{size:22,className:"text-[var(--accent)]"}),d.jsx("span",{children:m})]}),subtitle:i,actions:d.jsxs("div",{className:"flex items-center gap-2",children:[d.jsx("button",{onClick:$e,className:"px-3 py-2 text-xs rounded-xl border border-[var(--border)] text-[var(--muted)] hover:text-[var(--accent)] hover:border-[var(--accent)] cursor-pointer",children:"Re-encode"}),d.jsx("button",{onClick:()=>Me("clear"),className:"px-3 py-2 text-xs rounded-xl border border-red-500/30 text-red-400 hover:border-red-400 cursor-pointer",children:"Clear Data"}),d.jsx("button",{onClick:()=>Me("delete"),className:"px-3 py-2 text-xs rounded-xl border border-red-500/30 text-red-400 hover:border-red-400 cursor-pointer",children:"Delete"})]})}),d.jsxs("div",{className:"px-4 space-y-6",children:[d.jsx("button",{onClick:()=>r("/models"),className:"text-sm text-[var(--muted)] hover:text-[var(--fg)] cursor-pointer",children:"← Back to models"}),d.jsx("div",{className:"flex gap-4",children:[{label:"Glyphs",value:S.toLocaleString()},{label:"Vectors",value:A.toLocaleString()},{label:"Status",value:x}].map(q=>d.jsxs("div",{className:"p-4 rounded-xl border border-[var(--border)] bg-[var(--card-bg)] min-w-[140px]",children:[d.jsx("div",{className:"text-[11px] text-[var(--muted)] uppercase tracking-wide",children:q.label}),d.jsx("div",{className:"text-xl font-semibold mt-1",children:q.value})]},q.label))}),d.jsxs("div",{onClick:()=>{var q;return ce==="idle"&&((q=b.current)==null?void 0:q.click())},onDragOver:q=>{q.preventDefault(),q.currentTarget.classList.add("border-[var(--accent)]","bg-[var(--accent-soft)]")},onDragLeave:q=>{q.currentTarget.classList.remove("border-[var(--accent)]","bg-[var(--accent-soft)]")},onDrop:q=>{q.preventDefault(),q.currentTarget.classList.remove("border-[var(--accent)]","bg-[var(--accent-soft)]");const ve=q.dataTransfer.files[0];if(ve){const nt=b.current;if(nt){const Dt=new DataTransfer;Dt.items.add(ve),nt.files=Dt.files,nt.dispatchEvent(new Event("change",{bubbles:!0}))}}},className:"border-2 border-dashed border-[var(--border)] rounded-xl p-10 text-center text-[var(--muted)] hover:border-[var(--accent)] hover:bg-[var(--accent-soft)] transition cursor-pointer",children:[d.jsx("input",{ref:b,type:"file",accept:".json,.jsonl",className:"hidden",onChange:Wa}),d.jsx("div",{className:"text-2xl mb-2",children:"📦"}),d.jsx("p",{className:"text-sm",children:"Drop a concepts.json file here to load data"}),d.jsxs("p",{className:"text-xs text-[var(--muted)] mt-1",children:["JSON array, ","{records: [...]}",", or JSONL"]})]}),(at||x==="encoding"||x==="locked")&&d.jsx("div",{className:"p-3 rounded-xl border border-[var(--accent)]/30 bg-[var(--card-bg)]",children:d.jsx(Za,{progress:S>0&&A>=0?Math.min(A/Math.max(S,1),.99):0,indeterminate:A===0&&S===0,label:x==="encoding"?`Encoding exemplars${S>0?` — ${A.toLocaleString()} / ${S.toLocaleString()} vectors`:"..."}`:`Re-encoding vectors${S>0?` — ${A.toLocaleString()} / ${S.toLocaleString()}`:"..."}`})}),ce!=="idle"&&d.jsx("div",{className:"p-3 rounded-xl border border-[var(--border)] bg-[var(--card-bg)]",children:ce==="error"?d.jsxs("div",{className:"flex items-center justify-between",children:[d.jsx("div",{className:"font-mono text-xs text-red-400",children:re}),d.jsx("button",{onClick:()=>le("idle"),className:"text-xs text-[var(--muted)] hover:text-[var(--fg)] cursor-pointer",children:"Dismiss"})]}):ce==="done"?d.jsx(Za,{progress:1,label:re}):ce==="processing"?d.jsx(Za,{progress:_e,label:re}):d.jsx(Za,{progress:0,indeterminate:!0,label:re})}),d.jsxs("div",{children:[d.jsx("h2",{className:"text-sm font-semibold mb-3",children:"Data"}),d.jsx("div",{className:"border border-[var(--border)] rounded-xl overflow-hidden bg-[var(--card-bg)]",children:d.jsxs("table",{className:"w-full text-sm",children:[d.jsx("thead",{children:d.jsxs("tr",{className:"border-b border-[var(--border)]",children:[d.jsx("th",{className:"text-left px-4 py-2 text-[11px] text-[var(--muted)] uppercase tracking-wide font-medium",children:"ID"}),d.jsx("th",{className:"text-left px-4 py-2 text-[11px] text-[var(--muted)] uppercase tracking-wide font-medium",children:"Concept"}),d.jsx("th",{className:"text-left px-4 py-2 text-[11px] text-[var(--muted)] uppercase tracking-wide font-medium",children:"Type"}),d.jsx("th",{className:"text-left px-4 py-2 text-[11px] text-[var(--muted)] uppercase tracking-wide font-medium",children:"Vector"}),d.jsx("th",{className:"text-left px-4 py-2 text-[11px] text-[var(--muted)] uppercase tracking-wide font-medium",children:"Created"}),d.jsx("th",{className:"text-right px-4 py-2 text-[11px] text-[var(--muted)] uppercase tracking-wide font-medium"})]})}),d.jsxs("tbody",{children:[k&&L.length===0&&d.jsx("tr",{children:d.jsx("td",{colSpan:6,className:"px-4 py-8 text-center text-[var(--muted)]",children:"Loading..."})}),!k&&L.length===0&&d.jsx("tr",{children:d.jsx("td",{colSpan:6,className:"px-4 py-8 text-center text-[var(--muted)]",children:"No data loaded yet"})}),L.map(q=>d.jsxs("tr",{className:"border-b border-[var(--border)] last:border-b-0 hover:bg-[var(--border)]/20 cursor-pointer",onClick:()=>Yl(q),children:[d.jsx("td",{className:"px-4 py-2 font-mono text-[11px] text-[var(--muted)]",children:String(q.id).slice(0,8)}),d.jsx("td",{className:"px-4 py-2 max-w-[300px] truncate",children:(q.concept_text||"").slice(0,80)}),d.jsx("td",{className:"px-4 py-2",children:d.jsxs("div",{className:"flex items-center gap-1.5",children:[q.node_type&&d.jsx("span",{className:"text-[10px] px-2 py-0.5 rounded-full bg-[var(--accent-soft)] text-[var(--accent)]",children:q.node_type}),q.record_type&&q.record_type!=="data"&&d.jsx("span",{className:"text-[10px] px-2 py-0.5 rounded-full bg-[var(--border)]/40 text-[var(--muted)]",children:q.record_type})]})}),d.jsx("td",{className:"px-4 py-2 font-mono text-[11px] text-[var(--muted)]",children:q.has_embedding?`${q.vector_dim}d`:"—"}),d.jsx("td",{className:"px-4 py-2 text-xs text-[var(--muted)]",children:q.created_at?new Date(q.created_at).toLocaleDateString():"—"}),d.jsx("td",{className:"px-4 py-2 text-right",children:d.jsx("button",{onClick:ve=>{ve.stopPropagation(),Yl(q)},className:"p-1 rounded-lg text-[var(--muted)] hover:text-[var(--accent)] transition",title:"View / Edit",children:d.jsx(Ep,{size:14})})})]},q.id))]})]})}),Q>0&&d.jsxs("div",{className:"flex items-center justify-between mt-4",children:[d.jsxs("div",{className:"text-xs text-[var(--muted)]",children:[Z+1,"–",Math.min(Z+U,Q)," of ",Q]}),d.jsxs("div",{className:"flex items-center gap-1",children:[d.jsx("button",{onClick:()=>te(B-1),disabled:B===0,className:"px-2.5 py-1 text-xs rounded-lg border border-[var(--border)] text-[var(--muted)] hover:text-[var(--accent)] hover:border-[var(--accent)] transition cursor-pointer disabled:opacity-30 disabled:cursor-default disabled:hover:text-[var(--muted)] disabled:hover:border-[var(--border)]",children:"‹ Prev"}),Fa().map((q,ve)=>q==="..."?d.jsx("span",{className:"px-1.5 text-xs text-[var(--muted)]",children:"…"},`e${ve}`):d.jsx("button",{onClick:()=>te(q),className:`px-2.5 py-1 text-xs rounded-lg border transition cursor-pointer ${q===B?"border-[var(--accent)] text-[var(--accent)] bg-[var(--accent-soft)]":"border-[var(--border)] text-[var(--muted)] hover:text-[var(--accent)] hover:border-[var(--accent)]"}`,children:q+1},q)),d.jsx("button",{onClick:()=>te(B+1),disabled:B>=Y-1,className:"px-2.5 py-1 text-xs rounded-lg border border-[var(--border)] text-[var(--muted)] hover:text-[var(--accent)] hover:border-[var(--accent)] transition cursor-pointer disabled:opacity-30 disabled:cursor-default disabled:hover:text-[var(--muted)] disabled:hover:border-[var(--border)]",children:"Next ›"})]})]})]})]}),fe&&d.jsx("div",{className:"fixed inset-0 bg-black/50 backdrop-blur-sm flex items-center justify-center z-50",onClick:()=>O(null),children:d.jsxs("div",{className:"w-full max-w-lg bg-[var(--bg)] text-[var(--fg)] border border-[var(--border)] rounded-2xl shadow-2xl p-6 space-y-4 max-h-[80vh] overflow-y-auto",onClick:q=>q.stopPropagation(),children:[d.jsxs("div",{className:"flex items-center justify-between",children:[d.jsx("div",{className:"text-base font-semibold",children:"Glyph Detail"}),d.jsx("button",{onClick:()=>O(null),className:"p-1 rounded-lg text-[var(--muted)] hover:text-[var(--accent)] cursor-pointer",children:d.jsx(xp,{size:18})})]}),d.jsxs("div",{className:"space-y-1",children:[d.jsx("label",{className:"text-[11px] text-[var(--muted)] uppercase tracking-wide font-medium",children:"ID"}),d.jsx("div",{className:"font-mono text-xs text-[var(--muted)] bg-[var(--page-bg)] border border-[var(--border)] rounded-xl px-3 py-2 select-all",children:fe.id})]}),d.jsxs("div",{className:"space-y-1",children:[d.jsx("label",{className:"text-[11px] text-[var(--muted)] uppercase tracking-wide font-medium",children:"Concept Text"}),d.jsx("textarea",{value:G,onChange:q=>I(q.target.value),rows:4,className:"w-full px-3 py-2 bg-[var(--page-bg)] border border-[var(--border)] rounded-xl text-sm outline-none focus:border-[var(--accent)] resize-y font-mono"})]}),d.jsxs("div",{className:"grid grid-cols-2 gap-3",children:[d.jsxs("div",{className:"space-y-1",children:[d.jsx("label",{className:"text-[11px] text-[var(--muted)] uppercase tracking-wide font-medium",children:"Node Type"}),d.jsx("div",{className:"text-sm px-3 py-2 bg-[var(--page-bg)] border border-[var(--border)] rounded-xl",children:fe.node_type||"—"})]}),d.jsxs("div",{className:"space-y-1",children:[d.jsx("label",{className:"text-[11px] text-[var(--muted)] uppercase tracking-wide font-medium",children:"Record Type"}),d.jsx("div",{className:"text-sm px-3 py-2 bg-[var(--page-bg)] border border-[var(--border)] rounded-xl",children:fe.record_type||"—"})]}),d.jsxs("div",{className:"space-y-1",children:[d.jsx("label",{className:"text-[11px] text-[var(--muted)] uppercase tracking-wide font-medium",children:"Vector"}),d.jsx("div",{className:"text-sm px-3 py-2 bg-[var(--page-bg)] border border-[var(--border)] rounded-xl",children:fe.has_embedding?`${fe.vector_dim}d`:"No embedding"})]}),d.jsxs("div",{className:"space-y-1",children:[d.jsx("label",{className:"text-[11px] text-[var(--muted)] uppercase tracking-wide font-medium",children:"Created"}),d.jsx("div",{className:"text-sm px-3 py-2 bg-[var(--page-bg)] border border-[var(--border)] rounded-xl",children:fe.created_at?new Date(fe.created_at).toLocaleString():"—"})]})]}),d.jsxs("div",{className:"flex items-center justify-end gap-2 pt-2",children:[d.jsx("button",{onClick:()=>O(null),className:"px-3 py-2 text-xs rounded-xl border border-[var(--border)] text-[var(--muted)] hover:text-[var(--fg)] transition cursor-pointer",children:"Cancel"}),d.jsx("button",{onClick:$a,disabled:ge||G===(fe.concept_text||""),className:"px-4 py-2 text-xs font-semibold rounded-xl bg-[var(--accent)] btn-primary shadow shadow-[var(--accent)]/30 hover:opacity-95 transition disabled:opacity-50 cursor-pointer",children:ge?"Saving...":"Save Changes"})]})]})}),d.jsx(Fr,{open:F==="clear",title:"Clear Model Data",message:`This will permanently delete all glyphs and vectors for ${i}. The model will remain deployed but empty.`,confirmLabel:"Clear All Data",variant:"danger",onConfirm:Be,onCancel:()=>Me(null)}),d.jsx(Fr,{open:F==="delete",title:"Delete Model",message:`This will permanently delete ${i} and all its data — glyphs, vectors, edges, and configuration. This cannot be undone.`,confirmLabel:"Delete Model",variant:"danger",onConfirm:ql,onCancel:()=>Me(null)})]})}function Up(){const{api:i,orgId:f}=ka(),[s,r]=g.useState([]),[m,h]=g.useState(!0),[x,N]=g.useState(!1),[S,y]=g.useState(null),[A,E]=g.useState(!1),[L,X]=g.useState(""),[Q,R]=g.useState(""),[B,w]=g.useState(new Set(["read","write"])),[k,K]=g.useState("365"),[ce,le]=g.useState(!1),[re,$]=g.useState(null),_e=async()=>{if(f){h(!0);try{const F=await i.get(`/${f}/tokens`);r(F.tokens||[])}catch{r([])}finally{h(!1)}}};g.useEffect(()=>{_e()},[f]);const He=async()=>{if(!(!f||!L.trim()||ce)){le(!0);try{const F=await i.post(`/${f}/tokens`,{name:L.trim(),model_id:Q.trim()||null,permissions:Array.from(B),expires_days:k==="never"?null:parseInt(k)});y(F.token),E(!1),await _e()}catch(F){alert("Create failed: "+(F instanceof Error?F.message:""))}finally{le(!1)}}},at=g.useCallback(async()=>{if(!(!f||!re)){$(null);try{await i.delete(`/${f}/tokens/${re.id}`),await _e()}catch(F){alert("Revoke failed: "+(F instanceof Error?F.message:""))}}},[f,re,i]),Ve=F=>{w(Me=>{const fe=new Set(Me);return fe.has(F)?fe.delete(F):fe.add(F),fe})},Ce=()=>{X(""),R(""),w(new Set(["read","write"])),K("365"),y(null),E(!1),N(!1)};return d.jsxs("div",{className:"space-y-4",children:[d.jsx(cf,{title:d.jsxs("span",{className:"inline-flex items-center gap-2",children:[d.jsx(Wr,{size:22,className:"text-[var(--accent)]"}),d.jsx("span",{children:"API Tokens"})]}),subtitle:"Manage tokens for listeners, MCP clients, and external integrations.",actions:d.jsx("button",{onClick:()=>{y(null),N(!0)},className:"px-3 py-2 text-sm font-semibold rounded-xl bg-[var(--accent)] btn-primary shadow shadow-[var(--accent)]/30 hover:opacity-95 transition cursor-pointer",children:"Create Token"})}),d.jsx("div",{className:"px-4",children:d.jsx("div",{className:"border border-[var(--border)] rounded-xl overflow-hidden bg-[var(--card-bg)]",children:d.jsxs("table",{className:"w-full text-sm",children:[d.jsx("thead",{children:d.jsxs("tr",{className:"border-b border-[var(--border)]",children:[d.jsx("th",{className:"text-left px-4 py-2 text-[11px] text-[var(--muted)] uppercase tracking-wide font-medium",children:"Name"}),d.jsx("th",{className:"text-left px-4 py-2 text-[11px] text-[var(--muted)] uppercase tracking-wide font-medium",children:"Prefix"}),d.jsx("th",{className:"text-left px-4 py-2 text-[11px] text-[var(--muted)] uppercase tracking-wide font-medium",children:"Scope"}),d.jsx("th",{className:"text-left px-4 py-2 text-[11px] text-[var(--muted)] uppercase tracking-wide font-medium",children:"Permissions"}),d.jsx("th",{className:"text-left px-4 py-2 text-[11px] text-[var(--muted)] uppercase tracking-wide font-medium",children:"Created"}),d.jsx("th",{className:"text-left px-4 py-2 text-[11px] text-[var(--muted)] uppercase tracking-wide font-medium",children:"Expires"}),d.jsx("th",{className:"text-right px-4 py-2 text-[11px] text-[var(--muted)] uppercase tracking-wide font-medium"})]})}),d.jsxs("tbody",{children:[m&&s.length===0&&d.jsx("tr",{children:d.jsx("td",{colSpan:7,className:"px-4 py-8 text-center text-[var(--muted)]",children:"Loading..."})}),!m&&s.length===0&&d.jsx("tr",{children:d.jsx("td",{colSpan:7,className:"px-4 py-8 text-center text-[var(--muted)]",children:"No tokens yet. Create one to get started."})}),s.map(F=>d.jsxs("tr",{className:"border-b border-[var(--border)] last:border-b-0 hover:bg-[var(--border)]/20",children:[d.jsx("td",{className:"px-4 py-3 font-medium",children:F.name}),d.jsxs("td",{className:"px-4 py-3 font-mono text-xs text-[var(--muted)]",children:[F.token_prefix,"..."]}),d.jsx("td",{className:"px-4 py-3 text-xs text-[var(--muted)]",children:F.model_id||"All models"}),d.jsx("td",{className:"px-4 py-3",children:d.jsx("div",{className:"flex gap-1",children:F.permissions.map(Me=>d.jsx("span",{className:"text-[10px] px-2 py-0.5 rounded-full bg-[var(--accent-soft)] text-[var(--accent)]",children:Me},Me))})}),d.jsx("td",{className:"px-4 py-3 text-xs text-[var(--muted)]",children:F.created_at?new Date(F.created_at).toLocaleDateString():"-"}),d.jsx("td",{className:"px-4 py-3 text-xs text-[var(--muted)]",children:F.expires_at?new Date(F.expires_at).toLocaleDateString():"Never"}),d.jsx("td",{className:"px-4 py-3 text-right",children:d.jsx("button",{onClick:()=>$({id:F.id,name:F.name}),className:"p-1.5 rounded-lg text-red-400 hover:bg-red-400/10 transition cursor-pointer",title:"Revoke token",children:d.jsx(Sp,{size:16})})})]},F.id))]})]})})}),x&&d.jsx("div",{className:"fixed inset-0 bg-black/50 backdrop-blur-sm flex items-center justify-center z-50",children:d.jsxs("div",{className:"w-full max-w-md bg-[var(--bg)] text-[var(--fg)] border border-[var(--border)] rounded-2xl shadow-2xl p-6 space-y-4",onClick:F=>F.stopPropagation(),children:[d.jsxs("div",{className:"flex items-center justify-between mb-2",children:[d.jsxs("div",{className:"text-lg font-semibold flex items-center gap-2",children:[d.jsx(Wr,{size:20,className:"text-[var(--accent)]"}),S?"Token Created":"Create API Token"]}),d.jsx("button",{onClick:Ce,className:"text-xs text-[var(--muted)] hover:text-[var(--accent)] cursor-pointer",children:"Close"})]}),S?d.jsxs("div",{className:"space-y-4",children:[d.jsx("p",{className:"text-sm text-[var(--muted)]",children:"Copy this token now — it won't be shown again."}),d.jsxs("div",{className:"flex items-center gap-2",children:[d.jsx("div",{className:"flex-1 font-mono text-xs bg-[var(--page-bg)] border border-[var(--border)] rounded-xl px-3 py-2 break-all select-all",children:S}),d.jsx("button",{onClick:()=>{navigator.clipboard.writeText(S),E(!0),setTimeout(()=>E(!1),1500)},className:`p-2 rounded-lg border transition cursor-pointer ${A?"border-emerald-400 text-emerald-400":"border-[var(--border)] text-[var(--muted)] hover:text-[var(--accent)] hover:border-[var(--accent)]"}`,title:"Copy",children:A?d.jsx(bp,{size:16}):d.jsx(jp,{size:16})})]}),d.jsx("button",{onClick:Ce,className:"w-full px-4 py-2 text-sm font-semibold rounded-xl bg-[var(--accent)] btn-primary shadow shadow-[var(--accent)]/30 hover:opacity-95 transition cursor-pointer",children:"Done"})]}):d.jsxs("div",{className:"space-y-3",children:[d.jsxs("div",{className:"space-y-1",children:[d.jsx("label",{className:"text-xs font-medium",children:"Name"}),d.jsx("input",{type:"text",value:L,onChange:F=>X(F.target.value),placeholder:"e.g. boomi-prod, mcp-client",className:"w-full px-3 py-2 bg-[var(--page-bg)] border border-[var(--border)] rounded-xl text-sm outline-none focus:border-[var(--accent)]"})]}),d.jsxs("div",{className:"space-y-1",children:[d.jsx("label",{className:"text-xs font-medium",children:"Model scope"}),d.jsx("input",{type:"text",value:Q,onChange:F=>R(F.target.value),placeholder:"All models (leave empty)",className:"w-full px-3 py-2 bg-[var(--page-bg)] border border-[var(--border)] rounded-xl text-sm outline-none focus:border-[var(--accent)]"}),d.jsx("p",{className:"text-[10px] text-[var(--muted)]",children:"Leave empty for access to all models."})]}),d.jsxs("div",{className:"space-y-1",children:[d.jsx("label",{className:"text-xs font-medium",children:"Permissions"}),d.jsx("div",{className:"flex gap-2",children:["read","write","admin"].map(F=>d.jsx("button",{onClick:()=>Ve(F),className:`px-3 py-1.5 text-xs rounded-xl border transition cursor-pointer ${B.has(F)?"border-[var(--accent)] text-[var(--accent)] bg-[var(--accent-soft)]":"border-[var(--border)] text-[var(--muted)] hover:border-[var(--accent)] hover:text-[var(--accent)]"}`,children:F},F))})]}),d.jsxs("div",{className:"space-y-1",children:[d.jsx("label",{className:"text-xs font-medium",children:"Expires"}),d.jsxs("select",{value:k,onChange:F=>K(F.target.value),className:"w-full px-3 py-2 bg-[var(--page-bg)] border border-[var(--border)] rounded-xl text-sm outline-none focus:border-[var(--accent)]",children:[d.jsx("option",{value:"30",children:"30 days"}),d.jsx("option",{value:"90",children:"90 days"}),d.jsx("option",{value:"365",children:"1 year"}),d.jsx("option",{value:"never",children:"Never"})]})]}),d.jsxs("div",{className:"flex items-center justify-end gap-2 pt-2",children:[d.jsx("button",{onClick:Ce,className:"px-3 py-2 text-xs rounded-xl border border-[var(--border)] text-[var(--muted)] hover:text-[var(--accent)] hover:border-[var(--accent)] cursor-pointer",children:"Cancel"}),d.jsx("button",{onClick:He,disabled:!L.trim()||ce,className:"px-4 py-2 text-xs font-semibold rounded-xl bg-[var(--accent)] btn-primary shadow shadow-[var(--accent)]/30 hover:opacity-95 transition disabled:opacity-50 cursor-pointer",children:ce?"Creating...":"Create Token"})]})]})]})}),d.jsx(Fr,{open:re!==null,title:"Revoke Token",message:`Revoke token "${re==null?void 0:re.name}"? Any integrations using this token will immediately lose access. This cannot be undone.`,confirmLabel:"Revoke Token",variant:"danger",onConfirm:at,onCancel:()=>$(null)})]})}function Hp({children:i}){const{token:f}=ka();return f?d.jsx(d.Fragment,{children:i}):d.jsx(kr,{to:"/login",replace:!0})}function Bp(){return d.jsxs(R0,{children:[d.jsx(wl,{path:"/login",element:d.jsx(Cp,{})}),d.jsxs(wl,{path:"/",element:d.jsx(Hp,{children:d.jsx(Ap,{})}),children:[d.jsx(wl,{index:!0,element:d.jsx(kr,{to:"/models",replace:!0})}),d.jsx(wl,{path:"models",element:d.jsx(Mp,{})}),d.jsx(wl,{path:"models/:modelId",element:d.jsx(Dp,{})}),d.jsx(wl,{path:"tokens",element:d.jsx(Up,{})})]}),d.jsx(wl,{path:"*",element:d.jsx(kr,{to:"/",replace:!0})})]})}Cy.createRoot(document.getElementById("root")).render(d.jsx(g.StrictMode,{children:d.jsx(ep,{children:d.jsx(op,{children:d.jsx(sp,{children:d.jsx(Bp,{})})})})}));
